@@ -31,6 +31,7 @@ typedef gint	(*AccountFunc)	(PrefsAccount	*ac_prefs,
 
 extern PrefsAccount *cur_account;
 
+PrefsAccount *account_get_cur_account   (void);
 void	      account_read_config_all	(void);
 void	      account_write_config_all	(void);
 
@@ -46,7 +47,7 @@ void	      account_set_menu_only_toolbar	(void);
 
 GList	     *account_get_list		(void);
 
-void	      account_edit_open		(void);
+void	      account_edit_open		(gpointer a, gpointer b);
 void	      account_add		(void);
 void	      account_open		(PrefsAccount	*ac_prefs);
 void	      account_set_as_recv_at_get_all	(PrefsAccount	*ac_prefs);
@@ -60,5 +61,6 @@ PrefsAccount *account_get_reply_account	(MsgInfo 	*msginfo,
 					 gboolean	 reply_autosel);
 void 	      account_rename_path	(const gchar 	*old_id, 
 					 const gchar 	*new_id);
+gchar *account_get_signature_str(PrefsAccount *account);
 
 #endif /* __ACCOUNT_H__ */
