@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * 
  */
 
 /*
@@ -299,8 +299,7 @@ static void addrharvest_insert_cache(
 	}
 
 	/* Insert address */
-	key = g_strdup( address );
-	g_strdown( key );
+	key = g_utf8_strdown( address, -1 );
 	person = g_hash_table_lookup( harvester->dupTable, key );
 	if( person ) {
 		/* Update existing person to use longest name */
@@ -721,7 +720,7 @@ static void addrharvest_harvest_dir(
 	/* Process directory */
 	chdir( dir );
 	while( ( d = readdir( dp ) ) != NULL ) {
-		stat( d->d_name, &s );
+		g_stat( d->d_name, &s );
 		if( S_ISDIR( s.st_mode ) ) {
 			if( harvester->folderRecurse ) {
 				if( strstr( DIR_IGNORE, d->d_name ) != NULL )
@@ -807,8 +806,7 @@ gint addrharvest_harvest(
 		if( entry->selected ) {
 			gchar *p;
 
-			p = g_strdup( entry->header );
-			g_strdown( p );
+			p = g_utf8_strdown( entry->header, -1 );
 			listHdr = g_list_append( listHdr, p );
 		}
 		node = g_list_next( node );
