@@ -60,7 +60,7 @@ static gboolean session_write_data_cb	(SockInfo	*source,
 					 gpointer	 data);
 
 
-void session_init(Session *session)
+void session_init(Session *session, const void *prefs_account, gboolean is_smtp)
 {
 	session->type = SESSION_UNKNOWN;
 	session->sock = NULL;
@@ -97,6 +97,8 @@ void session_init(Session *session)
 	session->timeout_interval = 0;
 
 	session->data = NULL;
+	session->account = prefs_account;
+	session->is_smtp = is_smtp;
 }
 
 /*!
@@ -139,6 +141,7 @@ gint session_connect(Session *session, const gchar *server, gushort port)
 		session_close(session);
 		return -1;
 	}
+	sock->is_smtp = session->is_smtp;
 
 	return session_connect_cb(sock, session);
 #endif
@@ -157,7 +160,8 @@ static gint session_connect_cb(SockInfo *sock, gpointer data)
 	}
 
 	session->sock = sock;
-
+	sock->account = session->account;
+	sock->is_smtp = session->is_smtp;
 #if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
 	if (session->ssl_type == SSL_TUNNEL) {
 		sock_set_nonblocking_mode(sock, FALSE);
@@ -236,10 +240,16 @@ void session_set_timeout(Session *session, guint interval)
 		g_source_remove(session->timeout_tag);
 
 	session->timeout_interval = interval;
-	if (interval > 0)
+	if (interval > 0) {
+#if GLIB_CHECK_VERSION(2,14,0)
+		if (interval % 1000 == 0)
+			session->timeout_tag =
+				g_timeout_add_seconds(interval/1000, session_timeout_cb, session);
+		else
+#endif
 		session->timeout_tag =
 			g_timeout_add(interval, session_timeout_cb, session);
-	else
+	} else
 		session->timeout_tag = 0;
 }
 
