@@ -28,6 +28,7 @@
 #else
 #include <gnutls/gnutls.h>
 #include <gnutls/x509.h>
+#include <gnutls/pkcs12.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #include <string.h>
@@ -259,6 +260,7 @@ static SSLCertificate *ssl_certificate_new_lookup(gnutls_x509_crt x509_cert, gch
 	X509_digest(cert->x509_cert, EVP_md5(), md, &n);
 	cert->fingerprint = readable_fingerprint(md, (int)n);
 #else
+	n = 128;
 	gnutls_x509_crt_get_fingerprint(cert->x509_cert, GNUTLS_DIG_MD5, md, &n);
 	cert->fingerprint = readable_fingerprint(md, (int)n);
 #endif
@@ -266,7 +268,7 @@ static SSLCertificate *ssl_certificate_new_lookup(gnutls_x509_crt x509_cert, gch
 }
 
 #ifdef USE_GNUTLS
-static void i2d_X509_fp(FILE *fp, gnutls_x509_crt x509_cert)
+static void gnutls_i2d_X509_fp(FILE *fp, gnutls_x509_crt x509_cert)
 {
 	char output[10*1024];
 	size_t cert_size = 10*1024;
@@ -281,7 +283,46 @@ static void i2d_X509_fp(FILE *fp, gnutls_x509_crt x509_cert)
 		g_warning("failed to write cert\n");
 	}
 }
-static gnutls_x509_crt d2i_X509_fp(FILE *fp, int unused)
+
+size_t gnutls_i2d_X509(gnutls_x509_crt x509_cert, unsigned char **output)
+{
+	size_t cert_size = 10*1024;
+	int r;
+	
+	if (output == NULL)
+		return 0;
+	
+	*output = malloc(cert_size);
+
+	if ((r = gnutls_x509_crt_export(x509_cert, GNUTLS_X509_FMT_DER, *output, &cert_size)) < 0) {
+		g_warning("couldn't export cert %s (%d)\n", gnutls_strerror(r), cert_size);
+		free(*output);
+		*output = NULL;
+		return 0;
+	}
+	return cert_size;
+}
+
+size_t gnutls_i2d_PrivateKey(gnutls_x509_privkey pkey, unsigned char **output)
+{
+	size_t key_size = 10*1024;
+	int r;
+	
+	if (output == NULL)
+		return 0;
+	
+	*output = malloc(key_size);
+
+	if ((r = gnutls_x509_privkey_export(pkey, GNUTLS_X509_FMT_DER, *output, &key_size)) < 0) {
+		g_warning("couldn't export key %s (%d)\n", gnutls_strerror(r), key_size);
+		free(*output);
+		*output = NULL;
+		return 0;
+	}
+	return key_size;
+}
+
+static gnutls_x509_crt gnutls_d2i_X509_fp(FILE *fp, int format)
 {
 	gnutls_x509_crt cert = NULL;
 	gnutls_datum tmp;
@@ -296,18 +337,82 @@ static gnutls_x509_crt d2i_X509_fp(FILE *fp, int unused)
 	tmp.size = s.st_size;
 	if (fread (tmp.data, 1, s.st_size, fp) < s.st_size) {
 		perror("fread");
+		free(tmp.data);
 		return NULL;
 	}
 
 	gnutls_x509_crt_init(&cert);
-	if ((r = gnutls_x509_crt_import(cert, &tmp, GNUTLS_X509_FMT_DER)) < 0) {
-		g_warning("import failed: %s\n", gnutls_strerror(r));
+	if ((r = gnutls_x509_crt_import(cert, &tmp, (format == 0)?GNUTLS_X509_FMT_DER:GNUTLS_X509_FMT_PEM)) < 0) {
+		debug_print("cert import failed: %s\n", gnutls_strerror(r));
 		gnutls_x509_crt_deinit(cert);
 		cert = NULL;
 	}
+	free(tmp.data);
 	debug_print("got cert! %p\n", cert);
 	return cert;
 }
+
+static gnutls_x509_privkey gnutls_d2i_key_fp(FILE *fp, int format)
+{
+	gnutls_x509_privkey key = NULL;
+	gnutls_datum tmp;
+	struct stat s;
+	int r;
+	if (fstat(fileno(fp), &s) < 0) {
+		perror("fstat");
+		return NULL;
+	}
+	tmp.data = malloc(s.st_size);
+	memset(tmp.data, 0, s.st_size);
+	tmp.size = s.st_size;
+	if (fread (tmp.data, 1, s.st_size, fp) < s.st_size) {
+		perror("fread");
+		free(tmp.data);
+		return NULL;
+	}
+
+	gnutls_x509_privkey_init(&key);
+	if ((r = gnutls_x509_privkey_import(key, &tmp, (format == 0)?GNUTLS_X509_FMT_DER:GNUTLS_X509_FMT_PEM)) < 0) {
+		debug_print("key import failed: %s\n", gnutls_strerror(r));
+		gnutls_x509_privkey_deinit(key);
+		key = NULL;
+	}
+	free(tmp.data);
+	debug_print("got key! %p\n", key);
+	return key;
+}
+
+static gnutls_pkcs12_t gnutls_d2i_PKCS12_fp(FILE *fp, int format)
+{
+	gnutls_pkcs12_t p12 = NULL;
+	gnutls_datum tmp;
+	struct stat s;
+	int r;
+	if (fstat(fileno(fp), &s) < 0) {
+		perror("fstat");
+		return NULL;
+	}
+	tmp.data = malloc(s.st_size);
+	memset(tmp.data, 0, s.st_size);
+	tmp.size = s.st_size;
+	if (fread (tmp.data, 1, s.st_size, fp) < s.st_size) {
+		perror("fread");
+		free(tmp.data);
+		return NULL;
+	}
+
+	gnutls_pkcs12_init(&p12);
+
+	if ((r = gnutls_pkcs12_import(p12, &tmp, (format == 0)?GNUTLS_X509_FMT_DER:GNUTLS_X509_FMT_PEM,0)) < 0) {
+		g_warning("p12 import failed: %s\n", gnutls_strerror(r));
+		gnutls_pkcs12_deinit(p12);
+		p12 = NULL;
+	}
+	free(tmp.data);
+	debug_print("got p12! %p\n", p12);
+	return p12;
+}
+
 #endif
 
 static void ssl_certificate_save (SSLCertificate *cert)
@@ -332,7 +437,11 @@ static void ssl_certificate_save (SSLCertificate *cert)
 		debug_print("Can't save certificate !\n");
 		return;
 	}
+#ifdef USE_GNUTLS
+	gnutls_i2d_X509_fp(fp, cert->x509_cert);
+#else
 	i2d_X509_fp(fp, cert->x509_cert);
+#endif
 	g_free(file);
 	fclose(fp);
 
@@ -417,7 +526,11 @@ SSLCertificate *ssl_certificate_find_lookup (gchar *host, gushort port, const gc
 		return NULL;
 	}
 	
+#if USE_OPENSSL
 	if ((tmp_x509 = d2i_X509_fp(fp, 0)) != NULL) {
+#else
+	if ((tmp_x509 = gnutls_d2i_X509_fp(fp, 0)) != NULL) {
+#endif
 		cert = ssl_certificate_new_lookup(tmp_x509, fqdn_host, port, lookup);
 		debug_print("got cert %p\n", cert);
 #if USE_OPENSSL
@@ -477,20 +590,30 @@ static gboolean ssl_certificate_compare (SSLCertificate *cert_a, SSLCertificate
 	output_b = malloc(cert_size_b);
 	if ((r = gnutls_x509_crt_export(cert_a->x509_cert, GNUTLS_X509_FMT_DER, output_a, &cert_size_a)) < 0) {
 		g_warning("couldn't gnutls_x509_crt_export a %s\n", gnutls_strerror(r));
+		g_free(output_a);
+		g_free(output_b);
 		return FALSE;
 	}
 	if ((r = gnutls_x509_crt_export(cert_b->x509_cert, GNUTLS_X509_FMT_DER, output_b, &cert_size_b)) < 0) {
 		g_warning("couldn't gnutls_x509_crt_export b %s\n", gnutls_strerror(r));
+		g_free(output_a);
+		g_free(output_b);
 		return FALSE;
 	}
 	if (cert_size_a != cert_size_b) {
 		g_warning("size differ %d %d\n", cert_size_a, cert_size_b);
+		g_free(output_a);
+		g_free(output_b);
 		return FALSE;
 	}
 	if (memcmp(output_a, output_b, cert_size_a)) {
 		g_warning("contents differ\n");
+		g_free(output_a);
+		g_free(output_b);
 		return FALSE;
 	}
+	g_free(output_a);
+	g_free(output_b);
 	
 	return TRUE;
 #endif
@@ -500,19 +623,14 @@ static gboolean ssl_certificate_compare (SSLCertificate *cert_a, SSLCertificate
 char *ssl_certificate_check_signer (X509 *cert) 
 {
 	X509_STORE_CTX store_ctx;
-	X509_STORE *store;
+	X509_STORE *store = SSL_CTX_get_cert_store(ssl_get_ctx());
 	char *err_msg = NULL;
 
-	store = X509_STORE_new();
 	if (store == NULL) {
 		g_print("Can't create X509_STORE\n");
 		return NULL;
 	}
-	if (!X509_STORE_set_default_paths(store)) {
-		X509_STORE_free (store);
-		return g_strdup(_("Couldn't load X509 default paths"));
-	}
-	
+
 	X509_STORE_CTX_init (&store_ctx, store, cert, NULL);
 
 	if(!X509_verify_cert (&store_ctx)) {
@@ -520,12 +638,10 @@ char *ssl_certificate_check_signer (X509 *cert)
 					X509_STORE_CTX_get_error(&store_ctx)));
 		debug_print("Can't check signer: %s\n", err_msg);
 		X509_STORE_CTX_cleanup (&store_ctx);
-		X509_STORE_free (store);
 		return err_msg;
 			
 	}
 	X509_STORE_CTX_cleanup (&store_ctx);
-	X509_STORE_free (store);
 	return NULL;
 }
 #else
@@ -675,4 +791,276 @@ gboolean ssl_certificate_check (gnutls_x509_crt x509_cert, guint status, gchar *
 	return TRUE;
 }
 
+#if USE_OPENSSL
+X509 *ssl_certificate_get_x509_from_pem_file(const gchar *file)
+{
+	X509 *x509 = NULL;
+	if (!file)
+		return NULL;
+	if (is_file_exist(file)) {
+		FILE *fp = g_fopen(file, "r");
+		if (fp) {
+			x509 = PEM_read_X509(fp, NULL, NULL, NULL);
+			fclose(fp);
+			return x509;
+		}
+	} else {
+		log_error(LOG_PROTOCOL, "Can not open certificate file %s\n", file);
+	}
+	return NULL;
+}
+
+static int ssl_pkey_password_cb(char *buf, int max_len, int flag, void *pwd)
+{
+	return 0;
+}
+
+EVP_PKEY *ssl_certificate_get_pkey_from_pem_file(const gchar *file)
+{
+	EVP_PKEY *pkey = NULL;
+	if (!file)
+		return NULL;
+	if (is_file_exist(file)) {
+		FILE *fp = g_fopen(file, "r");
+		if (fp) {
+			pkey = PEM_read_PrivateKey(fp, NULL, ssl_pkey_password_cb, NULL);
+			fclose(fp);
+			return pkey;
+		}
+	} else {
+		log_error(LOG_PROTOCOL, "Can not open private key file %s\n", file);
+	}
+	return NULL;
+}
+
+void ssl_certificate_get_x509_and_pkey_from_p12_file(const gchar *file, const gchar *password,
+			X509 **x509, EVP_PKEY **pkey)
+{
+	PKCS12 *p12 = NULL;
+	*x509 = NULL;
+	*pkey = NULL;
+
+	if (!file)
+		return;
+
+	if (is_file_exist(file)) {
+		FILE *fp = g_fopen(file, "r");
+		if (fp) {
+			p12 = d2i_PKCS12_fp(fp, NULL);
+			fclose(fp);
+		}
+	} else {
+		log_error(LOG_PROTOCOL, "Can not open certificate file %s\n", file);
+	}
+	if (p12 != NULL) {
+		if (PKCS12_parse(p12, password, pkey, x509, NULL) == 1) {
+			/* we got the correct password */
+		} else {
+			gchar *tmp = NULL;
+			hooks_invoke(SSL_CERT_GET_PASSWORD, &tmp);
+			if (PKCS12_parse(p12, tmp, pkey, x509, NULL) == 1) {
+				debug_print("got p12\n");
+			} else {
+				log_error(LOG_PROTOCOL, "%s\n", ERR_error_string(ERR_get_error(),NULL));
+			}
+		}
+		PKCS12_free(p12);
+	}
+}
+#endif
+
+#ifdef USE_GNUTLS
+gnutls_x509_crt ssl_certificate_get_x509_from_pem_file(const gchar *file)
+{
+	gnutls_x509_crt x509 = NULL;
+	if (!file)
+		return NULL;
+	
+	if (is_file_exist(file)) {
+		FILE *fp = g_fopen(file, "r");
+		if (fp) {
+			x509 = gnutls_d2i_X509_fp(fp, 1);
+			fclose(fp);
+			return x509;
+		}
+	} else {
+		log_error(LOG_PROTOCOL, "Can not open certificate file %s\n", file);
+	}
+	return NULL;
+}
+
+gnutls_x509_privkey ssl_certificate_get_pkey_from_pem_file(const gchar *file)
+{
+	gnutls_x509_privkey key = NULL;
+	if (!file)
+		return NULL;
+	
+	if (is_file_exist(file)) {
+		FILE *fp = g_fopen(file, "r");
+		if (fp) {
+			key = gnutls_d2i_key_fp(fp, 1);
+			fclose(fp);
+			return key;
+		}
+	} else {
+		log_error(LOG_PROTOCOL, "Can not open key file %s\n", file);
+	}
+	return NULL;
+}
+
+/* From GnuTLS lib/gnutls_x509.c */
+static int
+parse_pkcs12 (gnutls_pkcs12_t p12,
+	      const char *password,
+	      gnutls_x509_privkey * key,
+	      gnutls_x509_crt_t * cert)
+{
+  gnutls_pkcs12_bag bag = NULL;
+  int index = 0;
+  int ret;
+
+  for (;;)
+    {
+      int elements_in_bag;
+      int i;
+
+      ret = gnutls_pkcs12_bag_init (&bag);
+      if (ret < 0)
+	{
+	  bag = NULL;
+	  goto done;
+	}
+
+      ret = gnutls_pkcs12_get_bag (p12, index, bag);
+      if (ret == GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE)
+	break;
+      if (ret < 0)
+	{
+	  goto done;
+	}
+
+      ret = gnutls_pkcs12_bag_get_type (bag, 0);
+      if (ret < 0)
+	{
+	  goto done;
+	}
+
+      if (ret == GNUTLS_BAG_ENCRYPTED)
+	{
+	  ret = gnutls_pkcs12_bag_decrypt (bag, password);
+	  if (ret < 0)
+	    {
+	      goto done;
+	    }
+	}
+
+      elements_in_bag = gnutls_pkcs12_bag_get_count (bag);
+      if (elements_in_bag < 0)
+	{
+	  goto done;
+	}
+
+      for (i = 0; i < elements_in_bag; i++)
+	{
+	  int type;
+	  gnutls_datum data;
+
+	  type = gnutls_pkcs12_bag_get_type (bag, i);
+	  if (type < 0)
+	    {
+	      goto done;
+	    }
+
+	  ret = gnutls_pkcs12_bag_get_data (bag, i, &data);
+	  if (ret < 0)
+	    {
+	      goto done;
+	    }
+
+	  switch (type)
+	    {
+	    case GNUTLS_BAG_PKCS8_ENCRYPTED_KEY:
+	    case GNUTLS_BAG_PKCS8_KEY:
+	      ret = gnutls_x509_privkey_init (key);
+	      if (ret < 0)
+		{
+		  goto done;
+		}
+
+	      ret = gnutls_x509_privkey_import_pkcs8
+		(*key, &data, GNUTLS_X509_FMT_DER, password,
+		 type == GNUTLS_BAG_PKCS8_KEY ? GNUTLS_PKCS_PLAIN : 0);
+	      if (ret < 0)
+		{
+		  goto done;
+		}
+	      break;
+
+	    case GNUTLS_BAG_CERTIFICATE:
+	      ret = gnutls_x509_crt_init (cert);
+	      if (ret < 0)
+		{
+		  goto done;
+		}
+
+	      ret =
+		gnutls_x509_crt_import (*cert, &data, GNUTLS_X509_FMT_DER);
+	      if (ret < 0)
+		{
+		  goto done;
+		}
+	      break;
+
+	    case GNUTLS_BAG_ENCRYPTED:
+	      /* XXX Bother to recurse one level down?  Unlikely to
+	         use the same password anyway. */
+	    case GNUTLS_BAG_EMPTY:
+	    default:
+	      break;
+	    }
+	}
+
+      index++;
+      gnutls_pkcs12_bag_deinit (bag);
+    }
+
+  ret = 0;
+
+done:
+  if (bag)
+    gnutls_pkcs12_bag_deinit (bag);
+
+  return ret;
+}
+void ssl_certificate_get_x509_and_pkey_from_p12_file(const gchar *file, const gchar *password,
+			gnutls_x509_crt *x509, gnutls_x509_privkey *pkey)
+{
+	gnutls_pkcs12_t p12 = NULL;
+
+	int r;
+
+	*x509 = NULL;
+	*pkey = NULL;
+	if (!file)
+		return;
+
+	if (is_file_exist(file)) {
+		FILE *fp = g_fopen(file, "r");
+		if (fp) {
+			p12 = gnutls_d2i_PKCS12_fp(fp, 0);
+			fclose(fp);
+		}
+	} else {
+		log_error(LOG_PROTOCOL, "Can not open certificate file %s\n", file);
+	}
+	if (p12 != NULL) {
+		if ((r = parse_pkcs12(p12, password, pkey, x509)) == 0) {
+			debug_print("got p12\n");
+		} else {
+			log_error(LOG_PROTOCOL, "%s\n", gnutls_strerror(r));
+		}
+		gnutls_pkcs12_deinit(p12);
+	}
+}
+#endif
 #endif /* USE_OPENSSL */
