@@ -116,6 +116,13 @@ static gboolean thread_manager_event(GIOChannel * source,
     GIOCondition condition,
     gpointer data)
 {
+#ifdef G_OS_WIN32
+	gsize bytes_read;
+	gchar ch;
+	
+	if (condition & G_IO_IN)
+		g_io_channel_read_chars(source, &ch, 1, &bytes_read, NULL);
+#endif
 	etpan_thread_manager_loop(thread_manager);
 	
 	return TRUE;
@@ -137,7 +144,11 @@ void nntp_main_init(gboolean skip_ssl_cert_check)
 	
 	fd_thread_manager = etpan_thread_manager_get_fd(thread_manager);
 	
+#ifndef G_OS_WIN32
 	io_channel = g_io_channel_unix_new(fd_thread_manager);
+#else
+	io_channel = g_io_channel_win32_new_fd(fd_thread_manager);
+#endif
 	
 	thread_manager_signal = g_io_add_watch_full(io_channel, 0, G_IO_IN,
 						    thread_manager_event,
@@ -290,6 +301,7 @@ static void threaded_run(Folder * folder, void * param, void * result,
 
 struct connect_param {
 	newsnntp * nntp;
+	PrefsAccount *account;
 	const char * server;
 	int port;
 };
@@ -409,6 +421,60 @@ static int etpan_certificate_check(const unsigned char *certificate, int len, vo
 	return 0;
 }
 
+static void connect_ssl_context_cb(struct mailstream_ssl_context * ssl_context, void * data)
+{
+#if (defined(USE_OPENSSL) || defined(USE_GNUTLS))
+	PrefsAccount *account = (PrefsAccount *)data;
+	const gchar *cert_path = NULL;
+	const gchar *password = NULL;
+#ifdef USE_OPENSSL
+	X509 *x509 = NULL;
+	EVP_PKEY *pkey = NULL;
+#else
+	gnutls_x509_crt x509 = NULL;
+	gnutls_x509_privkey pkey = NULL;
+#endif
+
+	if (account->in_ssl_client_cert_file && *account->in_ssl_client_cert_file)
+		cert_path = account->in_ssl_client_cert_file;
+	if (account->in_ssl_client_cert_pass && *account->in_ssl_client_cert_pass)
+		password = account->in_ssl_client_cert_pass;
+	
+	if (mailstream_ssl_set_client_certificate_data(ssl_context, NULL, 0) < 0 ||
+	    mailstream_ssl_set_client_private_key_data(ssl_context, NULL, 0) < 0)
+		debug_print("Impossible to set the client certificate.\n");
+	x509 = ssl_certificate_get_x509_from_pem_file(cert_path);
+	pkey = ssl_certificate_get_pkey_from_pem_file(cert_path);
+	if (!(x509 && pkey)) {
+		/* try pkcs12 format */
+		ssl_certificate_get_x509_and_pkey_from_p12_file(cert_path, password, &x509, &pkey);
+	}
+	if (x509 && pkey) {
+		unsigned char *x509_der = NULL, *pkey_der = NULL;
+		size_t x509_len, pkey_len;
+		
+#ifndef USE_GNUTLS
+		x509_len = (size_t)i2d_X509(x509, &x509_der);
+		pkey_len = (size_t)i2d_PrivateKey(pkey, &pkey_der);
+#else
+		x509_len = (size_t)gnutls_i2d_X509(x509, &x509_der);
+		pkey_len = (size_t)gnutls_i2d_PrivateKey(pkey, &pkey_der);
+#endif
+		if (x509_len > 0 && pkey_len > 0) {
+			if (mailstream_ssl_set_client_certificate_data(ssl_context, x509_der, x509_len) < 0 ||
+			    mailstream_ssl_set_client_private_key_data(ssl_context, pkey_der, pkey_len) < 0) 
+				log_error(LOG_PROTOCOL, "Impossible to set the client certificate.\n");
+			g_free(x509_der);
+			g_free(pkey_der);
+		}
+#ifdef USE_GNUTLS
+		gnutls_x509_crt_deinit(x509);
+		gnutls_x509_privkey_deinit(pkey);
+#endif
+	}
+#endif
+}
+
 static void connect_ssl_run(struct etpan_thread_op * op)
 {
 	int r;
@@ -420,8 +486,9 @@ static void connect_ssl_run(struct etpan_thread_op * op)
 	
 	CHECK_NNTP();
 
-	r = newsnntp_ssl_connect(param->nntp,
-				 param->server, param->port);
+	r = newsnntp_ssl_connect_with_callback(param->nntp,
+				 param->server, param->port,
+				 connect_ssl_context_cb, param->account);
 	result->error = r;
 }
 
@@ -453,7 +520,8 @@ int nntp_threaded_connect_ssl(Folder * folder, const char * server, int port)
 	param.nntp = nntp;
 	param.server = server;
 	param.port = port;
-	
+	param.account = folder->account;
+
 	refresh_resolvers();
 	threaded_run(folder, &param, &result, connect_ssl_run);
 
