@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * 
  */
 
 /*
@@ -30,12 +30,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkbutton.h>
+#include <gtk/gtk.h>
 
 #include "gtkutils.h"
 #include "prefs_common.h"
@@ -310,8 +305,8 @@ static void export_html_next( GtkWidget *widget ) {
 static void export_html_browse( GtkWidget *widget, gpointer data ) {
 	gchar *uri;
 
-	uri = g_strconcat( "file://", _exportCtl_->path, NULL );
-	open_uri( uri, prefs_common.uri_cmd );
+	uri = g_filename_to_uri(_exportCtl_->path, NULL, NULL);
+	open_uri( uri, prefs_common_get_uri_cmd() );
 	g_free( uri );
 }
 
