@@ -27,6 +27,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 
 #include "colorlabel.h"
 #include "utils.h"
@@ -328,12 +329,19 @@ GtkWidget *colorlabel_create_check_color_menu_item(gint color_index, gboolean fo
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 4);
 	if (color_index < 9) {
-		accel = g_strdup_printf(gettext("Ctrl+%c"), '1'+color_index);
+		accel = gtk_accelerator_get_label(GDK_1+color_index, GDK_CONTROL_MASK);
 		label = gtk_label_new(accel);
 		gtk_widget_show(label);
 		gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
 		g_free(accel);
 		gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 4);
+		g_object_set_data(G_OBJECT(item), "accel_label", label);
+	} else {
+		label = gtk_label_new("");
+		gtk_widget_show(label);
+		gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
+		gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 4);
+		g_object_set_data(G_OBJECT(item), "accel_label", label);
 	}
 	return item;
 }
