@@ -24,16 +24,11 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenubar.h>
-#include <gtk/gtkcheckmenuitem.h>
-#include <gtk/gtkitemfactory.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkwindow.h>
 
+#include "gtkcmoptionmenu.h"
 #include "menu.h"
 #include "utils.h"
+#include "gtkutils.h"
 
 #ifdef MAEMO
 #ifdef CHINOOK
@@ -41,45 +36,30 @@
 #else
 #include <hildon-widgets/hildon-program.h>
 #endif
-#include <gtk/gtkmain.h>
 #endif
 
+#if 0 /* FIXME */
 static void connect_accel_change_signals(GtkWidget* widget, GtkWidget *wid2) ;
+#endif
 
-
-GtkWidget *menubar_create(GtkWidget *window, GtkItemFactoryEntry *entries,
-			  guint n_entries, const gchar *path, gpointer data)
+GtkActionGroup *cm_menu_create_action_group(const gchar *name, GtkActionEntry *entries,
+					    gint num_entries, gpointer data)
 {
-	GtkItemFactory *factory;
-	GtkWidget *menubar;
-	
-#ifdef MAEMO
-	factory = gtk_item_factory_new(GTK_TYPE_MENU, path, NULL);
-#else
-	factory = gtk_item_factory_new(GTK_TYPE_MENU_BAR, path, NULL);
-#endif
-	gtk_item_factory_set_translate_func(factory, menu_translate,
-					    NULL, NULL);
-	gtk_item_factory_create_items(factory, n_entries, entries, data);
-	gtk_window_add_accel_group (GTK_WINDOW (window), factory->accel_group);
-
-	menubar  = gtk_item_factory_get_widget(factory, path);
-#ifdef MAEMO
-	hildon_window_set_menu(HILDON_WINDOW(window), GTK_MENU(menubar));
-#endif
-	return menubar;
+	GtkActionGroup *group = gtk_action_group_new(name);
+	gtk_action_group_set_translate_func(group, menu_translate, NULL, NULL);
+	gtk_action_group_add_actions(group, entries, num_entries, data);
+	gtk_ui_manager_insert_action_group(gtkut_ui_manager(), group, 0);
+	return group;
 }
 
-GtkWidget *menu_create_items(GtkItemFactoryEntry *entries,
-			     guint n_entries, const gchar *path,
-			     GtkItemFactory **factory, gpointer data)
+GtkActionGroup *cm_menu_create_action_group_full(GtkUIManager *manager, const gchar *name, GtkActionEntry *entries,
+					    gint num_entries, gpointer data)
 {
-	*factory = gtk_item_factory_new(GTK_TYPE_MENU, path, NULL);
-	gtk_item_factory_set_translate_func(*factory, menu_translate,
-					    NULL, NULL);
-	gtk_item_factory_create_items(*factory, n_entries, entries, data);
-
-	return gtk_item_factory_get_widget(*factory, path);
+	GtkActionGroup *group = gtk_action_group_new(name);
+	gtk_action_group_set_translate_func(group, menu_translate, NULL, NULL);
+	gtk_action_group_add_actions(group, entries, num_entries, data);
+	gtk_ui_manager_insert_action_group(manager, group, 0);
+	return group;
 }
 
 gchar *menu_translate(const gchar *path, gpointer data)
@@ -91,17 +71,58 @@ gchar *menu_translate(const gchar *path, gpointer data)
 	return retval;
 }
 
-void menu_set_sensitive(GtkItemFactory *ifactory, const gchar *path,
-			gboolean sensitive)
+void cm_menu_set_sensitive(gchar *menu, gboolean sensitive)
+{
+	GtkUIManager *gui_manager = gtkut_ui_manager();
+	gchar *path = g_strdup_printf("Menus/%s", menu);
+
+	cm_menu_set_sensitive_full(gui_manager, path, sensitive);
+	g_free(path);
+}
+
+void cm_toggle_menu_set_active(gchar *menu, gboolean active)
+{
+	GtkUIManager *gui_manager = gtkut_ui_manager();
+	gchar *path = g_strdup_printf("Menus/%s", menu);
+
+	cm_toggle_menu_set_active_full(gui_manager, path, active);
+	g_free(path);
+}
+
+void cm_menu_set_sensitive_full(GtkUIManager *gui_manager, gchar *menu, gboolean sensitive)
 {
 	GtkWidget *widget;
+	gchar *path = g_strdup_printf("/%s/", menu);
 
-	g_return_if_fail(ifactory != NULL);
+	widget = gtk_ui_manager_get_widget(gui_manager, path);
+	if( !GTK_IS_WIDGET(widget) ) {
+		g_message("Blah, '%s' is not a widget.\n", path);
+	}
 
-	widget = gtk_item_factory_get_item(ifactory, path);
-	g_return_if_fail(widget != NULL);
+	if( !GTK_IS_MENU_ITEM(widget) ) {
+		g_message("Blah, '%s' is not a menu item.\n", path);
+	}
 
 	gtk_widget_set_sensitive(widget, sensitive);
+	g_free(path);
+}
+
+void cm_toggle_menu_set_active_full(GtkUIManager *gui_manager, gchar *menu, gboolean active)
+{
+	GtkWidget *widget;
+	gchar *path = g_strdup_printf("/%s/", menu);
+
+	widget = gtk_ui_manager_get_widget(gui_manager, path);
+	if( !GTK_IS_WIDGET(widget) ) {
+		g_message("Blah, '%s' is not a widget.\n", path);
+	}
+
+	if( !GTK_CHECK_MENU_ITEM(widget) ) {
+		g_message("Blah, '%s' is not a check menu item.\n", path);
+	}
+
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(widget), active);
+	g_free(path);
 }
 
 void menu_set_sensitive_all(GtkMenuShell *menu_shell, gboolean sensitive)
@@ -112,23 +133,6 @@ void menu_set_sensitive_all(GtkMenuShell *menu_shell, gboolean sensitive)
 		gtk_widget_set_sensitive(GTK_WIDGET(cur->data), sensitive);
 }
 
-void menu_set_active(GtkItemFactory *ifactory, const gchar *path,
-		     gboolean is_active)
-{
-	GtkWidget *widget;
-
-	g_return_if_fail(ifactory != NULL);
-
-	widget = gtk_item_factory_get_item(ifactory, path);
-	g_return_if_fail(widget != NULL);
-
-	if (!GTK_IS_CHECK_MENU_ITEM(widget)) {
-		debug_print("%s not check_menu_item\n", path?path:"(null)");
-		return;
-	}	
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(widget), is_active);
-}
-
 void menu_button_position(GtkMenu *menu, gint *x, gint *y, gboolean *push_in,
 			  gpointer user_data)
 {
@@ -163,7 +167,7 @@ void menu_button_position(GtkMenu *menu, gint *x, gint *y, gboolean *push_in,
 		*y -= mreq.height;
 }
 
-gint menu_find_option_menu_index(GtkOptionMenu *optmenu, gpointer data,
+gint menu_find_option_menu_index(GtkCMOptionMenu *optmenu, gpointer data,
 				 GCompareFunc func)
 {
 	GtkWidget *menu;
@@ -172,7 +176,7 @@ gint menu_find_option_menu_index(GtkOptionMenu *optmenu, gpointer data,
 	GList *cur;
 	gint n;
 
-	menu = gtk_option_menu_get_menu(optmenu);
+	menu = gtk_cmoption_menu_get_menu(optmenu);
 
 	for (cur = GTK_MENU_SHELL(menu)->children, n = 0;
 	     cur != NULL; cur = cur->next, n++) {
@@ -189,18 +193,19 @@ gint menu_find_option_menu_index(GtkOptionMenu *optmenu, gpointer data,
 	return -1;
 }
 
+#if 0
 static void connect_accel_change_signals(GtkWidget* widget, GtkWidget *wid2) 
 {
-#if 0
 	g_signal_connect_after(G_OBJECT(widget), "add_accelerator", 
 			       G_CALLBACK(menu_item_add_accel), wid2);
 	g_signal_connect_after(G_OBJECT(widget), "remove_accelerator", 
 			       G_CALLBACK(menu_item_remove_accel), wid2);
-#endif
 }
+#endif
 
 void menu_connect_identical_items(void)
 {
+#if 0 /* DEPRECATED */
 	gint n;
 	GtkWidget *item1;
 	GtkWidget *item2;
@@ -270,4 +275,5 @@ void menu_connect_identical_items(void)
 			if (!item2) debug_print(" ** Menu item not found: %s\n",pairs[n].path2);
 		}				
 	}
+#endif
 }
