@@ -29,6 +29,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
+#include "gtkcmoptionmenu.h"
 #include "utils.h"
 #include "combobox.h"
 #include "menu.h"
@@ -87,15 +88,15 @@ gboolean quicksearch_is_fast(QuickSearch *quicksearch)
 static void quicksearch_set_type(QuickSearch *quicksearch, gint type)
 {
 	gint index;
-	index = menu_find_option_menu_index(GTK_OPTION_MENU(quicksearch->search_type_opt), 
+	index = menu_find_option_menu_index(GTK_CMOPTION_MENU(quicksearch->search_type_opt), 
 					GINT_TO_POINTER(type),
 					NULL);
-	gtk_option_menu_set_history(GTK_OPTION_MENU(quicksearch->search_type_opt), index);	
+	gtk_cmoption_menu_set_history(GTK_CMOPTION_MENU(quicksearch->search_type_opt), index);	
 }
 
 static gchar *quicksearch_get_text(QuickSearch * quicksearch)
 {
-	gchar *search_string = gtk_editable_get_chars(GTK_EDITABLE(GTK_BIN(quicksearch->search_string_entry)->child), 0, -1);
+	gchar *search_string = gtk_editable_get_chars(GTK_EDITABLE(gtk_bin_get_child(GTK_BIN((quicksearch->search_string_entry)))), 0, -1);
 
 	g_strstrip(search_string);
 	return search_string;
@@ -549,7 +550,7 @@ QuickSearch *quicksearch_new()
 	GtkWidget *clear_search;
 	GtkWidget *search_condition_expression;
 	GtkWidget *menuitem;
-	GtkTooltips *tips = gtk_tooltips_new();
+	CLAWS_TIP_DECL();
 	GtkWidget *vbox;
 
 	quicksearch = g_new0(QuickSearch, 1);
@@ -557,7 +558,7 @@ QuickSearch *quicksearch_new()
 	/* quick search */
 	hbox_search = gtk_hbox_new(FALSE, 0);
 
-	search_type_opt = gtk_option_menu_new();
+	search_type_opt = gtk_cmoption_menu_new();
 	gtk_widget_show(search_type_opt);
 	gtk_box_pack_start(GTK_BOX(hbox_search), search_type_opt, FALSE, FALSE, 0);
 
@@ -638,7 +639,7 @@ QuickSearch *quicksearch_new()
 			 G_CALLBACK(searchtype_autorun_changed),
 			 quicksearch);
 
-	gtk_option_menu_set_menu(GTK_OPTION_MENU(search_type_opt), search_type);
+	gtk_cmoption_menu_set_menu(GTK_CMOPTION_MENU(search_type_opt), search_type);
 
 	quicksearch->search_type_opt = search_type_opt;
 	quicksearch_set_type(quicksearch, prefs_common.summary_quicksearch_type);
@@ -669,9 +670,8 @@ QuickSearch *quicksearch_new()
 			   FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(clear_search), "clicked",
 			 G_CALLBACK(clear_search_cb), quicksearch);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tips),
-			     clear_search,
-			     _("Clear the current search"), NULL);
+	CLAWS_SET_TIP(clear_search,
+			     _("Clear the current search"));
 	gtk_widget_show(clear_search);
 
 #if GTK_CHECK_VERSION(2, 8, 0)
@@ -684,9 +684,8 @@ QuickSearch *quicksearch_new()
 	g_signal_connect(G_OBJECT (search_condition_expression), "clicked",
 			 G_CALLBACK(search_condition_expr),
 			 quicksearch);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tips),
-			     search_condition_expression,
-			     _("Edit search criteria"), NULL);
+	CLAWS_SET_TIP(search_condition_expression,
+			     _("Edit search criteria"));
 	gtk_widget_show(search_condition_expression);
 
 #if GTK_CHECK_VERSION(2, 8, 0)
@@ -698,29 +697,28 @@ QuickSearch *quicksearch_new()
 			   FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(search_description), "clicked",
 			 G_CALLBACK(search_description_cb), NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tips),
-			     search_description,
-			     _("Information about extended symbols"), NULL);
+	CLAWS_SET_TIP(search_description,
+			     _("Information about extended symbols"));
 	gtk_widget_show(search_description);
 
 	gtk_box_pack_start(GTK_BOX(hbox_search), search_hbox, FALSE, FALSE, 2);
 	gtk_widget_show(search_hbox);
 
-	g_signal_connect(G_OBJECT(GTK_BIN(search_string_entry)->child),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN((search_string_entry)))),
 			   "key_press_event",
 			   G_CALLBACK(searchbar_pressed),
 			   quicksearch);
 
-	g_signal_connect(G_OBJECT(GTK_BIN(search_string_entry)->child),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN((search_string_entry)))),
 			 "changed",
 			 G_CALLBACK(searchbar_changed_cb),
 			 quicksearch);
 
-	g_signal_connect(G_OBJECT(GTK_BIN(search_string_entry)->child),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN((search_string_entry)))),
 			 "focus_in_event",
 			 G_CALLBACK(searchbar_focus_evt_in),
 			 quicksearch);
-	g_signal_connect(G_OBJECT(GTK_BIN(search_string_entry)->child),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN((search_string_entry)))),
 			 "focus_out_event",
 			 G_CALLBACK(searchbar_focus_evt_out),
 			 quicksearch);
@@ -792,7 +790,7 @@ void quicksearch_show(QuickSearch *quicksearch)
 	gtk_widget_show(quicksearch->hbox_search);
 	update_extended_buttons(quicksearch);
 	gtk_widget_grab_focus(
-		GTK_WIDGET(GTK_BIN(quicksearch->search_string_entry)->child));
+		GTK_WIDGET(gtk_bin_get_child(GTK_BIN((quicksearch->search_string_entry)))));
 
 	GTK_EVENTS_FLUSH();
 
@@ -803,7 +801,7 @@ void quicksearch_show(QuickSearch *quicksearch)
 	ctree = summary_get_main_widget(mainwin->summaryview);
 	
 	if (ctree && mainwin->summaryview->selected)
-		gtk_ctree_node_moveto(GTK_CTREE(ctree), 
+		gtk_cmctree_node_moveto(GTK_CMCTREE(ctree), 
 				mainwin->summaryview->selected, 
 				0, 0.5, 0);
 }
@@ -825,11 +823,11 @@ void quicksearch_set(QuickSearch *quicksearch, QuickSearchType type,
 	if (!matchstring || !(*matchstring))
 		quicksearch->in_typing = FALSE;
 
-	g_signal_handlers_block_by_func(G_OBJECT(GTK_BIN(quicksearch->search_string_entry)->child),
+	g_signal_handlers_block_by_func(G_OBJECT(gtk_bin_get_child(GTK_BIN((quicksearch->search_string_entry)))),
 			G_CALLBACK(searchbar_changed_cb), quicksearch);
-	gtk_entry_set_text(GTK_ENTRY(GTK_BIN(quicksearch->search_string_entry)->child),
+	gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN((quicksearch->search_string_entry)))),
 			   matchstring);
-	g_signal_handlers_unblock_by_func(G_OBJECT(GTK_BIN(quicksearch->search_string_entry)->child),
+	g_signal_handlers_unblock_by_func(G_OBJECT(gtk_bin_get_child(GTK_BIN((quicksearch->search_string_entry)))),
 			G_CALLBACK(searchbar_changed_cb), quicksearch);
 
 	prefs_common.summary_quicksearch_type = type;
@@ -880,20 +878,20 @@ static void quicksearch_set_active(QuickSearch *quicksearch, gboolean active)
 		gtk_widget_set_sensitive(quicksearch->clear_search, TRUE);
 		if (colors_initialised) {
 			gtk_widget_modify_base(
-				GTK_BIN(quicksearch->search_string_entry)->child,
+				gtk_bin_get_child(GTK_BIN((quicksearch->search_string_entry))),
 				GTK_STATE_NORMAL, error ? &red : &yellow);
 			gtk_widget_modify_text(
-				GTK_BIN(quicksearch->search_string_entry)->child,
+				gtk_bin_get_child(GTK_BIN((quicksearch->search_string_entry))),
 				GTK_STATE_NORMAL, &black);
 		}
 	} else {
 		gtk_widget_set_sensitive(quicksearch->clear_search, FALSE);
 		if (colors_initialised) {
 			gtk_widget_modify_base(
-				GTK_BIN(quicksearch->search_string_entry)->child,
+				gtk_bin_get_child(GTK_BIN((quicksearch->search_string_entry))),
 				GTK_STATE_NORMAL, NULL);
 			gtk_widget_modify_text(
-				GTK_BIN(quicksearch->search_string_entry)->child,
+				gtk_bin_get_child(GTK_BIN((quicksearch->search_string_entry))),
 				GTK_STATE_NORMAL, NULL);
 		}
 	}
@@ -1202,7 +1200,7 @@ gboolean quicksearch_is_running(QuickSearch *quicksearch)
 
 void quicksearch_pass_key(QuickSearch *quicksearch, guint val, GdkModifierType mod)
 {
-	GtkEntry *entry = GTK_ENTRY(GTK_BIN(quicksearch->search_string_entry)->child);
+	GtkEntry *entry = GTK_ENTRY(gtk_bin_get_child(GTK_BIN((quicksearch->search_string_entry))));
 	glong curpos = gtk_editable_get_position(GTK_EDITABLE(entry));
 	guint32 c;
 	char *str = g_strdup(gtk_entry_get_text(entry));
