@@ -197,8 +197,11 @@ static GtkWidget *cert_presenter(SSLCertificate *cert)
 #endif	
 
 	memset(buf, 0, sizeof(buf));
-	strftime(buf, sizeof(buf)-1, prefs_common.date_format, localtime_r(&exp_time_t, &lt));
-	exp_date = (*buf) ? g_strdup(buf):g_strdup("?");
+	if (exp_time_t > 0) {
+		strftime(buf, sizeof(buf)-1, prefs_common.date_format, localtime_r(&exp_time_t, &lt));
+		exp_date = (*buf) ? g_strdup(buf):g_strdup("?");
+	} else
+		exp_date = g_strdup("");
 
 	/* fingerprint */
 #if USE_OPENSSL
