@@ -43,66 +43,93 @@
 #include "statusbar.h"
 #include "summaryview.h"
 
-static void new_folder_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void rename_folder_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void move_folder_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void delete_folder_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void update_tree_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void download_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void sync_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void subscribed_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void subscribe_cb(FolderView *folderview, guint action, GtkWidget *widget);
+static void new_folder_cb(GtkAction *action, gpointer data);
+static void rename_folder_cb(GtkAction *action, gpointer data);
+static void move_folder_cb(GtkAction *action, gpointer data);
+static void copy_folder_cb(GtkAction *action, gpointer data);
+static void delete_folder_cb(GtkAction *action, gpointer data);
+static void update_tree_cb(GtkAction *action, gpointer data);
+static void download_cb(GtkAction *action, gpointer data);
+static void sync_cb(GtkAction *action, gpointer data);
+static void subscribed_cb(GtkAction *action, gpointer data);
+static void subscribe_cb(GtkAction *action, gpointer data);
+static void unsubscribe_cb(GtkAction *action, gpointer data);
 
-static GtkItemFactoryEntry imap_popup_entries[] =
+static GtkActionEntry imap_popup_entries[] =
 {
-	{N_("/Create _new folder..."),	 NULL, new_folder_cb,    0, NULL},
-	{"/---",			 NULL, NULL,             0, "<Separator>"},
-	{N_("/_Rename folder..."),	 NULL, rename_folder_cb, 0, NULL},
-	{N_("/M_ove folder..."),	 NULL, move_folder_cb,   0, NULL},
-	{N_("/Cop_y folder..."),	 NULL, move_folder_cb,   1, NULL},
-	{"/---",			 NULL, NULL,             0, "<Separator>"},
-	{N_("/_Delete folder..."),	 NULL, delete_folder_cb, 0, NULL},
-	{"/---",			 NULL, NULL,             0, "<Separator>"},
-	{N_("/_Synchronise"),		 NULL, sync_cb,      	 0, NULL},
-	{N_("/Down_load messages"),	 NULL, download_cb,      0, NULL},
-	{"/---",			 NULL, NULL,             0, "<Separator>"},
-	{N_("/S_ubscriptions"),		 NULL, NULL,		 0, "<Branch>"},
-	{N_("/Subscriptions/Show only subscribed _folders"),    
-					 NULL, subscribed_cb,  	 0, "<ToggleItem>"},
-	{N_("/Subscriptions/---"),	 NULL, NULL,  		 0, "<Separator>"},
-	{N_("/Subscriptions/_Subscribe..."),NULL, subscribe_cb,  	 1, NULL},
-	{N_("/Subscriptions/_Unsubscribe..."),    
-					 NULL, subscribe_cb, 	 0, NULL},
-	{"/---",			 NULL, NULL,             0, "<Separator>"},
-	{N_("/_Check for new messages"), NULL, update_tree_cb,   0, NULL},
-	{N_("/C_heck for new folders"),	 NULL, update_tree_cb,   1, NULL},
-	{N_("/R_ebuild folder tree"),	 NULL, update_tree_cb,   2, NULL},
-	{"/---",			 NULL, NULL, 		 0, "<Separator>"},
+	{"FolderViewPopup/CreateNewFolder",	NULL, N_("Create _new folder..."), NULL, NULL, G_CALLBACK(new_folder_cb) },
+
+	{"FolderViewPopup/RenameFolder",	NULL, N_("_Rename folder..."), NULL, NULL, G_CALLBACK(rename_folder_cb) },
+	{"FolderViewPopup/MoveFolder",		NULL, N_("M_ove folder..."), NULL, NULL, G_CALLBACK(move_folder_cb) },
+	{"FolderViewPopup/CopyFolder",		NULL, N_("Cop_y folder..."), NULL, NULL, G_CALLBACK(copy_folder_cb) },
+
+	{"FolderViewPopup/DeleteFolder",	NULL, N_("_Delete folder..."), NULL, NULL, G_CALLBACK(delete_folder_cb) },
+
+	{"FolderViewPopup/Synchronise",		NULL, N_("Synchronise"), NULL, NULL, G_CALLBACK(sync_cb) },
+	{"FolderViewPopup/DownloadMessages",	NULL, N_("Down_load messages"), NULL, NULL, G_CALLBACK(download_cb) },
+
+
+	{"FolderViewPopup/Subscriptions",	NULL, N_("S_ubscriptions") },
+	{"FolderViewPopup/Subscriptions/---",	NULL, "---", NULL, NULL, NULL }, 
+	{"FolderViewPopup/Subscriptions/Subscribe",	NULL, N_("_Subscribe..."), NULL, NULL, G_CALLBACK(subscribe_cb) },
+	{"FolderViewPopup/Subscriptions/Unsubscribe",	NULL, N_("_Unsubscribe..."), NULL, NULL, G_CALLBACK(unsubscribe_cb) },
+
+	{"FolderViewPopup/CheckNewMessages",	NULL, N_("_Check for new messages"), NULL, NULL, G_CALLBACK(update_tree_cb) }, /*0*/
+	{"FolderViewPopup/CheckNewFolders",	NULL, N_("C_heck for new folders"), NULL, NULL, G_CALLBACK(update_tree_cb) }, /*1*/
+	{"FolderViewPopup/RebuildTree",		NULL, N_("R_ebuild folder tree"), NULL, NULL, G_CALLBACK(update_tree_cb) }, /*2*/
 };
 
-static void set_sensitivity(GtkItemFactory *factory, FolderItem *item);
+static GtkToggleActionEntry imap_toggle_popup_entries[] =
+{
+	{"FolderViewPopup/Subscriptions/ShowOnlySubs",	NULL, N_("Show only subscribed _folders"), NULL, NULL, G_CALLBACK(subscribed_cb) }, 
+};
+
+static void set_sensitivity(GtkUIManager *ui_manager, FolderItem *item);
+static void add_menuitems(GtkUIManager *ui_manager, FolderItem *item);
 
 static FolderViewPopup imap_popup =
 {
 	"imap",
 	"<IMAPFolder>",
-	NULL,
+	imap_popup_entries,
+	G_N_ELEMENTS(imap_popup_entries),
+	imap_toggle_popup_entries,
+	G_N_ELEMENTS(imap_toggle_popup_entries),
+	NULL, 0, 0, NULL,
+	add_menuitems,
 	set_sensitivity
 };
 
 void imap_gtk_init(void)
 {
-	guint i, n_entries;
-
-	n_entries = sizeof(imap_popup_entries) /
-		sizeof(imap_popup_entries[0]);
-	for (i = 0; i < n_entries; i++)
-		imap_popup.entries = g_slist_append(imap_popup.entries, &imap_popup_entries[i]);
-
 	folderview_register_popup(&imap_popup);
 }
 
-static void set_sensitivity(GtkItemFactory *factory, FolderItem *item)
+static void add_menuitems(GtkUIManager *ui_manager, FolderItem *item)
+{
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "CreateNewFolder", "FolderViewPopup/CreateNewFolder", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorIMAP1", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "RenameFolder", "FolderViewPopup/RenameFolder", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "MoveFolder", "FolderViewPopup/MoveFolder", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "CopyFolder", "FolderViewPopup/CopyFolder", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorIMAP2", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "DeleteFolder", "FolderViewPopup/DeleteFolder", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorIMAP3", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "Synchronise", "FolderViewPopup/Synchronise", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "DownloadMessages", "FolderViewPopup/DownloadMessages", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorIMAP4", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "Subscriptions", "FolderViewPopup/Subscriptions", GTK_UI_MANAGER_MENU)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup/Subscriptions", "ShowOnlySubs", "FolderViewPopup/Subscriptions/ShowOnlySubs", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup/Subscriptions", "SeparatorIMAP5", "FolderViewPopup/Subscriptions/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup/Subscriptions", "Subscribe", "FolderViewPopup/Subscriptions/Subscribe", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup/Subscriptions", "Unsubscribe", "FolderViewPopup/Subscriptions/Unsubscribe", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "CheckNewMessages", "FolderViewPopup/CheckNewMessages", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "CheckNewFolders", "FolderViewPopup/CheckNewFolders", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "RebuildTree", "FolderViewPopup/RebuildTree", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorIMAP6", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+}
+
+static void set_sensitivity(GtkUIManager *ui_manager, FolderItem *item)
 {
 	gboolean folder_is_normal = 
 			item != NULL &&
@@ -113,33 +140,40 @@ static void set_sensitivity(GtkItemFactory *factory, FolderItem *item)
 			!folder_has_parent_of_type(item, F_TRASH);
 
 #define SET_SENS(name, sens) \
-	menu_set_sensitive(factory, name, sens)
+	cm_menu_set_sensitive_full(ui_manager, "Popup/"name, sens)
 
-	SET_SENS("/Create new folder...",   item->no_sub == FALSE);
-	SET_SENS("/Rename folder...",       item->stype == F_NORMAL && folder_item_parent(item) != NULL);
-	SET_SENS("/Move folder...", 	    folder_is_normal && folder_item_parent(item) != NULL);
-	SET_SENS("/Delete folder...", 	    item->stype == F_NORMAL && folder_item_parent(item) != NULL);
+	SET_SENS("FolderViewPopup/CreateNewFolder",   item->no_sub == FALSE);
+	SET_SENS("FolderViewPopup/RenameFolder",       item->stype == F_NORMAL && folder_item_parent(item) != NULL);
+	SET_SENS("FolderViewPopup/MoveFolder", 	    folder_is_normal && folder_item_parent(item) != NULL);
+	SET_SENS("FolderViewPopup/DeleteFolder", 	    item->stype == F_NORMAL && folder_item_parent(item) != NULL);
 
-	SET_SENS("/Synchronise",	    item ? (folder_item_parent(item) == NULL && folder_want_synchronise(item->folder))
-						: FALSE);
-	SET_SENS("/Check for new messages", folder_item_parent(item) == NULL);
-	SET_SENS("/Check for new folders",  folder_item_parent(item) == NULL);
-	SET_SENS("/Rebuild folder tree",    folder_item_parent(item) == NULL);
+	SET_SENS("FolderViewPopup/CheckNewMessages", folder_item_parent(item) == NULL);
+	SET_SENS("FolderViewPopup/CheckNewFolders",  folder_item_parent(item) == NULL);
+	SET_SENS("FolderViewPopup/RebuildTree",    folder_item_parent(item) == NULL);
+
+	SET_SENS("FolderViewPopup/Synchronise",    
+			item ? (folder_item_parent(item) != NULL
+			&& folder_want_synchronise(item->folder))
+			: FALSE);
+	SET_SENS("FolderViewPopup/DownloadMessages", !item->no_select);
+
+	SET_SENS("FolderViewPopup/CheckNewMessages", folder_item_parent(item) == NULL);
+	SET_SENS("FolderViewPopup/CheckNewFolders",  folder_item_parent(item) == NULL);
+	SET_SENS("FolderViewPopup/RebuildTree",    folder_item_parent(item) == NULL);
 	
-	SET_SENS("/Subscriptions/Unsubscribe...",    item->stype == F_NORMAL && folder_item_parent(item) != NULL);
-	SET_SENS("/Subscriptions/Subscribe...",    TRUE);
+	SET_SENS("FolderViewPopup/Subscriptions/Unsubscribe",    item->stype == F_NORMAL && folder_item_parent(item) != NULL);
+	SET_SENS("FolderViewPopup/Subscriptions/Subscribe",    TRUE);
 	if (item->folder && item->folder->account)
-		menu_set_active(factory, 
-			"/Subscriptions/Show only subscribed folders", 
+		cm_toggle_menu_set_active_full(ui_manager, "Popup/FolderViewPopup/Subscriptions/ShowOnlySubs",
 			item->folder->account->imap_subsonly);
 
 #undef SET_SENS
 }
 
-static void new_folder_cb(FolderView *folderview, guint action,
-		          GtkWidget *widget)
+static void new_folder_cb(GtkAction *action, gpointer data)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
+	FolderView *folderview = (FolderView *)data;
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 	FolderItem *new_item;
 	gchar *new_folder;
@@ -149,7 +183,7 @@ static void new_folder_cb(FolderView *folderview, guint action,
 	
 	if (!folderview->selected) return;
 
-	item = gtk_ctree_node_get_row_data(ctree, folderview->selected);
+	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
 	g_return_if_fail(item != NULL);
 	g_return_if_fail(item->folder != NULL);
 	g_return_if_fail(item->folder->account != NULL);
@@ -203,9 +237,9 @@ static void new_folder_cb(FolderView *folderview, guint action,
 	folder_write_list();
 }
 
-static void rename_folder_cb(FolderView *folderview, guint action,
-			     GtkWidget *widget)
+static void rename_folder_cb(GtkAction *action, gpointer data)
 {
+	FolderView *folderview = (FolderView *)data;
 	FolderItem *item;
 	gchar *new_folder;
 	gchar *name;
@@ -272,8 +306,9 @@ static void rename_folder_cb(FolderView *folderview, guint action,
 	folder_write_list();
 }
 
-static void move_folder_cb(FolderView *folderview, guint action, GtkWidget *widget)
+static void move_folder_cb(GtkAction *action, gpointer data)
 {
+	FolderView *folderview = (FolderView *)data;
 	FolderItem *from_folder = NULL, *to_folder = NULL;
 
 	from_folder = folderview_get_selected_item(folderview);
@@ -284,13 +319,29 @@ static void move_folder_cb(FolderView *folderview, guint action, GtkWidget *widg
 	if (!to_folder)
 		return;
 	
-	folderview_move_folder(folderview, from_folder, to_folder, action);
+	folderview_move_folder(folderview, from_folder, to_folder, 0);
 }
 
-static void delete_folder_cb(FolderView *folderview, guint action,
-			     GtkWidget *widget)
+static void copy_folder_cb(GtkAction *action, gpointer data)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
+	FolderView *folderview = (FolderView *)data;
+	FolderItem *from_folder = NULL, *to_folder = NULL;
+
+	from_folder = folderview_get_selected_item(folderview);
+	if (!from_folder || from_folder->folder->klass != imap_get_class())
+		return;
+
+	to_folder = foldersel_folder_sel(from_folder->folder, FOLDER_SEL_MOVE, NULL, TRUE);
+	if (!to_folder)
+		return;
+	
+	folderview_move_folder(folderview, from_folder, to_folder, 1);
+}
+
+static void delete_folder_cb(GtkAction *action, gpointer data)
+{
+	FolderView *folderview = (FolderView *)data;
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 	gchar *message, *name;
 	AlertValue avalue;
@@ -299,7 +350,7 @@ static void delete_folder_cb(FolderView *folderview, guint action,
 
 	if (!folderview->selected) return;
 
-	item = gtk_ctree_node_get_row_data(ctree, folderview->selected);
+	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
 	g_return_if_fail(item != NULL);
 	g_return_if_fail(item->path != NULL);
 	g_return_if_fail(item->folder != NULL);
@@ -320,7 +371,7 @@ static void delete_folder_cb(FolderView *folderview, guint action,
 	old_id = folder_item_get_identifier(item);
 
 	if (folderview->opened == folderview->selected ||
-	    gtk_ctree_is_ancestor(ctree,
+	    gtk_cmctree_is_ancestor(ctree,
 				  folderview->selected,
 				  folderview->opened)) {
 		summary_clear_all(folderview->summaryview);
@@ -341,10 +392,13 @@ static void delete_folder_cb(FolderView *folderview, guint action,
 
 }
 
-static void update_tree_cb(FolderView *folderview, guint action,
-			   GtkWidget *widget)
+#define DO_ACTION(name, act)	{ if (!strcmp(a_name, name)) act; }
+
+static void update_tree_cb(GtkAction *action, gpointer data)
 {
+	FolderView *folderview = (FolderView *)data;
 	FolderItem *item;
+	const gchar *a_name = gtk_action_get_name(action);
 
 	item = folderview_get_selected_item(folderview);
 	g_return_if_fail(item != NULL);
@@ -353,17 +407,14 @@ static void update_tree_cb(FolderView *folderview, guint action,
 
 	g_return_if_fail(item->folder != NULL);
 
-	if (action == 0)
-		folderview_check_new(item->folder);
-	else if (action == 1)
-		folderview_rescan_tree(item->folder, FALSE);
-	else if (action == 2)
-		folderview_rescan_tree(item->folder, TRUE);
+	DO_ACTION("FolderViewPopup/CheckNewMessages", folderview_check_new(item->folder));
+	DO_ACTION("FolderViewPopup/CheckNewFolders", folderview_rescan_tree(item->folder, FALSE));
+	DO_ACTION("FolderViewPopup/RebuildTree", folderview_rescan_tree(item->folder, FALSE));
 }
 
-static void sync_cb(FolderView *folderview, guint action,
-			   GtkWidget *widget)
+static void sync_cb(GtkAction *action, gpointer data)
 {
+	FolderView *folderview = (FolderView *)data;
 	FolderItem *item;
 
 	item = folderview_get_selected_item(folderview);
@@ -432,10 +483,9 @@ static gboolean imap_gtk_subscribe_func(GNode *node, gpointer data)
 	return FALSE;
 }
 
-static void subscribe_cb(FolderView *folderview, guint action,
-			   GtkWidget *widget)
+static void subscribe_cb_full(FolderView *folderview, guint action)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 	gchar *message, *name;
 	AlertValue avalue;
@@ -444,7 +494,7 @@ static void subscribe_cb(FolderView *folderview, guint action,
 
 	if (!folderview->selected) return;
 
-	item = gtk_ctree_node_get_row_data(ctree, folderview->selected);
+	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
 	g_return_if_fail(item != NULL);
 	g_return_if_fail(item->folder != NULL);
 
@@ -530,7 +580,7 @@ static void subscribe_cb(FolderView *folderview, guint action,
 	
 	if (!action) {
 		if (folderview->opened == folderview->selected ||
-		    gtk_ctree_is_ancestor(ctree,
+		    gtk_cmctree_is_ancestor(ctree,
 					  folderview->selected,
 					  folderview->opened)) {
 			summary_clear_all(folderview->summaryview);
@@ -549,37 +599,47 @@ static void subscribe_cb(FolderView *folderview, guint action,
 		folderview_fast_rescan_tree(item->folder);
 }
 
-static void subscribed_cb(FolderView *folderview, guint action,
-			   GtkWidget *widget)
+static void subscribe_cb(GtkAction *action, gpointer data)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
-	FolderItem *item = gtk_ctree_node_get_row_data(ctree, folderview->selected);
+	subscribe_cb_full((FolderView *)data, 1);
+}
+
+static void unsubscribe_cb(GtkAction *action, gpointer data)
+{
+	subscribe_cb_full((FolderView *)data, 0);
+}
+
+static void subscribed_cb(GtkAction *action, gpointer data)
+{
+	FolderView *folderview = (FolderView *)data;
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
+	FolderItem *item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
 	
 	if (!item || !item->folder || !item->folder->account)
 		return;
-	if (item->folder->account->imap_subsonly == GTK_CHECK_MENU_ITEM(widget)->active)
+	if (item->folder->account->imap_subsonly == gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
 		return;
 
 	if (folderview->opened == folderview->selected ||
-	    gtk_ctree_is_ancestor(ctree,
+	    gtk_cmctree_is_ancestor(ctree,
 				  folderview->selected,
 				  folderview->opened)) {
 		summary_clear_all(folderview->summaryview);
 		folderview->opened = NULL;
 	}
 
-	item->folder->account->imap_subsonly = GTK_CHECK_MENU_ITEM(widget)->active;
+	item->folder->account->imap_subsonly = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	folderview_fast_rescan_tree(item->folder);
 }
 
-static void download_cb(FolderView *folderview, guint action,
-			GtkWidget *widget)
+static void download_cb(GtkAction *action, gpointer data)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
+	FolderView *folderview = (FolderView *)data;
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 
 	if (!folderview->selected) return;
 
-	item = gtk_ctree_node_get_row_data(ctree, folderview->selected);
+	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
 	imap_gtk_synchronise(item, 0);
 }
