@@ -25,10 +25,7 @@
 
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkprogressbar.h>
+#include <gtk/gtk.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
@@ -168,7 +165,7 @@ static void inc_finished(MainWindow *mainwin, gboolean new_messages, gboolean au
 	if (prefs_common.scan_all_after_inc)
 		folderview_check_new(NULL);
 
-	if (!autocheck && prefs_common.open_inbox_on_inc) {
+	if (!autocheck && new_messages && prefs_common.open_inbox_on_inc) {
 		FolderItem *item = NULL;
 
 		if (cur_account && cur_account->inbox)
@@ -558,9 +555,6 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 		if (pop3_session->ac_prefs->passwd)
 			pop3_session->pass =
 				g_strdup(pop3_session->ac_prefs->passwd);
-		else if (pop3_session->ac_prefs->tmp_pass)
-			pop3_session->pass =
-				g_strdup(pop3_session->ac_prefs->tmp_pass);
 		else {
 			gchar *pass;
 
@@ -569,9 +563,10 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 					(inc_dialog->dialog->window,
 					 NULL, NULL);
 
-			pass = input_dialog_query_password
+			pass = input_dialog_query_password_keep
 				(pop3_session->ac_prefs->recv_server,
-				 pop3_session->user);
+				 pop3_session->user,
+				 &(pop3_session->ac_prefs->session_passwd));
 
 			if (inc_dialog->show_dialog)
 				manage_window_focus_out
@@ -579,8 +574,6 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 					 NULL, NULL);
 
 			if (pass) {
-				pop3_session->ac_prefs->tmp_pass =
-					g_strdup(pass);
 				pop3_session->pass = pass;
 			}
 		}
@@ -638,6 +631,10 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 			break;
 		case INC_AUTH_FAILED:
 			SET_PIXMAP_AND_TEXT(errorpix, _("Auth failed"));
+			if (pop3_session->ac_prefs->session_passwd) {
+				g_free(pop3_session->ac_prefs->session_passwd);
+				pop3_session->ac_prefs->session_passwd = NULL;
+			}
 			break;
 		case INC_LOCKED:
 			SET_PIXMAP_AND_TEXT(errorpix, _("Locked"));
@@ -710,12 +707,6 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 
 		new_msgs += pop3_session->cur_total_num;
 
-		if (pop3_session->error_val == PS_AUTHFAIL &&
-		    pop3_session->ac_prefs->tmp_pass) {
-			g_free(pop3_session->ac_prefs->tmp_pass);
-			pop3_session->ac_prefs->tmp_pass = NULL;
-		}
-
 		pop3_write_uidl_list(pop3_session);
 
 		if (inc_state != INC_SUCCESS && inc_state != INC_CANCEL) {
@@ -1504,6 +1495,12 @@ static void inc_autocheck_timer_set_interval(guint interval)
 	   the common preferences */
 	if (prefs_common.autochk_newmail && autocheck_data
 	    && prefs_common.work_offline == FALSE) {
+#if GLIB_CHECK_VERSION(2,14,0)
+		if (interval % 1000 == 0)
+			autocheck_timer =
+				g_timeout_add_seconds(interval/1000, inc_autocheck_func, autocheck_data);
+		else
+#endif
 		autocheck_timer = g_timeout_add
 			(interval, inc_autocheck_func, autocheck_data);
 		debug_print("added timer = %d\n", autocheck_timer);
