@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * 
  */
 
 /*
@@ -363,7 +363,7 @@ static gboolean jpilot_mark_files( JPilotFile *pilotFile ) {
 	pilotFile->pc3ModifyTime = 0;
 	pcFile = jpilot_get_pc3_file( pilotFile );
 	if( pcFile == NULL ) return retVal;
-	if( 0 == stat( pcFile, &filestat ) ) {
+	if( 0 == g_stat( pcFile, &filestat ) ) {
 		pilotFile->havePC3 = TRUE;
 		pilotFile->pc3ModifyTime = filestat.st_mtime;
 		retVal = TRUE;
@@ -392,7 +392,7 @@ static gboolean jpilot_check_files( JPilotFile *pilotFile ) {
 	pcFile = jpilot_get_pc3_file( pilotFile );
 	if( pcFile == NULL ) return FALSE;
 
-	if( 0 == stat( pcFile, &filestat ) ) {
+	if( 0 == g_stat( pcFile, &filestat ) ) {
 		if( filestat.st_mtime == pilotFile->pc3ModifyTime ) retVal = FALSE;
 	}
 	g_free( pcFile );
@@ -1175,7 +1175,7 @@ static void jpilot_load_address(
 
 		ind = indPhoneLbl[k];
 		/*
-		* fprintf( stdout, "%d : %d : %20s : %s\n", k, ind,
+		* g_print( "%d : %d : %20s : %s\n", k, ind,
 		* ai->phoneLabels[ind], addrEnt[3+k] );
 		*/
 		if( indPhoneLbl[k] == IND_PHONE_EMAIL ) {
@@ -1192,7 +1192,7 @@ static void jpilot_load_address(
 		ind = GPOINTER_TO_INT( node->data );
 		if( ind > -1 ) {
 			/*
-			* fprintf( stdout, "%d : %20s : %s\n", ind, ai->labels[ind],
+			* g_print( "%d : %20s : %s\n", ind, ai->labels[ind],
 			* addrEnt[ind] );
 			*/
 			labelEntry = addrEnt[ind];
