@@ -39,54 +39,65 @@
 #include "foldersel.h"
 #include "prefs_common.h"
 
-static void new_folder_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void delete_folder_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void rename_folder_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void move_folder_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void update_tree_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void remove_mailbox_cb(FolderView *folderview, guint action, GtkWidget *widget);
+static void new_folder_cb(GtkAction *action, gpointer data);
+static void delete_folder_cb(GtkAction *action, gpointer data);
+static void rename_folder_cb(GtkAction *action, gpointer data);
+static void move_folder_cb(GtkAction *action, gpointer data);
+static void copy_folder_cb(GtkAction *action, gpointer data);
+static void update_tree_cb(GtkAction *action, gpointer data);
+static void remove_mailbox_cb(GtkAction *action, gpointer data);
 
-static GtkItemFactoryEntry mh_popup_entries[] =
+static GtkActionEntry mh_popup_entries[] = 
 {
-	{N_("/Create _new folder..."),	 NULL, new_folder_cb,     0, NULL},
-	{"/---",			 NULL, NULL,             0, "<Separator>"},
-	{N_("/_Rename folder..."),	 NULL, rename_folder_cb,  0, NULL},
-	{N_("/M_ove folder..."), 	 NULL, move_folder_cb,    0, NULL},
-	{N_("/Cop_y folder..."),	 NULL, move_folder_cb,    1, NULL},
-	{"/---",			 NULL, NULL,             0, "<Separator>"},
-	{N_("/_Delete folder..."),	 NULL, delete_folder_cb,  0, NULL},
-	{"/---",			 NULL, NULL,              0, "<Separator>"},
-	{N_("/_Check for new messages"), NULL, update_tree_cb,    0, NULL},
-	{N_("/C_heck for new folders"),	 NULL, update_tree_cb,    1, NULL},
-	{N_("/R_ebuild folder tree"),	 NULL, update_tree_cb,    2, NULL},
-	{"/---",			 NULL, NULL, 		  0, "<Separator>"},
-	{N_("/Remove _mailbox..."),	 NULL, remove_mailbox_cb, 0, NULL},
-	{"/---",			 NULL, NULL, 		  0, "<Separator>"},
-};
-
-static void set_sensitivity(GtkItemFactory *factory, FolderItem *item);
+	{"FolderViewPopup/CreateNewFolder",	NULL, N_("Create _new folder..."), NULL, NULL, G_CALLBACK(new_folder_cb) },
+	{"FolderViewPopup/RenameFolder",	NULL, N_("_Rename folder..."), NULL, NULL, G_CALLBACK(rename_folder_cb) },
+	{"FolderViewPopup/MoveFolder",		NULL, N_("M_ove folder..."), NULL, NULL, G_CALLBACK(move_folder_cb) },
+	{"FolderViewPopup/CopyFolder",		NULL, N_("Cop_y folder..."), NULL, NULL, G_CALLBACK(copy_folder_cb) },
+	{"FolderViewPopup/DeleteFolder",	NULL, N_("_Delete folder..."), NULL, NULL, G_CALLBACK(delete_folder_cb) },
+	{"FolderViewPopup/CheckNewMessages",	NULL, N_("_Check for new messages"), NULL, NULL, G_CALLBACK(update_tree_cb) }, /*0*/
+	{"FolderViewPopup/CheckNewFolders",	NULL, N_("C_heck for new folders"), NULL, NULL, G_CALLBACK(update_tree_cb) }, /*1*/
+	{"FolderViewPopup/RebuildTree",		NULL, N_("R_ebuild folder tree"), NULL, NULL, G_CALLBACK(update_tree_cb) }, /*2*/
+	{"FolderViewPopup/RemoveMailbox",	NULL, N_("Remove _mailbox..."), NULL, NULL, G_CALLBACK(remove_mailbox_cb) },
+};			
+static void set_sensitivity(GtkUIManager *ui_manager, FolderItem *item);
+static void add_menuitems(GtkUIManager *ui_manager, FolderItem *item);
 
 static FolderViewPopup mh_popup =
 {
 	"mh",
 	"<MHFolder>",
-	NULL,
+	mh_popup_entries,
+	G_N_ELEMENTS(mh_popup_entries),
+	NULL, 0,
+	NULL, 0, 0, NULL,
+	add_menuitems,
 	set_sensitivity
 };
 
 void mh_gtk_init(void)
 {
-	guint i, n_entries;
-
-	n_entries = sizeof(mh_popup_entries) /
-		sizeof(mh_popup_entries[0]);
-	for (i = 0; i < n_entries; i++)
-		mh_popup.entries = g_slist_append(mh_popup.entries, &mh_popup_entries[i]);
-
 	folderview_register_popup(&mh_popup);
 }
 
-static void set_sensitivity(GtkItemFactory *factory, FolderItem *item)
+static void add_menuitems(GtkUIManager *ui_manager, FolderItem *item)
+{
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "CreateNewFolder", "FolderViewPopup/CreateNewFolder", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorMH1", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "RenameFolder", "FolderViewPopup/RenameFolder", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "MoveFolder", "FolderViewPopup/MoveFolder", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "CopyFolder", "FolderViewPopup/CopyFolder", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorMH2", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "DeleteFolder", "FolderViewPopup/DeleteFolder", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorMH3", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "CheckNewMessages", "FolderViewPopup/CheckNewMessages", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "CheckNewFolders", "FolderViewPopup/CheckNewFolders", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "RebuildTree", "FolderViewPopup/RebuildTree", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorMH4", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "RemoveMailbox", "FolderViewPopup/RemoveMailbox", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorMH5", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+}
+
+static void set_sensitivity(GtkUIManager *ui_manager, FolderItem *item)
 {
 	gboolean folder_is_normal = 
 			item != NULL &&
@@ -96,26 +107,26 @@ static void set_sensitivity(GtkItemFactory *factory, FolderItem *item)
 			!folder_has_parent_of_type(item, F_QUEUE) &&
 			!folder_has_parent_of_type(item, F_TRASH);
 #define SET_SENS(name, sens) \
-	menu_set_sensitive(factory, name, sens)
+	cm_menu_set_sensitive_full(ui_manager, "Popup/"name, sens)
 
-	SET_SENS("/Create new folder...",   TRUE);
-	SET_SENS("/Rename folder...",       item->stype == F_NORMAL && folder_item_parent(item) != NULL);
-	SET_SENS("/Move folder...", 	    folder_is_normal && folder_item_parent(item) != NULL);
-	SET_SENS("/Delete folder...", 	    item->stype == F_NORMAL && folder_item_parent(item) != NULL);
+	SET_SENS("FolderViewPopup/CreateNewFolder",   TRUE);
+	SET_SENS("FolderViewPopup/RenameFolder",       item->stype == F_NORMAL && folder_item_parent(item) != NULL);
+	SET_SENS("FolderViewPopup/MoveFolder", 	    folder_is_normal && folder_item_parent(item) != NULL);
+	SET_SENS("FolderViewPopup/DeleteFolder", 	    item->stype == F_NORMAL && folder_item_parent(item) != NULL);
 
-	SET_SENS("/Check for new messages", folder_item_parent(item) == NULL);
-	SET_SENS("/Check for new folders",  folder_item_parent(item) == NULL);
-	SET_SENS("/Rebuild folder tree",    folder_item_parent(item) == NULL);
+	SET_SENS("FolderViewPopup/CheckNewMessages", folder_item_parent(item) == NULL);
+	SET_SENS("FolderViewPopup/CheckNewFolders",  folder_item_parent(item) == NULL);
+	SET_SENS("FolderViewPopup/RebuildTree",    folder_item_parent(item) == NULL);
 
-	SET_SENS("/Remove mailbox...",         folder_item_parent(item) == NULL);
+	SET_SENS("FolderViewPopup/RemoveMailbox",         folder_item_parent(item) == NULL);
 
 #undef SET_SENS
 }
 
-static void new_folder_cb(FolderView *folderview, guint action,
-		          GtkWidget *widget)
+static void new_folder_cb(GtkAction *action, gpointer data)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
+	FolderView *folderview = (FolderView *)data;
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 	FolderItem *new_item;
 	gchar *new_folder;
@@ -124,7 +135,7 @@ static void new_folder_cb(FolderView *folderview, guint action,
 
 	if (!folderview->selected) return;
 
-	item = gtk_ctree_node_get_row_data(ctree, folderview->selected);
+	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
 	g_return_if_fail(item != NULL);
 	g_return_if_fail(item->folder != NULL);
 
@@ -165,10 +176,10 @@ static void new_folder_cb(FolderView *folderview, guint action,
 	folder_write_list();
 }
 
-static void delete_folder_cb(FolderView *folderview, guint action,
-			     GtkWidget *widget)
+static void delete_folder_cb(GtkAction *action, gpointer data)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
+	FolderView *folderview = (FolderView *)data;
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 	gchar *message, *name;
 	AlertValue avalue;
@@ -196,7 +207,7 @@ static void delete_folder_cb(FolderView *folderview, guint action,
 	old_id = folder_item_get_identifier(item);
 
 	if (folderview->opened == folderview->selected ||
-	    gtk_ctree_is_ancestor(ctree,
+	    gtk_cmctree_is_ancestor(ctree,
 				  folderview->selected,
 				  folderview->opened)) {
 		summary_clear_all(folderview->summaryview);
@@ -217,9 +228,9 @@ static void delete_folder_cb(FolderView *folderview, guint action,
 
 }
 
-static void rename_folder_cb(FolderView *folderview, guint action,
-			     GtkWidget *widget)
+static void rename_folder_cb(GtkAction *action, gpointer data)
 {
+	FolderView *folderview = (FolderView *)data;
 	FolderItem *item;
 	gchar *new_folder;
 	gchar *name;
@@ -278,8 +289,9 @@ static void rename_folder_cb(FolderView *folderview, guint action,
 	folder_write_list();
 }
 
-static void move_folder_cb(FolderView *folderview, guint action, GtkWidget *widget)
+static void move_folder_cb(GtkAction *action, gpointer data)
 {
+	FolderView *folderview = (FolderView *)data;
 	FolderItem *from_folder = NULL, *to_folder = NULL;
 
 	from_folder = folderview_get_selected_item(folderview);
@@ -290,13 +302,32 @@ static void move_folder_cb(FolderView *folderview, guint action, GtkWidget *widg
 	if (!to_folder)
 		return;
 	
-	folderview_move_folder(folderview, from_folder, to_folder, action);
+	folderview_move_folder(folderview, from_folder, to_folder, 0);
 }
 
-static void update_tree_cb(FolderView *folderview, guint action,
-			   GtkWidget *widget)
+static void copy_folder_cb(GtkAction *action, gpointer data)
 {
+	FolderView *folderview = (FolderView *)data;
+	FolderItem *from_folder = NULL, *to_folder = NULL;
+
+	from_folder = folderview_get_selected_item(folderview);
+	if (!from_folder || from_folder->folder->klass != mh_get_class())
+		return;
+
+	to_folder = foldersel_folder_sel(from_folder->folder, FOLDER_SEL_MOVE, NULL, TRUE);
+	if (!to_folder)
+		return;
+	
+	folderview_move_folder(folderview, from_folder, to_folder, 1);
+}
+
+#define DO_ACTION(name, act)	{ if (!strcmp(a_name, name)) act; }
+
+static void update_tree_cb(GtkAction *action, gpointer data)
+{
+	FolderView *folderview = (FolderView *)data;
 	FolderItem *item;
+	const gchar *a_name = gtk_action_get_name(action);
 
 	item = folderview_get_selected_item(folderview);
 	g_return_if_fail(item != NULL);
@@ -305,17 +336,14 @@ static void update_tree_cb(FolderView *folderview, guint action,
 
 	g_return_if_fail(item->folder != NULL);
 
-	if (action == 0)
-		folderview_check_new(item->folder);
-	else if (action == 1)
-		folderview_rescan_tree(item->folder, FALSE);
-	else if (action == 2)
-		folderview_rescan_tree(item->folder, TRUE);
+	DO_ACTION("FolderViewPopup/CheckNewMessages", folderview_check_new(item->folder));
+	DO_ACTION("FolderViewPopup/CheckNewFolders", folderview_rescan_tree(item->folder, FALSE));
+	DO_ACTION("FolderViewPopup/RebuildTree", folderview_rescan_tree(item->folder, FALSE));
 }
 
-static void remove_mailbox_cb(FolderView *folderview, guint action,
-			      GtkWidget *widget)
+static void remove_mailbox_cb(GtkAction *action, gpointer data)
 {
+	FolderView *folderview = (FolderView *)data;
 	FolderItem *item;
 	gchar *name;
 	gchar *message;
