@@ -324,8 +324,7 @@ static ItemEMail *mutt_insert_table(
 	gchar *key;
 
 	/* Test whether address already in hash table */
-	key = g_strdup( address );
-	g_strdown( key );
+	key = g_utf8_strdown( address, -1 );
 	email = g_hash_table_lookup( muttFile->uniqTable, key );
 
 	if( email == NULL ) {
