@@ -37,7 +37,6 @@
 
 #include "nntp-thread.h"
 #include "news.h"
-#include "news.h"
 #include "news_gtk.h"
 #include "socket.h"
 #include "recv.h"
@@ -147,6 +146,9 @@ static void news_synchronise		 (FolderItem	*item, gint days);
 static int news_remove_msg		 (Folder 	*folder, 
 					  FolderItem 	*item, 
 					  gint 		 msgnum);
+static gint news_rename_folder		 (Folder *folder,
+					  FolderItem *item,
+					  const gchar *name);
 static gint news_remove_folder		 (Folder	*folder,
 					  FolderItem	*item);
 static FolderClass news_class;
@@ -166,6 +168,7 @@ FolderClass *news_get_class(void)
 		news_class.item_get_path = news_item_get_path;
 		news_class.get_num_list = news_get_num_list;
 		news_class.scan_required = news_scan_required;
+		news_class.rename_folder = news_rename_folder;
 		news_class.remove_folder = news_remove_folder;
 
 		/* Message functions */
@@ -294,7 +297,7 @@ static Session *news_session_new(Folder *folder, const gchar *server, gushort po
 	log_message(LOG_PROTOCOL, _("creating NNTP connection to %s:%d ...\n"), server, port);
 
 	session = g_new0(NewsSession, 1);
-	session_init(SESSION(session));
+	session_init(SESSION(session), folder->account, FALSE);
 	SESSION(session)->type             = SESSION_NEWS;
 	SESSION(session)->server           = g_strdup(server);
  	SESSION(session)->sock             = NULL;
@@ -335,8 +338,9 @@ static Session *news_session_new_for_folder(Folder *folder)
 		if (ac->passwd && ac->passwd[0])
 			passwd = g_strdup(ac->passwd);
 		else
-			passwd = input_dialog_query_password(ac->nntp_server,
-							     userid);
+			passwd = input_dialog_query_password_keep(ac->nntp_server,
+								  userid,
+								  &(ac->session_passwd));
 	}
 
 #if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
@@ -368,6 +372,10 @@ static Session *news_session_new_for_folder(Folder *folder)
 			log_error(LOG_PROTOCOL, _("Error authenticating to %s:%d ...\n"), ac->nntp_server, port);
 			session_destroy(SESSION(session));
 			g_free(passwd);
+			if (ac->session_passwd) {
+				g_free(ac->session_passwd);
+				ac->session_passwd = NULL;
+			}
 			return NULL;
 		}
 	}
@@ -542,7 +550,7 @@ GSList *news_get_group_list(Folder *folder)
 		gint ok;
 		clist *grouplist = NULL;
 		clistiter *cur;
-		fp = fopen(filename, "wb");
+		fp = g_fopen(filename, "wb");
 		
 		if (!fp) {
 			g_free(filename);
@@ -709,9 +717,9 @@ static gint news_get_article(Folder *folder, gint num, gchar *filename)
 	if (r == NEWSNNTP_NO_ERROR) {
 		if (str_write_to_file(result, filename) < 0)
 			return -1;
+		g_free(result);
 	}
 	
-	g_free(result);
 	return r;
 }
 
@@ -923,7 +931,7 @@ static gchar *news_item_get_path(Folder *folder, FolderItem *item)
 	folder_path = news_folder_get_path(folder);
 
         g_return_val_if_fail(folder_path != NULL, NULL);
-        if (folder_path[0] == G_DIR_SEPARATOR) {
+        if (g_path_is_absolute(folder_path)) {
                 if (item->path)
                         path = g_strconcat(folder_path, G_DIR_SEPARATOR_S,
                                            item->path, NULL);
@@ -939,7 +947,10 @@ static gchar *news_item_get_path(Folder *folder, FolderItem *item)
                                            folder_path, NULL);
         }
         g_free(folder_path);
-
+#ifdef G_OS_WIN32
+	while (strchr(path, '/'))
+		*strchr(path, '/') = '\\';
+#endif
 	return path;
 }
 
@@ -1212,6 +1223,26 @@ void news_synchronise(FolderItem *item, gint days)
 	news_gtk_synchronise(item, days);
 }
 
+static gint news_rename_folder(Folder *folder, FolderItem *item,
+				const gchar *name)
+{
+	gchar *path;
+	 
+	g_return_val_if_fail(folder != NULL, -1);
+	g_return_val_if_fail(item != NULL, -1);
+	g_return_val_if_fail(item->path != NULL, -1);
+	g_return_val_if_fail(name != NULL, -1);
+
+	path = folder_item_get_path(item);
+	if (!is_dir_exist(path))
+		make_dir_hier(path);
+
+	g_free(item->name);
+	item->name = g_strdup(name);
+
+	return 0;
+}
+
 static gint news_remove_folder(Folder *folder, FolderItem *item)
 {
 	gchar *path;
