@@ -41,77 +41,100 @@
 #include "inc.h"
 #include "news.h"
 #include "statusbar.h"
+#include "inputdialog.h"
 
-static void subscribe_newsgroup_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void unsubscribe_newsgroup_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void update_tree_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void download_cb(FolderView *folderview, guint action, GtkWidget *widget);
-static void sync_cb(FolderView *folderview, guint action, GtkWidget *widget);
+static void subscribe_newsgroup_cb(GtkAction *action, gpointer data);
+static void unsubscribe_newsgroup_cb(GtkAction *action, gpointer data);
+static void rename_newsgroup_cb(GtkAction *action, gpointer data);
+static void update_tree_cb(GtkAction *action, gpointer data);
+static void download_cb(GtkAction *action, gpointer data);
+static void sync_cb(GtkAction *action, gpointer data);
 
-static GtkItemFactoryEntry news_popup_entries[] =
+static GtkActionEntry news_popup_entries[] =
 {
-	{N_("/_Subscribe to newsgroup..."),	NULL, subscribe_newsgroup_cb,    0, NULL},
-	{N_("/_Unsubscribe newsgroup"),		NULL, unsubscribe_newsgroup_cb,  0, NULL},
-	{"/---",				NULL, NULL,                      0, "<Separator>"},
-	{N_("/Synchronise"),			NULL, sync_cb,      	0, NULL},
-	{N_("/Down_load messages"),		NULL, download_cb,               0, NULL},
-	{"/---",				NULL, NULL,                      0, "<Separator>"},
-	{N_("/_Check for new messages"),	NULL, update_tree_cb,            0, NULL},
-	{"/---",				NULL, NULL,                      0, "<Separator>"},
+	{"FolderViewPopup/Subscribe",		NULL, N_("_Subscribe to newsgroup..."), NULL, NULL, G_CALLBACK(subscribe_newsgroup_cb) },
+	{"FolderViewPopup/Unsubscribe",		NULL, N_("_Unsubscribe newsgroup"), NULL, NULL, G_CALLBACK(unsubscribe_newsgroup_cb) },
+
+	{"FolderViewPopup/Synchronise",		NULL, N_("Synchronise"), NULL, NULL, G_CALLBACK(sync_cb) },
+	{"FolderViewPopup/DownloadMessages",	NULL, N_("Down_load messages"), NULL, NULL, G_CALLBACK(download_cb) },
+	{"FolderViewPopup/RenameFolder",	NULL, N_("_Rename folder..."), NULL, NULL, G_CALLBACK(rename_newsgroup_cb) },
+
+	{"FolderViewPopup/CheckNewMessages",	NULL, N_("_Check for new messages"), NULL, NULL, G_CALLBACK(update_tree_cb) },
+
 };
 
-static void set_sensitivity(GtkItemFactory *factory, FolderItem *item);
+static void set_sensitivity(GtkUIManager *ui_manager, FolderItem *item);
+static void add_menuitems(GtkUIManager *ui_manager, FolderItem *item);
 
 static FolderViewPopup news_popup =
 {
 	"news",
 	"<NewsFolder>",
-	NULL,
+	news_popup_entries,
+	G_N_ELEMENTS(news_popup_entries),
+	NULL, 0,
+	NULL, 0, 0, NULL,
+	add_menuitems,
 	set_sensitivity
 };
 
 void news_gtk_init(void)
 {
-	guint i, n_entries;
-
-	n_entries = sizeof(news_popup_entries) /
-		sizeof(news_popup_entries[0]);
-	for (i = 0; i < n_entries; i++)
-		news_popup.entries = g_slist_append(news_popup.entries, &news_popup_entries[i]);
-
 	folderview_register_popup(&news_popup);
 }
 
-static void set_sensitivity(GtkItemFactory *factory, FolderItem *item)
+static void add_menuitems(GtkUIManager *ui_manager, FolderItem *item)
+{
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "Subscribe", "FolderViewPopup/Subscribe", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "Unsubscribe", "FolderViewPopup/Unsubscribe", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorNews1", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "Synchronise", "FolderViewPopup/Synchronise", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "DownloadMessages", "FolderViewPopup/DownloadMessages", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "RenameFolder", "FolderViewPopup/RenameFolder", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorNews2", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "CheckNewMessages", "FolderViewPopup/CheckNewMessages", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(ui_manager, "/Popup/FolderViewPopup", "SeparatorNews3", "FolderViewPopup/---", GTK_UI_MANAGER_SEPARATOR)
+}
+	
+static void set_sensitivity(GtkUIManager *ui_manager, FolderItem *item)
 {
 	MainWindow *mainwin = mainwindow_get_mainwindow();
 	
 #define SET_SENS(name, sens) \
-	menu_set_sensitive(factory, name, sens)
-
-	SET_SENS("/Subscribe to newsgroup...", 
-		 folder_item_parent(item) == NULL 
-		 && mainwin->lock_count == 0
-		 && news_folder_locked(item->folder) == 0);
-	SET_SENS("/Unsubscribe newsgroup",     
-		 folder_item_parent(item) != NULL 
-		 && mainwin->lock_count == 0
-		 && news_folder_locked(item->folder) == 0);
-	SET_SENS("/Check for new messages",    
-		 folder_item_parent(item) == NULL 
-		 && mainwin->lock_count == 0
-		 && news_folder_locked(item->folder) == 0);
-	SET_SENS("/Synchronise",    
-		 item ? (folder_item_parent(item) != NULL && folder_want_synchronise(item->folder))
-			 : FALSE);
+	cm_menu_set_sensitive_full(ui_manager, "Popup/"name, sens)
 
+	SET_SENS("FolderViewPopup/Subscribe", 
+			folder_item_parent(item) == NULL 
+			&& mainwin->lock_count == 0
+			&& news_folder_locked(item->folder) == 0);
+	SET_SENS("FolderViewPopup/Unsubscribe",     
+			folder_item_parent(item) != NULL 
+			&& mainwin->lock_count == 0
+			&& news_folder_locked(item->folder) == 0);
+	SET_SENS("FolderViewPopup/CheckNewMessages",    
+			folder_item_parent(item) == NULL 
+			&& mainwin->lock_count == 0
+			&& news_folder_locked(item->folder) == 0);
+	SET_SENS("FolderViewPopup/Synchronise",    
+			item ? (folder_item_parent(item) != NULL
+			&& folder_want_synchronise(item->folder))
+			: FALSE);
+	SET_SENS("FolderViewPopup/DownloadMessages",
+			item ? (folder_item_parent(item) != NULL
+			&& !item->no_select)
+			: FALSE);
+	SET_SENS("FolderViewPopup/RenameFolder",
+			folder_item_parent(item) != NULL 
+			&& mainwin->lock_count == 0
+			&& news_folder_locked(item->folder) == 0);
 #undef SET_SENS
 }
 
-static void subscribe_newsgroup_cb(FolderView *folderview, guint action, GtkWidget *widget)
+static void subscribe_newsgroup_cb(GtkAction *action, gpointer data)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
-	GtkCTreeNode *servernode, *node;
+	FolderView *folderview = (FolderView *)data;
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
+	GtkCMCTreeNode *servernode, *node;
 	Folder *folder;
 	FolderItem *item;
 	FolderItem *rootitem;
@@ -123,7 +146,7 @@ static void subscribe_newsgroup_cb(FolderView *folderview, guint action, GtkWidg
 	
 	if (!folderview->selected) return;
 
-	item = gtk_ctree_node_get_row_data(ctree, folderview->selected);
+	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
 	g_return_if_fail(item != NULL);
 
 	if (mainwin->lock_count || news_folder_locked(item->folder))
@@ -134,12 +157,12 @@ static void subscribe_newsgroup_cb(FolderView *folderview, guint action, GtkWidg
 	g_return_if_fail(FOLDER_TYPE(folder) == F_NEWS);
 	g_return_if_fail(folder->account != NULL);
 
-	if (GTK_CTREE_ROW(folderview->selected)->parent != NULL)
-		servernode = GTK_CTREE_ROW(folderview->selected)->parent;
+	if (GTK_CMCTREE_ROW(folderview->selected)->parent != NULL)
+		servernode = GTK_CMCTREE_ROW(folderview->selected)->parent;
 	else
 		servernode = folderview->selected;
 
-	rootitem = gtk_ctree_node_get_row_data(ctree, servernode);
+	rootitem = gtk_cmctree_node_get_row_data(ctree, servernode);
 
 	new_subscr = grouplist_dialog(folder);
 
@@ -154,7 +177,7 @@ static void subscribe_newsgroup_cb(FolderView *folderview, guint action, GtkWidg
 			continue;
 		}
 
-		node = gtk_ctree_find_by_row_data(ctree, servernode, item);
+		node = gtk_cmctree_find_by_row_data(ctree, servernode, item);
 		if (!node) {
 			gnode = next;
 			continue;
@@ -165,13 +188,13 @@ static void subscribe_newsgroup_cb(FolderView *folderview, guint action, GtkWidg
 			folderview->opened = NULL;
 		}
 
-		gtk_ctree_remove_node(ctree, node);
+		gtk_cmctree_remove_node(ctree, node);
 		folder_item_remove(item);
 
 		gnode = next;
 	}
 
-	gtk_clist_freeze(GTK_CLIST(ctree));
+	gtk_cmclist_freeze(GTK_CMCLIST(ctree));
 
 	/* add subscribed newsgroups */
 	for (cur = new_subscr; cur != NULL; cur = cur->next) {
@@ -190,7 +213,7 @@ static void subscribe_newsgroup_cb(FolderView *folderview, guint action, GtkWidg
 		hooks_invoke(FOLDER_UPDATE_HOOKLIST, &hookdata);
 	}
 
-	gtk_clist_thaw(GTK_CLIST(ctree));
+	gtk_cmclist_thaw(GTK_CMCLIST(ctree));
 
 	slist_free_strings(new_subscr);
 	g_slist_free(new_subscr);
@@ -198,10 +221,10 @@ static void subscribe_newsgroup_cb(FolderView *folderview, guint action, GtkWidg
 	folder_write_list();
 }
 
-static void unsubscribe_newsgroup_cb(FolderView *folderview, guint action,
-				     GtkWidget *widget)
+static void unsubscribe_newsgroup_cb(GtkAction *action, gpointer data)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
+	FolderView *folderview = (FolderView *)data;
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 	gchar *name;
 	gchar *message;
@@ -211,7 +234,7 @@ static void unsubscribe_newsgroup_cb(FolderView *folderview, guint action,
 	
 	if (!folderview->selected) return;
 
-	item = gtk_ctree_node_get_row_data(ctree, folderview->selected);
+	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
 	g_return_if_fail(item != NULL);
 
 	if (mainwin->lock_count || news_folder_locked(item->folder))
@@ -250,9 +273,68 @@ static void unsubscribe_newsgroup_cb(FolderView *folderview, guint action,
 	g_free(old_id);
 }
 
-static void update_tree_cb(FolderView *folderview, guint action,
-			   GtkWidget *widget)
+static FolderItem *find_child_by_name(FolderItem *item, const gchar *name)
 {
+	GNode *node;
+	FolderItem *child;
+
+	for (node = item->node->children; node != NULL; node = node->next) {
+		child = FOLDER_ITEM(node->data);
+		if (strcmp2(child->name, name) == 0) {
+			return child;
+		}
+	}
+
+	return NULL;
+}
+
+static void rename_newsgroup_cb(GtkAction *action, gpointer data)
+{
+	FolderView *folderview = (FolderView *)data;
+	FolderItem *item;
+	gchar *new_folder;
+	gchar *name;
+	gchar *message;
+
+	item = folderview_get_selected_item(folderview);
+	g_return_if_fail(item != NULL);
+	g_return_if_fail(item->path != NULL);
+	g_return_if_fail(item->folder != NULL);
+
+	name = trim_string(item->name, 32);
+	message = g_strdup_printf(_("Input new name for '%s':"), name);
+	new_folder = input_dialog(_("Rename newsgroup folder"), message, item->name);
+	g_free(message);
+	g_free(name);
+
+	if (!new_folder) return;
+	AUTORELEASE_STR(new_folder, {g_free(new_folder); return;});
+
+	if (strchr(new_folder, G_DIR_SEPARATOR) != NULL) {
+		alertpanel_error(_("'%c' can't be included in folder name."),
+				 G_DIR_SEPARATOR);
+		return;
+	}
+
+	if (find_child_by_name(folder_item_parent(item), new_folder)) {
+		name = trim_string(new_folder, 32);
+		alertpanel_error(_("The folder '%s' already exists."), name);
+		g_free(name);
+		return;
+	}
+
+	if (folder_item_rename(item, new_folder) < 0) {
+		alertpanel_error(_("The folder could not be renamed.\n"
+				   "The new folder name is not allowed."));
+		return;
+	}
+
+	folder_write_list();
+}
+
+static void update_tree_cb(GtkAction *action, gpointer data)
+{
+	FolderView *folderview = (FolderView *)data;
 	FolderItem *item;
 	MainWindow *mainwin = mainwindow_get_mainwindow();
 	
@@ -269,9 +351,9 @@ static void update_tree_cb(FolderView *folderview, guint action,
 	folderview_check_new(item->folder);
 }
 
-static void sync_cb(FolderView *folderview, guint action,
-			   GtkWidget *widget)
+static void sync_cb(GtkAction *action, gpointer data)
 {
+	FolderView *folderview = (FolderView *)data;
 	FolderItem *item;
 
 	item = folderview_get_selected_item(folderview);
@@ -325,14 +407,14 @@ void news_gtk_synchronise(FolderItem *item, gint days)
 	main_window_cursor_normal(mainwin);
 }
 
-static void download_cb(FolderView *folderview, guint action,
-			GtkWidget *widget)
+static void download_cb(GtkAction *action, gpointer data)
 {
-	GtkCTree *ctree = GTK_CTREE(folderview->ctree);
+	FolderView *folderview = (FolderView *)data;
+	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 
 	if (!folderview->selected) return;
 
-	item = gtk_ctree_node_get_row_data(ctree, folderview->selected);
+	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
 	news_gtk_synchronise(item, 0);
 }
