@@ -689,7 +689,7 @@ static gboolean pgpinline_sign(MimeInfo *mimeinfo, PrefsAccount *account)
 	if (msgcontent->content == MIMECONTENT_FILE &&
 	    msgcontent->data.filename != NULL) {
 	    	if (msgcontent->tmp == TRUE)
-			g_unlink(msgcontent->data.filename);
+			claws_unlink(msgcontent->data.filename);
 		g_free(msgcontent->data.filename);
 	}
 	msgcontent->data.mem = g_strdup(tmp);
@@ -825,7 +825,7 @@ static gboolean pgpinline_encrypt(MimeInfo *mimeinfo, const gchar *encrypt_data)
 	if (msgcontent->content == MIMECONTENT_FILE &&
 	    msgcontent->data.filename != NULL) {
 	    	if (msgcontent->tmp == TRUE)
-			g_unlink(msgcontent->data.filename);
+			claws_unlink(msgcontent->data.filename);
 		g_free(msgcontent->data.filename);
 	}
 	msgcontent->data.mem = g_strdup(tmp);
