@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -348,12 +348,37 @@ static MimeInfo *pgpmime_decrypt(MimeInfo *mimeinfo)
 		return NULL;
     	}
 
-	fprintf(dstfp, "MIME-Version: 1.0\n");
+	if (fprintf(dstfp, "MIME-Version: 1.0\n") < 0) {
+        	FILE_OP_ERROR(fname, "fprintf");
+		privacy_set_error(_("Couldn't write to decrypted file %s"), fname);
+        	g_free(fname);
+        	gpgme_data_release(plain);
+		gpgme_release(ctx);
+		debug_print("can't open!\n");
+		return NULL;
+	}
 
 	chars = sgpgme_data_release_and_get_mem(plain, &len);
-	if (len > 0)
-		fwrite(chars, len, 1, dstfp);
-	fclose(dstfp);
+	if (len > 0) {
+		if (fwrite(chars, 1, len, dstfp) < len) {
+        		FILE_OP_ERROR(fname, "fwrite");
+			privacy_set_error(_("Couldn't write to decrypted file %s"), fname);
+        		g_free(fname);
+        		gpgme_data_release(plain);
+			gpgme_release(ctx);
+			debug_print("can't open!\n");
+			return NULL;
+		}
+	}
+	if (fclose(dstfp) == EOF) {
+        	FILE_OP_ERROR(fname, "fclose");
+		privacy_set_error(_("Couldn't close decrypted file %s"), fname);
+        	g_free(fname);
+        	gpgme_data_release(plain);
+		gpgme_release(ctx);
+		debug_print("can't open!\n");
+		return NULL;
+	}
 
 	parseinfo = procmime_scan_file(fname);
 	g_free(fname);
