@@ -69,6 +69,7 @@ struct _PrefsAccount
 	gboolean use_nntp_auth_onconnect;
 	gchar *userid;
 	gchar *passwd;
+	gchar *session_passwd;
 
 	gchar * local_mbox;
 	gboolean use_mail_command;
@@ -78,15 +79,19 @@ struct _PrefsAccount
 	SSLType ssl_imap;
 	SSLType ssl_nntp;
 	SSLType ssl_smtp;
-	gboolean use_nonblocking_ssl;
+	
+	gchar *out_ssl_client_cert_file;
+	gchar *out_ssl_client_cert_pass;
+	gchar *in_ssl_client_cert_file;
+	gchar *in_ssl_client_cert_pass;
 
-	/* Temporarily preserved password */
-	gchar *tmp_pass;
+	gboolean use_nonblocking_ssl;
 
 	/* Receive */
 	gboolean use_apop_auth;
 	gboolean rmmail;
 	gint msg_leave_time;
+	gint msg_leave_hour;
 	gboolean recv_at_getall;
 	gboolean sd_rmmail_on_download;
 	gboolean enable_size_limit;
@@ -106,9 +111,7 @@ struct _PrefsAccount
 	SMTPAuthType smtp_auth_type;
 	gchar *smtp_userid;
 	gchar *smtp_passwd;
-
-	/* Temporarily preserved password */
-	gchar *tmp_smtp_pass;
+	gchar *session_smtp_passwd;
 
 	gboolean pop_before_smtp;
 	gint pop_before_smtp_timeout;
@@ -146,6 +149,7 @@ struct _PrefsAccount
 	gboolean  default_encrypt;
 	gboolean  default_encrypt_reply;
 	gboolean  default_sign;
+	gboolean  default_sign_reply;
 	gboolean  save_encrypted_as_clear_text;
 	gboolean  encrypt_to_self;
 
