@@ -91,13 +91,10 @@ static void prefs_actions_register_cb	(GtkWidget	*w,
 					 gpointer	 data);
 static void prefs_actions_substitute_cb	(GtkWidget	*w,
 					 gpointer	 data);
-static void prefs_actions_delete_cb	(GtkWidget	*w,
-					 gpointer	 data);
-static void prefs_actions_delete_all_cb	(GtkWidget	*w,
-					 gpointer	 data);
-static void prefs_actions_clear_cb	(void);
-static void prefs_actions_duplicate_cb	(GtkWidget	*w,
-					 gpointer	 data);
+static void prefs_actions_delete_cb	(gpointer gtk_action, gpointer data);
+static void prefs_actions_delete_all_cb	(gpointer gtk_action, gpointer data);
+static void prefs_actions_clear_cb	(gpointer gtk_action, gpointer data);
+static void prefs_actions_duplicate_cb	(gpointer gtk_action, gpointer data);
 static void prefs_actions_up		(GtkWidget	*w,
 					 gpointer	 data);
 static void prefs_actions_down		(GtkWidget	*w,
@@ -108,6 +105,9 @@ static gint prefs_actions_deleted	(GtkWidget	*widget,
 static gboolean prefs_actions_key_pressed(GtkWidget	*widget,
 					  GdkEventKey	*event,
 					  gpointer	 data);
+static gboolean prefs_actions_search_func_cb (GtkTreeModel *model, gint column, 
+						const gchar *key, GtkTreeIter *iter, 
+						gpointer search_data);
 static void prefs_actions_cancel	(GtkWidget	*w,
 					 gpointer	 data);
 static void prefs_actions_ok		(GtkWidget	*w,
@@ -196,12 +196,10 @@ static void prefs_actions_create(MainWindow *mainwin)
 	GtkWidget *up_btn;
 	GtkWidget *down_btn;
 	static GdkGeometry geometry;
-	GtkTooltips *tooltips;
+	CLAWS_TIP_DECL();
 
 	debug_print("Creating actions configuration window...\n");
 
-	tooltips = gtk_tooltips_new();
-
 	window = gtkut_window_new(GTK_WINDOW_TOPLEVEL, "prefs_actions");
 
 	gtk_container_set_border_width(GTK_CONTAINER (window), 8);
@@ -324,32 +322,32 @@ static void prefs_actions_create(MainWindow *mainwin)
 	gtk_box_pack_start(GTK_BOX(btn_hbox), reg_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT(reg_btn), "clicked",
 			 G_CALLBACK(prefs_actions_register_cb), NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), reg_btn,
-			_("Append the new action above to the list"), NULL);
+	CLAWS_SET_TIP(reg_btn,
+			_("Append the new action above to the list"));
 
 	subst_btn = gtkut_get_replace_btn(_("Replace"));
 	gtk_widget_show(subst_btn);
 	gtk_box_pack_start(GTK_BOX(btn_hbox), subst_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT(subst_btn), "clicked",
 			 G_CALLBACK(prefs_actions_substitute_cb), NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), subst_btn,
-			_("Replace the selected action in list with the action above"), NULL);
+	CLAWS_SET_TIP(subst_btn,
+			_("Replace the selected action in list with the action above"));
 
 	del_btn = gtk_button_new_from_stock(GTK_STOCK_DELETE);
 	gtk_widget_show(del_btn);
 	gtk_box_pack_start(GTK_BOX(btn_hbox), del_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT(del_btn), "clicked",
 			 G_CALLBACK(prefs_actions_delete_cb), NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), del_btn,
-			_("Delete the selected action from the list"), NULL);
+	CLAWS_SET_TIP(del_btn,
+			_("Delete the selected action from the list"));
 
 	clear_btn = gtk_button_new_from_stock (GTK_STOCK_CLEAR);
 	gtk_widget_show (clear_btn);
 	gtk_box_pack_start (GTK_BOX (btn_hbox), clear_btn, FALSE, TRUE, 0);
 	g_signal_connect(G_OBJECT (clear_btn), "clicked",
 			G_CALLBACK(prefs_actions_clear_cb), NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), clear_btn,
-			_("Clear all the input fields in the dialog"), NULL);
+	CLAWS_SET_TIP(clear_btn,
+			_("Clear all the input fields in the dialog"));
 
 #if GTK_CHECK_VERSION(2, 8, 0)
 	info_btn = gtk_button_new_from_stock(GTK_STOCK_INFO);
@@ -360,8 +358,8 @@ static void prefs_actions_create(MainWindow *mainwin)
 	gtk_box_pack_end(GTK_BOX(reg_hbox), info_btn, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(info_btn), "clicked",
 			 G_CALLBACK(prefs_actions_info_cb), GTK_WINDOW(window));
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), info_btn,
-			_("Show information on configuring actions"), NULL);
+	CLAWS_SET_TIP(info_btn,
+			_("Show information on configuring actions"));
 
 	cond_hbox = gtk_hbox_new(FALSE, 8);
 	gtk_widget_show(cond_hbox);
@@ -391,16 +389,16 @@ static void prefs_actions_create(MainWindow *mainwin)
 	gtk_box_pack_start(GTK_BOX(btn_vbox), up_btn, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(up_btn), "clicked",
 			 G_CALLBACK(prefs_actions_up), NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), up_btn,
-			_("Move the selected action up"), NULL);
+	CLAWS_SET_TIP(up_btn,
+			_("Move the selected action up"));
 
 	down_btn = gtk_button_new_from_stock(GTK_STOCK_GO_DOWN);
 	gtk_widget_show(down_btn);
 	gtk_box_pack_start(GTK_BOX(btn_vbox), down_btn, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(down_btn), "clicked",
 			 G_CALLBACK(prefs_actions_down), NULL);
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltips), down_btn,
-			_("Move selected action down"), NULL);
+	CLAWS_SET_TIP(down_btn,
+			_("Move selected action down"));
 
 	if (!geometry.min_height) {
 		geometry.min_width = 486;
@@ -659,7 +657,7 @@ static gint prefs_actions_clist_set_row(gint row)
 		gchar *message;
 		message = g_markup_printf_escaped(_("The command\n%s\nhas a syntax error."),
 						entry_text);
-		alertpanel_error(message);
+		alertpanel_error("%s", message);
 		g_free(message);
 		return -1;
 	}
@@ -699,7 +697,7 @@ static void prefs_actions_substitute_cb(GtkWidget *w, gpointer data)
 	modified_list = TRUE;
 }
 
-static void prefs_actions_delete_cb(GtkWidget *w, gpointer data)
+static void prefs_actions_delete_cb(gpointer gtk_action, gpointer data)
 {
 	GtkTreeIter sel;
 	GtkTreeModel *model;
@@ -732,7 +730,7 @@ static void prefs_actions_delete_cb(GtkWidget *w, gpointer data)
 	modified_list = TRUE;
 }
 
-static void prefs_actions_delete_all_cb(GtkWidget *w, gpointer data)
+static void prefs_actions_delete_all_cb(gpointer gtk_action, gpointer data)
 {
 	GtkListStore *list_store;
 
@@ -749,7 +747,7 @@ static void prefs_actions_delete_all_cb(GtkWidget *w, gpointer data)
 	modified_list = TRUE;
 }
 
-static void prefs_actions_clear_cb(void)
+static void prefs_actions_clear_cb(gpointer gtk_action, gpointer data)
 {
 	gint row;
 
@@ -761,7 +759,7 @@ static void prefs_actions_clear_cb(void)
 		modified = TRUE;
 }
 
-static void prefs_actions_duplicate_cb(GtkWidget *w, gpointer data)
+static void prefs_actions_duplicate_cb(gpointer gtk_action, gpointer data)
 {
 	gint row;
 	
@@ -874,6 +872,28 @@ static gboolean prefs_actions_key_pressed(GtkWidget *widget, GdkEventKey *event,
 	return FALSE;
 }
 
+static gboolean prefs_actions_search_func_cb (GtkTreeModel *model, gint column, const gchar *key, 
+						GtkTreeIter *iter, gpointer search_data) 
+{
+	gchar *store_string;
+	gboolean retval;
+	GtkTreePath *path;
+
+	gtk_tree_model_get (model, iter, column, &store_string, -1);
+
+	if (!store_string || !key) return FALSE;
+
+
+	retval = (strncmp (key, store_string, strlen(key)) != 0);
+
+	g_free(store_string);
+	debug_print("selecting row\n");
+	path = gtk_tree_model_get_path(model, iter);
+	prefs_actions_select_row(GTK_TREE_VIEW(actions.actions_list_view), path);
+	gtk_tree_path_free(path);
+
+	return retval;
+}
 static void prefs_actions_cancel(GtkWidget *w, gpointer data)
 {
 	GtkListStore *store;
@@ -1058,14 +1078,15 @@ static void prefs_actions_list_view_insert_action(GtkWidget *list_view,
 	}
 }
 
-static GtkItemFactory *prefs_actions_popup_factory = NULL;
+static GtkActionGroup *prefs_actions_popup_action = NULL;
 static GtkWidget *prefs_actions_popup_menu = NULL;
 
-static GtkItemFactoryEntry prefs_actions_popup_entries[] =
+static GtkActionEntry prefs_actions_popup_entries[] =
 {
-   {N_("/_Delete"),		NULL, prefs_actions_delete_cb, 0, NULL, NULL},
-   {N_("/Delete _all"),	NULL, prefs_actions_delete_all_cb, 0, NULL, NULL},
-   {N_("/D_uplicate"),	NULL, prefs_actions_duplicate_cb, 0, NULL, NULL},
+ 	{"PrefsActionsPopup",			NULL, "PrefsActionsPopup" },
+	{"PrefsActionsPopup/Delete",		NULL, N_("_Delete"), NULL, NULL, G_CALLBACK(prefs_actions_delete_cb) },
+	{"PrefsActionsPopup/DeleteAll",	NULL, N_("Delete _all"), NULL, NULL, G_CALLBACK(prefs_actions_delete_all_cb) },
+	{"PrefsActionsPopup/Duplicate",	NULL, N_("D_uplicate"), NULL, NULL, G_CALLBACK(prefs_actions_duplicate_cb) },
 };
 
 static gint prefs_actions_list_btn_pressed(GtkWidget *widget, GdkEventButton *event,
@@ -1091,24 +1112,27 @@ static gint prefs_actions_list_btn_pressed(GtkWidget *widget, GdkEventButton *ev
 		   gint row;
 
 		   if (!prefs_actions_popup_menu) {
-			   gint n_entries = sizeof(prefs_actions_popup_entries) /
-					   sizeof(prefs_actions_popup_entries[0]);
-			   prefs_actions_popup_menu = menu_create_items(prefs_actions_popup_entries,
-								 n_entries, "<PrefsActionsPopupMenu>",
-								 &prefs_actions_popup_factory, list_view);
+				prefs_actions_popup_action = cm_menu_create_action_group("PrefsActionsPopup", prefs_actions_popup_entries,
+					G_N_ELEMENTS(prefs_actions_popup_entries), (gpointer)list_view);
+				MENUITEM_ADDUI("/Menus", "PrefsActionsPopup", "PrefsActionsPopup", GTK_UI_MANAGER_MENU)
+				MENUITEM_ADDUI("/Menus/PrefsActionsPopup", "Delete", "PrefsActionsPopup/Delete", GTK_UI_MANAGER_MENUITEM)
+				MENUITEM_ADDUI("/Menus/PrefsActionsPopup", "DeleteAll", "PrefsActionsPopup/DeleteAll", GTK_UI_MANAGER_MENUITEM)
+				MENUITEM_ADDUI("/Menus/PrefsActionsPopup", "Duplicate", "PrefsActionsPopup/Duplicate", GTK_UI_MANAGER_MENUITEM)
+				prefs_actions_popup_menu = gtk_menu_item_get_submenu(GTK_MENU_ITEM(
+					gtk_ui_manager_get_widget(gtkut_ui_manager(), "/Menus/PrefsActionsPopup")) );
 		   }
 
 		   /* grey out some popup menu items if there is no selected row */
 		   row = gtkut_list_view_get_selected_row(GTK_WIDGET(list_view));
-		   menu_set_sensitive(prefs_actions_popup_factory, "/Delete", (row > 0));
-		   menu_set_sensitive(prefs_actions_popup_factory, "/Duplicate", (row > 0));
+			cm_menu_set_sensitive("PrefsActionsPopup/Delete", (row > 0));
+			cm_menu_set_sensitive("PrefsActionsPopup/Duplicate", (row > 0));
 
 		   /* grey out seom popup menu items if there is no row
 			  (not counting the (New) one at row 0) */
 		   non_empty = gtk_tree_model_get_iter_first(model, &iter);
 		   if (non_empty)
 			   non_empty = gtk_tree_model_iter_next(model, &iter);
-		   menu_set_sensitive(prefs_actions_popup_factory, "/Delete all", non_empty);
+			cm_menu_set_sensitive("PrefsActionsPopup/DeleteAll", non_empty);
 
 		   gtk_menu_popup(GTK_MENU(prefs_actions_popup_menu), 
 					  NULL, NULL, NULL, NULL, 
@@ -1177,6 +1201,7 @@ static void prefs_actions_create_list_view_columns(GtkWidget *list_view)
 		 "text", PREFS_ACTIONS_STRING,
 		 NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(list_view), column);		
+	gtk_tree_view_set_search_equal_func(GTK_TREE_VIEW(list_view), prefs_actions_search_func_cb , NULL, NULL);
 }
 
 #define ENTRY_SET_TEXT(entry, str) \
@@ -1218,7 +1243,7 @@ static void prefs_actions_select_row(GtkTreeView *list_view, GtkTreePath *path)
 		return;
 
 	*cmd = '\0';
-	ENTRY_SET_TEXT(actions.name_entry, buf);
+	gtk_entry_set_text(GTK_ENTRY(actions.name_entry), buf);
 
 	if(g_str_has_prefix(&cmd[2], "%as{") == TRUE)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
