@@ -55,6 +55,7 @@ typedef struct _LoggingPage
 	GtkWidget *checkbtn_log_warning;
 	GtkWidget *checkbtn_log_error;
 	GtkWidget *checkbtn_log_status;
+#ifndef G_OS_WIN32
 	GtkWidget *checkbtn_clip_filtering_log;
 	GtkWidget *spinbtn_filtering_log_length;
 	GtkWidget *checkbtn_filtering_log;
@@ -64,6 +65,7 @@ typedef struct _LoggingPage
 	GtkWidget *checkbtn_filtering_log_pre_proc;
 	GtkWidget *checkbtn_filtering_log_post_proc;
 	GtkWidget *optmenu_filtering_log_level;
+#endif
 } LoggingPage;
 
 static GtkWidget *prefs_logging_create_check_buttons(GtkWidget **checkbtn1,
@@ -75,10 +77,10 @@ static GtkWidget *prefs_logging_create_check_buttons(GtkWidget **checkbtn1,
 	gtk_widget_show(hbox_checkbtn);
 	
 	PACK_CHECK_BUTTON (hbox_checkbtn, *checkbtn1, label1); 
-	gtk_label_set_line_wrap(GTK_LABEL(GTK_BIN(*checkbtn1)->child), TRUE);
+	gtk_label_set_line_wrap(GTK_LABEL(gtk_bin_get_child(GTK_BIN((*checkbtn1)))), TRUE);
 
 	PACK_CHECK_BUTTON (hbox_checkbtn, *checkbtn2, label2);
-	gtk_label_set_line_wrap(GTK_LABEL(GTK_BIN(*checkbtn2)->child), TRUE);
+	gtk_label_set_line_wrap(GTK_LABEL(gtk_bin_get_child(GTK_BIN((*checkbtn2)))), TRUE);
 	
 	return hbox_checkbtn;
 }
@@ -96,30 +98,29 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 	GtkWidget *checkbtn_clip_network_log;
 	GtkWidget *spinbtn_network_log_length;
 	GtkObject *spinbtn_network_log_length_adj;
-	GtkTooltips *network_log_length_tooltip;
+	GtkWidget *hbox_checkbtn;
+#ifndef G_OS_WIN32
 	GtkWidget *vbox1_filtering_log;
 	GtkWidget *hbox_clip_filtering_log;
 	GtkWidget *checkbtn_clip_filtering_log;
 	GtkWidget *spinbtn_filtering_log_length;
 	GtkObject *spinbtn_filtering_log_length_adj;
-	GtkTooltips *filtering_log_length_tooltip;
 	GtkWidget *hbox_filtering_log;
 	GtkWidget *checkbtn_filtering_log;
 	GtkWidget *frame_filtering_log;
 	GtkWidget *vbox2_filtering_log;
-	GtkWidget *hbox_checkbtn;
 	GtkWidget *checkbtn_filtering_log_inc;
 	GtkWidget *checkbtn_filtering_log_manual;
 	GtkWidget *checkbtn_filtering_log_folder_proc;
 	GtkWidget *checkbtn_filtering_log_pre_proc;
 	GtkWidget *checkbtn_filtering_log_post_proc;
-	GtkTooltips *filtering_log_tooltip;
 	GtkWidget *hbox_filtering_log_level;
 	GtkWidget *label_filtering_log_level;
 	GtkWidget *optmenu_filtering_log_level;
+	GtkSizeGroup *filter_size_group;
 	GtkListStore *menu;
 	GtkTreeIter iter;
-	GtkTooltips *filtering_log_level_tooltip;
+#endif
 	GtkWidget *frame_disk_log;
 	GtkWidget *vbox_disk_log;
 	GtkWidget *label;
@@ -129,7 +130,7 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 	GtkWidget *checkbtn_log_error;
 	GtkWidget *checkbtn_log_status;
 	GtkSizeGroup *log_size_group;
-	GtkSizeGroup *filter_size_group;
+	CLAWS_TIP_DECL();
 	
 	vbox1 = gtk_vbox_new (FALSE, VSPACING);
 	gtk_widget_show (vbox1);
@@ -145,8 +146,6 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 	PACK_CHECK_BUTTON (hbox_clip_network_log, checkbtn_clip_network_log,
 			   _("Restrict the log window to"));
 	
-	network_log_length_tooltip = gtk_tooltips_new();
-
 	spinbtn_network_log_length_adj = gtk_adjustment_new (500, 0, G_MAXINT, 1, 10, 10);
 	spinbtn_network_log_length = gtk_spin_button_new
 		(GTK_ADJUSTMENT (spinbtn_network_log_length_adj), 1, 0);
@@ -156,9 +155,8 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 	gtk_widget_set_size_request (GTK_WIDGET (spinbtn_network_log_length), 64, -1);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbtn_network_log_length), TRUE);
 
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(network_log_length_tooltip), spinbtn_network_log_length,
-			     _("0 to stop logging in the log window"),
-			     NULL);
+	CLAWS_SET_TIP(spinbtn_network_log_length,
+			     _("0 to stop logging in the log window"));
 
 	label = gtk_label_new(_("lines"));
 	gtk_widget_show (label);
@@ -167,6 +165,7 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 	SET_TOGGLE_SENSITIVITY(checkbtn_clip_network_log, spinbtn_network_log_length);
 	SET_TOGGLE_SENSITIVITY(checkbtn_clip_network_log, label);
 
+#ifndef G_OS_WIN32
 	/* Filtering/processing debug log */
 	vbox1_filtering_log = gtkut_get_options_frame(vbox1,
 				&frame_logging, _("Filtering/processing log"));
@@ -177,15 +176,12 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 	gtk_container_add (GTK_CONTAINER (vbox1_filtering_log), hbox_filtering_log);
 	gtk_widget_show (hbox_filtering_log);
 
-	filtering_log_tooltip = gtk_tooltips_new();
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(filtering_log_tooltip),
-			     checkbtn_filtering_log,
+	CLAWS_SET_TIP(checkbtn_filtering_log,
 			     _("If checked, turns on logging of filtering and processing rules.\n"
 				"The log is accessible from 'Tools/Filtering log'.\n"
 				"Caution: enabling this option will slow down the filtering/processing, "
 				"this might be critical when applying many rules upon thousands of "
-				"messages."),
-				NULL);
+				"messages."));
 
 	vbox2_filtering_log = gtkut_get_options_frame(vbox1_filtering_log, &frame_filtering_log,
 							_("Log filtering/processing when..."));
@@ -238,9 +234,7 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 
 	gtk_box_pack_start(GTK_BOX(hbox_filtering_log_level), optmenu_filtering_log_level, FALSE, FALSE, 0);
 
-	filtering_log_level_tooltip = gtk_tooltips_new();
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(filtering_log_level_tooltip),
-			     optmenu_filtering_log_level,
+	CLAWS_SET_TIP(optmenu_filtering_log_level,
 			     _("Select the level of detail of the logging.\n"
 				"Choose Low to see when rules are applied, which "
 				"conditions match or don't match and what actions are "
@@ -251,8 +245,7 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 				"rules are processed or skipped, and why all conditions "
 				"are matched or not matched.\n"
 				"Caution: the higher the level, the greater the "
-				"impact on performance."),
-			     NULL);
+				"impact on performance."));
 
 	hbox_clip_filtering_log = gtk_hbox_new (FALSE, 8);
 	gtk_container_add (GTK_CONTAINER (vbox1_filtering_log), hbox_clip_filtering_log);
@@ -260,8 +253,6 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 	PACK_CHECK_BUTTON (hbox_clip_filtering_log, checkbtn_clip_filtering_log,
 			   _("Restrict the log window to"));
 	
-	filtering_log_length_tooltip = gtk_tooltips_new();
-
 	spinbtn_filtering_log_length_adj = gtk_adjustment_new (500, 0, G_MAXINT, 1, 10, 10);
 	spinbtn_filtering_log_length = gtk_spin_button_new
 		(GTK_ADJUSTMENT (spinbtn_filtering_log_length_adj), 1, 0);
@@ -271,9 +262,8 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 	gtk_widget_set_size_request (GTK_WIDGET (spinbtn_filtering_log_length), 64, -1);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbtn_filtering_log_length), TRUE);
 
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(filtering_log_length_tooltip), spinbtn_filtering_log_length,
-			     _("0 to stop logging in the log window"),
-			     NULL);
+	CLAWS_SET_TIP(spinbtn_filtering_log_length,
+			     _("0 to stop logging in the log window"));
 
 	label = gtk_label_new(_("lines"));
 	gtk_widget_show (label);
@@ -285,7 +275,7 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 	SET_TOGGLE_SENSITIVITY(checkbtn_filtering_log, optmenu_filtering_log_level);
 	SET_TOGGLE_SENSITIVITY(checkbtn_filtering_log, checkbtn_clip_filtering_log);
 	SET_TOGGLE_SENSITIVITY(checkbtn_filtering_log, label_filtering_log_level);
-
+#endif
 	/* disk log */
 	vbox_disk_log = gtkut_get_options_frame(vbox1, &frame_disk_log, _("Disk log"));
 
@@ -312,8 +302,10 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_clip_network_log), 
 		prefs_common.cliplog);
+#ifndef G_OS_WIN32
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_clip_filtering_log), 
 		prefs_common.filtering_debug_cliplog);
+#endif
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_log_standard), 
 		prefs_common.enable_log_standard);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_log_warning), 
@@ -322,6 +314,7 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 		prefs_common.enable_log_error);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_log_status), 
 		prefs_common.enable_log_status);
+#ifndef G_OS_WIN32
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_filtering_log), 
 		prefs_common.enable_filtering_debug);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_filtering_log_inc), 
@@ -334,14 +327,15 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 		prefs_common.enable_filtering_debug_pre_proc);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_filtering_log_post_proc), 
 		prefs_common.enable_filtering_debug_post_proc);
-
+#endif
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbtn_network_log_length),
 		prefs_common.loglength);
+#ifndef G_OS_WIN32
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbtn_filtering_log_length),
 		prefs_common.filtering_debug_loglength);
-
 	combobox_select_by_data(GTK_COMBO_BOX(optmenu_filtering_log_level),
 			prefs_common.filtering_debug_level);
+#endif
 
 	prefs_logging->checkbtn_clip_network_log = checkbtn_clip_network_log;
 	prefs_logging->spinbtn_network_log_length = spinbtn_network_log_length;
@@ -349,6 +343,7 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 	prefs_logging->checkbtn_log_warning = checkbtn_log_warning;
 	prefs_logging->checkbtn_log_error = checkbtn_log_error;
 	prefs_logging->checkbtn_log_status = checkbtn_log_status;
+#ifndef G_OS_WIN32
 	prefs_logging->checkbtn_clip_filtering_log = checkbtn_clip_filtering_log;
 	prefs_logging->spinbtn_filtering_log_length = spinbtn_filtering_log_length;
 	prefs_logging->checkbtn_filtering_log = checkbtn_filtering_log;
@@ -358,7 +353,7 @@ static void prefs_logging_create_widget(PrefsPage *_page, GtkWindow *window,
 	prefs_logging->checkbtn_filtering_log_pre_proc = checkbtn_filtering_log_pre_proc;
 	prefs_logging->checkbtn_filtering_log_post_proc = checkbtn_filtering_log_post_proc;
 	prefs_logging->optmenu_filtering_log_level = optmenu_filtering_log_level;
-
+#endif
 	prefs_logging->page.widget = vbox1;
 }
 
@@ -366,10 +361,11 @@ static void prefs_logging_save(PrefsPage *_page)
 {
 	LoggingPage *page = (LoggingPage *) _page;
 	MainWindow *mainwindow;
+#ifndef G_OS_WIN32
 	gboolean filtering_debug_enabled;
-
 	prefs_common.filtering_debug_level =
 		combobox_get_active_data(GTK_COMBO_BOX(page->optmenu_filtering_log_level));
+#endif
 
 	prefs_common.cliplog = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_clip_network_log));
@@ -383,6 +379,7 @@ static void prefs_logging_save(PrefsPage *_page)
 		GTK_TOGGLE_BUTTON(page->checkbtn_log_error));
 	prefs_common.enable_log_status = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_log_status));
+#ifndef G_OS_WIN32
 	prefs_common.filtering_debug_cliplog = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_clip_filtering_log));
 	prefs_common.filtering_debug_loglength = gtk_spin_button_get_value_as_int(
@@ -406,12 +403,14 @@ static void prefs_logging_save(PrefsPage *_page)
 		GTK_TOGGLE_BUTTON(page->checkbtn_filtering_log_pre_proc));
 	prefs_common.enable_filtering_debug_post_proc = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_filtering_log_post_proc));
-
+#endif
 	mainwindow = mainwindow_get_mainwindow();
 	log_window_set_clipping(mainwindow->logwin, prefs_common.cliplog,
 				prefs_common.loglength);
+#ifndef G_OS_WIN32
 	log_window_set_clipping(mainwindow->filtering_debugwin, prefs_common.filtering_debug_cliplog,
 				prefs_common.filtering_debug_loglength);
+#endif
 }
 
 static void prefs_logging_destroy_widget(PrefsPage *_page)
