@@ -113,7 +113,6 @@ static void prefs_keybind_select(void)
 			       _("Default"),
 			       "Mew / Wanderlust",
 			       "Mutt",
-			       _("Old Sylpheed"),
 			       NULL);
 	gtk_box_pack_start (GTK_BOX (hbox1), combo, TRUE, TRUE, 0);
 
@@ -204,248 +203,196 @@ static void prefs_keybind_apply_clicked(GtkWidget *widget)
 	gint n_menurc;
 
 	static struct KeyBind default_menurc[] = {
-		{"<Main>/File/Empty all Trash folders",		"<shift>D"},
-		{"<Main>/File/Save as...",			"<control>S"},
-		{"<Main>/File/Print...",			"<control>P"},
-		{"<Main>/File/Work offline",			"<control>W"},
-		{"<Main>/File/Synchronise folders",		"<control><shift>S"},
-		{"<Main>/File/Exit",				"<control>Q"},
+		/* main */
+		{"<Actions>/Menu/File/EmptyTrashes",			"<shift>D"},
+		{"<Actions>/Menu/File/SaveAs",				"<control>S"},
+		{"<Actions>/Menu/File/Print",				"<control>P"},
+		{"<Actions>/Menu/File/OfflineMode",			"<control>W"},
+		{"<Actions>/Menu/File/SynchroniseFolders",		"<control><shift>S"},
+		{"<Actions>/Menu/File/Exit",				"<control>Q"},
 
-		{"<Main>/Edit/Copy",				"<control>C"},
-		{"<Main>/Edit/Select all",			"<control>A"},
-		{"<Main>/Edit/Find in current message...",	"<control>F"},
-		{"<Main>/Edit/Search folder...",		"<shift><control>F"},
-		{"<Main>/Edit/Quick search",			"slash"},
+		{"<Actions>/Menu/Edit/Copy",				"<control>C"},
+		{"<Actions>/Menu/Edit/SelectAll",			"<control>A"},
+		{"<Actions>/Menu/Edit/Find",				"<control>F"},
+		{"<Actions>/Menu/Edit/SearchFolder",			"<shift><control>F"},
+		{"<Actions>/Menu/Edit/QuickSearch",			"slash"},
 
-		{"<Main>/View/Show or hide/Message View",	"V"},
-		{"<Main>/View/Thread view",			"<control>T"},
-		{"<Main>/View/Go to/Previous message",		"P"},
-		{"<Main>/View/Go to/Next message",		"N"},
-		{"<Main>/View/Go to/Previous unread message",	"<shift>P"},
-		{"<Main>/View/Go to/Next unread message",	"<shift>N"},
-		{"<Main>/View/Go to/Other folder...",		"G"},
-		{"<Main>/View/Open in new window",		"<control><alt>N"},
-		{"<Main>/View/Message source",			"<control>U"},
-		{"<Main>/View/All headers",			"<control>H"},
-		{"<Main>/View/Update summary",			"<control><alt>U"},
+		{"<Actions>/Menu/View/ShowHide/MessageView",		"V"},
+		{"<Actions>/Menu/View/ThreadView",			"<control>T"},
+		{"<Actions>/Menu/View/GoTo/Prev",			"P"},
+		{"<Actions>/Menu/View/GoTo/Next",			"N"},
+		{"<Actions>/Menu/View/GoTo/PrevUnread",			"<shift>P"},
+		{"<Actions>/Menu/View/GoTo/NextUnread",			"<shift>N"},
+		{"<Actions>/Menu/View/GoTo/OtherFolder",		"G"},
+		{"<Actions>/Menu/View/OpenNewWindow",			"<control><alt>N"},
+		{"<Actions>/Menu/View/MessageSource",			"<control>U"},
+		{"<Actions>/Menu/View/AllHeaders",			"<control>H"},
+		{"<Actions>/Menu/View/UpdateSummary",			"<control><alt>U"},
 
-		{"<Main>/Message/Receive/Get from current account",
-								"<control>I"},
-		{"<Main>/Message/Receive/Get from all accounts","<shift><control>I"},
-		{"<Main>/Message/Compose an email message",	"<control>M"},
-		{"<Main>/Message/Reply",			"<control>R"},
-		{"<Main>/Message/Reply to/all",			"<shift><control>R"},
-		{"<Main>/Message/Reply to/sender",		""},
-		{"<Main>/Message/Reply to/mailing list",	"<control>L"},
-		{"<Main>/Message/Forward",			"<control><alt>F"},
-		/* {"<Main>/Message/Forward as attachment",	 ""}, */
-		{"<Main>/Message/Move...",			"<control>O"},
-		{"<Main>/Message/Copy...",			"<shift><control>O"},
-		{"<Main>/Message/Move to trash",		"<control>D"},
-		{"<Main>/Message/Mark/Mark",			"<shift>asterisk"},
-		{"<Main>/Message/Mark/Unmark",			"U"},
-		{"<Main>/Message/Mark/Mark as unread",		"<shift>exclam"},
-		{"<Main>/Message/Mark/Mark as read",		""},
+		{"<Actions>/Menu/Message/Receive/CurrentAccount",
+									"<control>I"},
+		{"<Actions>/Menu/Message/Receive/AllAccounts",		"<shift><control>I"},
+		{"<Actions>/Menu/Message/ComposeEmail",			"<control>M"},
+		{"<Actions>/Menu/Message/Reply",			"<control>R"},
+		{"<Actions>/Menu/Message/ReplyTo/All",			"<shift><control>R"},
+		{"<Actions>/Menu/Message/ReplyTo/Sender",		""},
+		{"<Actions>/Menu/Message/ReplyTo/List",			"<control>L"},
+		{"<Actions>/Menu/Message/Forward",			"<control><alt>F"},
+		{"<Actions>/Menu/Message/Move",				"<control>O"},
+		{"<Actions>/Menu/Message/Copy",				"<shift><control>O"},
+		{"<Actions>/Menu/Message/Trash",			"<control>D"},
+		{"<Actions>/Menu/Message/Mark/Mark",			"<shift>asterisk"},
+		{"<Actions>/Menu/Message/Mark/Unmark",			"U"},
+		{"<Actions>/Menu/Message/Mark/MarkUnread",		"<shift>exclam"},
+		{"<Actions>/Menu/Message/Mark/MarkRead",		""},
 
-		{"<Main>/Tools/Address book",			"<shift><control>A"},
-		{"<Main>/Tools/Execute",			"X"},
-		{"<Main>/Tools/Log window",			"<shift><control>L"},
-
-		{"<Compose>/Message/Send",				"<control>Return"},
-		{"<Compose>/Message/Send later",			"<shift><control>S"},
-		{"<Compose>/Message/Attach file",			"<control>M"},
-		{"<Compose>/Message/Insert file",			"<control>I"},
-		{"<Compose>/Message/Insert signature",			"<control>G"},
-		{"<Compose>/Message/Save",				"<control>S"},
-		{"<Compose>/Message/Close",				"<control>W"},
-		{"<Compose>/Edit/Undo",					"<control>Z"},
-		{"<Compose>/Edit/Redo",					"<control>Y"},
-		{"<Compose>/Edit/Cut",					"<control>X"},
-		{"<Compose>/Edit/Copy",					"<control>C"},
-		{"<Compose>/Edit/Paste",				"<control>V"},
-		{"<Compose>/Edit/Select all",				"<control>A"},
-		{"<Compose>/Edit/Advanced/Move a character backward",	"<control>B"},
-		{"<Compose>/Edit/Advanced/Move a character forward",	"<control>F"},
-		{"<Compose>/Edit/Advanced/Move a word backward,"	""},
-		{"<Compose>/Edit/Advanced/Move a word forward",		""},
-		{"<Compose>/Edit/Advanced/Move to beginning of line",	""},
-		{"<Compose>/Edit/Advanced/Move to end of line",		"<control>E"},
-		{"<Compose>/Edit/Advanced/Move to previous line",	"<control>P"},
-		{"<Compose>/Edit/Advanced/Move to next line",		"<control>N"},
-		{"<Compose>/Edit/Advanced/Delete a character backward",	"<control>H"},
-		{"<Compose>/Edit/Advanced/Delete a character forward",	"<control>D"},
-		{"<Compose>/Edit/Advanced/Delete a word backward",	""},
-		{"<Compose>/Edit/Advanced/Delete a word forward",	""},
-		{"<Compose>/Edit/Advanced/Delete line",			"<control>U"},
-		{"<Compose>/Edit/Advanced/Delete entire line",		""},
-		{"<Compose>/Edit/Advanced/Delete to end of line",	"<control>K"},
-		{"<Compose>/Edit/Wrap current paragraph",		"<control>L"},
-		{"<Compose>/Edit/Wrap all long lines",			"<control><alt>L"},
-		{"<Compose>/Edit/Auto wrapping",			"<shift><control>L"},
-		{"<Compose>/Edit/Edit with external editor",		"<shift><control>X"},
-		{"<Compose>/Tools/Address book",			"<shift><control>A"},
+		{"<Actions>/Menu/Tools/AddressBook",			"<shift><control>A"},
+		{"<Actions>/Menu/Tools/Execute",			"X"},
+		{"<Actions>/Menu/Tools/NetworkLog",			"<shift><control>L"},
+		/* compose */
+		{"<Actions>/Menu/Message/Send",				"<control>Return"},
+		{"<Actions>/Menu/Message/SendLater",			"<shift><control>S"},
+		{"<Actions>/Menu/Message/AttachFile",			"<control>M"},
+		{"<Actions>/Menu/Message/InsertFile",			"<control>I"},
+		{"<Actions>/Menu/Message/InsertSig",			"<control>G"},
+		{"<Actions>/Menu/Message/Save",				"<control>S"},
+		{"<Actions>/Menu/Message/Close",			"<control>W"},
+		{"<Actions>/Menu/Edit/Undo",				"<control>Z"},
+		{"<Actions>/Menu/Edit/Redo",				"<control>Y"},
+		{"<Actions>/Menu/Edit/Cut",				"<control>X"},
+		{"<Actions>/Menu/Edit/Copy",				"<control>C"},
+		{"<Actions>/Menu/Edit/Paste",				"<control>V"},
+		{"<Actions>/Menu/Edit/SelectAll",			"<control>A"},
+		{"<Actions>/Menu/Edit/Advanced/BackChar",		"<control>B"},
+		{"<Actions>/Menu/Edit/Advanced/ForwChar",		"<control>F"},
+		{"<Actions>/Menu/Edit/Advanced/BackWord",		""},
+		{"<Actions>/Menu/Edit/Advanced/ForwWord",		""},
+		{"<Actions>/Menu/Edit/Advanced/BegLine",		""},
+		{"<Actions>/Menu/Edit/Advanced/EndLine",		"<control>E"},
+		{"<Actions>/Menu/Edit/Advanced/PrevLine",		"<control>P"},
+		{"<Actions>/Menu/Edit/Advanced/NextLine",		"<control>N"},
+		{"<Actions>/Menu/Edit/Advanced/DelBackChar",		"<control>H"},
+		{"<Actions>/Menu/Edit/Advanced/DelForwChar",		"<control>D"},
+		{"<Actions>/Menu/Edit/Advanced/DelBackWord",		""},
+		{"<Actions>/Menu/Edit/Advanced/DelForwWord",		""},
+		{"<Actions>/Menu/Edit/Advanced/DelLine",		"<control>U"},
+		{"<Actions>/Menu/Edit/Advanced/DelEndLine",		"<control>K"},
+		{"<Actions>/Menu/Edit/WrapPara",			"<control>L"},
+		{"<Actions>/Menu/Edit/WrapAllLines",			"<control><alt>L"},
+		{"<Actions>/Menu/Edit/AutoWrap",			"<shift><control>L"},
+		{"<Actions>/Menu/Edit/ExtEditor",			"<shift><control>X"},
+		{"<Actions>/Menu/Tools/AddressBook",			"<shift><control>A"},
 	};
 
 	static struct KeyBind mew_wl_menurc[] = {
-		{"<Main>/File/Empty all Trash folders",		"<shift>D"},
-		{"<Main>/File/Save as...",			"Y"},
-		{"<Main>/File/Print...",			"<shift>numbersign"},
-		{"<Main>/File/Exit",				"<shift>Q"},
+		/* main */
+		{"<Actions>/Menu/File/EmptyTrashes",			"<shift>D"},
+		{"<Actions>/Menu/File/SaveAs",				"Y"},
+		{"<Actions>/Menu/File/Print",				"<control>numbersign"},
+		{"<Actions>/Menu/File/Exit",				"<shift>Q"},
 
-		{"<Main>/Edit/Copy",				"<control>C"},
-		{"<Main>/Edit/Select all",			"<control>A"},
-		{"<Main>/Edit/Find in current message...",	"<control>F"},
-		{"<Main>/Edit/Search folder...",		"<control>S"},
+		{"<Actions>/Menu/Edit/Copy",				"<control>C"},
+		{"<Actions>/Menu/Edit/SelectAll",			"<control>A"},
+		{"<Actions>/Menu/Edit/Find",				"<control>F"},
+		{"<Actions>/Menu/Edit/SearchFolder",			"<control>S"},
+		{"<Actions>/Menu/Edit/QuickSearch",			"slash"},
 
-		{"<Main>/View/Show or hide/Message View",	""},
-		{"<Main>/View/Thread view",			"<shift>T"},
-		{"<Main>/View/Go to/Previous message",		"P"},
-		{"<Main>/View/Go to/Next message",		"N"},
-		{"<Main>/View/Go to/Previous unread message",	"<shift>P"},
-		{"<Main>/View/Go to/Next unread message",	"<shift>N"},
-		{"<Main>/View/Go to/Other folder...",		"G"},
-		{"<Main>/View/Open in new window",		"<control><alt>N"},
-		{"<Main>/View/Message source",			"<control>U"},
-		{"<Main>/View/All headers",			"<shift>H"},
-		{"<Main>/View/Update summary",			"<shift>S"},
+		{"<Actions>/Menu/View/ShowHide/MessageView",		""},
+		{"<Actions>/Menu/View/ThreadView",			"<shift>T"},
+		{"<Actions>/Menu/View/GoTo/Prev",			"P"},
+		{"<Actions>/Menu/View/GoTo/Next",			"N"},
+		{"<Actions>/Menu/View/GoTo/PrevUnread",			"<shift>P"},
+		{"<Actions>/Menu/View/GoTo/NextUnread",			"<shift>N"},
+		{"<Actions>/Menu/View/GoTo/OtherFolder",		"G"},
+		{"<Actions>/Menu/View/OpenNewWindow",			"<control><alt>N"},
+		{"<Actions>/Menu/View/MessageSource",			"<control>U"},
+		{"<Actions>/Menu/View/AllHeaders",			"<shift>H"},
+		{"<Actions>/Menu/View/UpdateSummary",			"<shift>S"},
 
-		{"<Main>/Message/Receive/Get from current account",
-								"<control>I"},
-		{"<Main>/Message/Receive/Get from all accounts","<shift><control>I"},
-		{"<Main>/Message/Compose an email message",	"W"},
-		{"<Main>/Message/Reply",			"<control>R"},
-		{"<Main>/Message/Reply to/all",			"<shift>A"},
-		{"<Main>/Message/Reply to/sender",		""},
-		{"<Main>/Message/Reply to/mailing list",	"<control>L"},
-		{"<Main>/Message/Forward",			"F"},
-		/* {"<Main>/Message/Forward as attachment", "<shift>F"}, */
-		{"<Main>/Message/Move...",			"O"},
-		{"<Main>/Message/Copy...",			"<shift>O"},
-		{"<Main>/Message/Delete",			"D"},
-		{"<Main>/Message/Mark/Mark",			"<shift>asterisk"},
-		{"<Main>/Message/Mark/Unmark",			"U"},
-		{"<Main>/Message/Mark/Mark as unread",		"<shift>exclam"},
-		{"<Main>/Message/Mark/Mark as read",		"<shift>R"},
+		{"<Actions>/Menu/Message/Receive/CurrentAccount",
+									"<control>I"},
+		{"<Actions>/Menu/Message/Receive/AllAccounts",		"<shift><control>I"},
+		{"<Actions>/Menu/Message/ComposeEmail",			"W"},
+		{"<Actions>/Menu/Message/Reply",			"<control>R"},
+		{"<Actions>/Menu/Message/ReplyTo/All",			"<shift>A"},
+		{"<Actions>/Menu/Message/ReplyTo/Sender",		""},
+		{"<Actions>/Menu/Message/ReplyTo/List",			"<control>L"},
+		{"<Actions>/Menu/Message/Forward",			"F"},
+		{"<Actions>/Menu/Message/Move",				"O"},
+		{"<Actions>/Menu/Message/Copy",				"<shift>O"},
+		{"<Actions>/Menu/Message/Trash",			"D"},
+		{"<Actions>/Menu/Message/Mark/Mark",			"<shift>asterisk"},
+		{"<Actions>/Menu/Message/Mark/Unmark",			"U"},
+		{"<Actions>/Menu/Message/Mark/MarkUnread",		"<shift>exclam"},
+		{"<Actions>/Menu/Message/Mark/MarkRead",		"<shift>R"},
 
-		{"<Main>/Tools/Address book",			"<shift><control>A"},
-		{"<Main>/Tools/Execute",			"X"},
-		{"<Main>/Tools/Log window",			"<shift><control>L"},
-
-		{"<Compose>/Message/Close",				"<alt>W"},
-		{"<Compose>/Edit/Select all",				""},
-		{"<Compose>/Edit/Advanced/Move a word backward,"	"<alt>B"},
-		{"<Compose>/Edit/Advanced/Move a word forward",		"<alt>F"},
-		{"<Compose>/Edit/Advanced/Move to beginning of line",	"<control>A"},
-		{"<Compose>/Edit/Advanced/Delete a word backward",	"<control>W"},
-		{"<Compose>/Edit/Advanced/Delete a word forward",	"<alt>D"},
+		{"<Actions>/Menu/Tools/AddressBook",			"<shift><control>A"},
+		{"<Actions>/Menu/Tools/Execute",			"X"},
+		{"<Actions>/Menu/Tools/NetworkLog",			"<shift><control>L"},
+		/* compose */
+		{"<Actions>/Menu/Message/Close",			"<alt>W"},
+		{"<Actions>/Menu/Edit/SelectAll",			""},
+		{"<Actions>/Menu/Edit/Advanced/BackChar",		"<alt>B"},
+		{"<Actions>/Menu/Edit/Advanced/ForwChar",		"<alt>F"},
+		{"<Actions>/Menu/Edit/Advanced/BackWord",		""},
+		{"<Actions>/Menu/Edit/Advanced/ForwWord",		""},
+		{"<Actions>/Menu/Edit/Advanced/BegLine",		"<control>A"},
+		{"<Actions>/Menu/Edit/Advanced/DelBackWord",		"<control>W"},
+		{"<Actions>/Menu/Edit/Advanced/DelForwWord",		"<alt>D"},
 	};
 
 	static struct KeyBind mutt_menurc[] = {
-		{"<Main>/File/Empty all Trash folders",		""},
-		{"<Main>/File/Save as...",			"S"},
-		{"<Main>/File/Print...",			"P"},
-		{"<Main>/File/Exit",				"Q"},
+		/* main */
+		{"<Actions>/Menu/File/EmptyTrashes",			""},
+		{"<Actions>/Menu/File/SaveAs",				"S"},
+		{"<Actions>/Menu/File/Print",				"P"},
+		{"<Actions>/Menu/File/Exit",				"Q"},
 
-		{"<Main>/Edit/Copy",				"<control>C"},
-		{"<Main>/Edit/Select all",			"<control>A"},
-		{"<Main>/Edit/Find in current message...",	"<control>F"},
-		{"<Main>/Edit/Search messages...",		"slash"},
+		{"<Actions>/Menu/Edit/Copy",				"<control>C"},
+		{"<Actions>/Menu/Edit/SelectAll",			"<control>A"},
+		{"<Actions>/Menu/Edit/Find",				"<control>F"},
+		{"<Actions>/Menu/Edit/SearchFolder",			"/"},
 
-		{"<Main>/View/Show or hide/Message view",	"V"},
-		{"<Main>/View/Thread view",			"<control>T"},
-		{"<Main>/View/Go to/Previous message",		""},
-		{"<Main>/View/Go to/Next message",		""},
-		{"<Main>/View/Go to/Previous unread message",	""},
-		{"<Main>/View/Go to/Next unread message",	""},
-		{"<Main>/View/Go to/Other folder...",		"C"},
-		{"<Main>/View/Open in new window",		"<control><alt>N"},
-		{"<Main>/View/Message source",			"<control>U"},
-		{"<Main>/View/All headers",			"<control>H"},
-		{"<Main>/View/Update summary",			"<control><alt>U"},
+		{"<Actions>/Menu/View/ShowHide/MessageView",		"V"},
+		{"<Actions>/Menu/View/ThreadView",			"<control>T"},
+		{"<Actions>/Menu/View/GoTo/Prev",			""},
+		{"<Actions>/Menu/View/GoTo/Next",			""},
+		{"<Actions>/Menu/View/GoTo/PrevUnread",			""},
+		{"<Actions>/Menu/View/GoTo/NextUnread",			""},
+		{"<Actions>/Menu/View/GoTo/OtherFolder",		"C"},
+		{"<Actions>/Menu/View/OpenNewWindow",			"<control><alt>N"},
+		{"<Actions>/Menu/View/MessageSource",			"<control>U"},
+		{"<Actions>/Menu/View/AllHeaders",			"<control>H"},
+		{"<Actions>/Menu/View/UpdateSummary",			"<control><alt>U"},
 
-		{"<Main>/Message/Receive/Get from current account",
-								"<control>I"},
-		{"<Main>/Message/Receive/Get from all accounts","<shift><control>I"},
-		{"<Main>/Message/Compose an email message",		"M"},
-		{"<Main>/Message/Reply",			"R"},
-		{"<Main>/Message/Reply to/all",			"G"},
-		{"<Main>/Message/Reply to/sender",		""},
-		{"<Main>/Message/Reply to/mailing list",	"<control>L"},
-		{"<Main>/Message/Forward",			"F"},
-		{"<Main>/Message/Forward as attachment",	""},
-		{"<Main>/Message/Move...",			"<control>O"},
-		{"<Main>/Message/Copy...",			"<shift>C"},
-		{"<Main>/Message/Delete",			"D"},
-		{"<Main>/Message/Mark/Mark",			"<shift>F"},
-		{"<Main>/Message/Mark/Unmark",			"U"},
-		{"<Main>/Message/Mark/Mark as unread",		"<shift>N"},
-		{"<Main>/Message/Mark/Mark as read",		""},
+		{"<Actions>/Menu/Message/Receive/CurrentAccount",
+									"<control>I"},
+		{"<Actions>/Menu/Message/Receive/AllAccounts",		"<shift><control>I"},
+		{"<Actions>/Menu/Message/ComposeEmail",			"M"},
+		{"<Actions>/Menu/Message/Reply",			"R"},
+		{"<Actions>/Menu/Message/ReplyTo/All",			"G"},
+		{"<Actions>/Menu/Message/ReplyTo/Sender",		""},
+		{"<Actions>/Menu/Message/ReplyTo/List",			"<control>L"},
+		{"<Actions>/Menu/Message/Forward",			"F"},
+		{"<Actions>/Menu/Message/Move",				"<control>O"},
+		{"<Actions>/Menu/Message/Copy",				"<shift>C"},
+		{"<Actions>/Menu/Message/Trash",			"D"},
+		{"<Actions>/Menu/Message/Mark/Mark",			"<shift>F"},
+		{"<Actions>/Menu/Message/Mark/Unmark",			"U"},
+		{"<Actions>/Menu/Message/Mark/MarkUnread",		"<shift>N"},
+		{"<Actions>/Menu/Message/Mark/MarkRead",		""},
 
-		{"<Main>/Tools/Address book",			"<shift><control>A"},
-		{"<Main>/Tools/Execute",			"X"},
-		{"<Main>/Tools/Log window",			"<shift><control>L"},
-
-		{"<Compose>/Message/Close",				"<alt>W"},
-		{"<Compose>/Edit/Select all",				""},
-		{"<Compose>/Edit/Advanced/Move a word backward",	"<alt>B"},
-		{"<Compose>/Edit/Advanced/Move a word forward",		"<alt>F"},
-		{"<Compose>/Edit/Advanced/Move to beginning of line",	"<control>A"},
-		{"<Compose>/Edit/Advanced/Delete a word backward",	"<control>W"},
-		{"<Compose>/Edit/Advanced/Delete a word forward",	"<alt>D"},
-	};
-
-	static struct KeyBind old_sylpheed_menurc[] = {
-		{"<Main>/File/Empty all Trash folders",		""},
-		{"<Main>/File/Save as...",			""},
-		{"<Main>/File/Print...",			"<alt>P"},
-		{"<Main>/File/Exit",				"<alt>Q"},
-
-		{"<Main>/Edit/Copy",				"<control>C"},
-		{"<Main>/Edit/Select all",			"<control>A"},
-		{"<Main>/Edit/Find in current message...",	"<control>F"},
-		{"<Main>/Edit/Search folder...",		"<control>S"},
-
-		{"<Main>/View/Show or hide/Message View",	""},
-		{"<Main>/View/Thread view",			"<control>T"},
-		{"<Main>/View/Go to/Previous message",		"P"},
-		{"<Main>/View/Go to/Next message",		"N"},
-		{"<Main>/View/Go to/Previous unread message",	"<shift>P"},
-		{"<Main>/View/Go to/Next unread message",	"<shift>N"},
-		{"<Main>/View/Go to/Other folder...",		"<alt>G"},
-		{"<Main>/View/Open in new window",		"<shift><control>N"},
-		{"<Main>/View/Message source",			"<control>U"},
-		{"<Main>/View/All headers",			"<control>H"},
-		{"<Main>/View/Update summary",			"<alt>U"},
-
-		{"<Main>/Message/Receive/Get from current account",
-								"<alt>I"},
-		{"<Main>/Message/Receive/Get from all accounts","<shift><alt>I"},
-		{"<Main>/Message/Compose an email message",	"<alt>N"},
-		{"<Main>/Message/Reply",			"<alt>R"},
-		{"<Main>/Message/Reply to/all",			"<shift><alt>R"},
-		{"<Main>/Message/Reply to/sender",		"<control><alt>R"},
-		{"<Main>/Message/Reply to/mailing list",	"<control>L"},
-		{"<Main>/Message/Forward",			 "<shift><alt>F"},
-		/* "(menu-path \"<Main>/Message/Forward as attachment", "<shift><control>F"}, */
-		{"<Main>/Message/Move...",			"<alt>O"},
-		{"<Main>/Message/Copy...",			""},
-		{"<Main>/Message/Delete",			"<alt>D"},
-		{"<Main>/Message/Mark/Mark",			"<shift>asterisk"},
-		{"<Main>/Message/Mark/Unmark",			"U"},
-		{"<Main>/Message/Mark/Mark as unread",		"<shift>exclam"},
-		{"<Main>/Message/Mark/Mark as read",		""},
-
-		{"<Main>/Tools/Address book",			"<alt>A"},
-		{"<Main>/Tools/Execute",			"<alt>X"},
-		{"<Main>/Tools/Log window",			"<alt>L"},
-
-		{"<Compose>/Message/Close",				"<alt>W"},
-		{"<Compose>/Edit/Select all",				""},
-		{"<Compose>/Edit/Advanced/Move a word backward",	"<alt>B"},
-		{"<Compose>/Edit/Advanced/Move a word forward",		"<alt>F"},
-		{"<Compose>/Edit/Advanced/Move to beginning of line",	"<control>A"},
-		{"<Compose>/Edit/Advanced/Delete a word backward",	"<control>W"},
-		{"<Compose>/Edit/Advanced/Delete a word forward",	"<alt>D"},
+		{"<Actions>/Menu/Tools/AddressBook",			"<shift><control>A"},
+		{"<Actions>/Menu/Tools/Execute",			"X"},
+		{"<Actions>/Menu/Tools/NetworkLog",			"<shift><control>L"},
+		/* compose */
+		{"<Actions>/Menu/Message/Close",			"<alt>W"},
+		{"<Actions>/Menu/Edit/SelectAll",			""},
+		{"<Actions>/Menu/Edit/Advanced/BackWord",		"<alt>B"},
+		{"<Actions>/Menu/Edit/Advanced/ForwWord",		"<alt>F"},
+		{"<Actions>/Menu/Edit/Advanced/BegLine",		"<control>A"},
+		{"<Actions>/Menu/Edit/Advanced/DelBackWord",		"<control>W"},
+		{"<Actions>/Menu/Edit/Advanced/DelForwWord",		"<alt>D"},
 	};
 
 	text = gtk_combo_box_get_active_text(GTK_COMBO_BOX(keybind.combo));
@@ -459,16 +406,12 @@ static void prefs_keybind_apply_clicked(GtkWidget *widget)
 	} else if (!strcmp(text, "Mutt")) {
 		menurc = mutt_menurc;
 		n_menurc = G_N_ELEMENTS(mutt_menurc);
-	} else if (!strcmp(text, _("Old Sylpheed"))) {
-	        menurc = old_sylpheed_menurc;
-		n_menurc = G_N_ELEMENTS(old_sylpheed_menurc);
 	} else {
 		g_free(text);
 		return;
 	}
 	g_free(text);
 
-	/* prefs_keybind_apply(empty_menurc, G_N_ELEMENTS(empty_menurc)); */
 	prefs_keybind_apply(menurc, n_menurc);
 
 	gtk_widget_destroy(keybind.window);
@@ -649,7 +592,6 @@ static void prefs_other_save(PrefsPage *_page)
 {
 	OtherPage *page = (OtherPage *) _page;
 	gboolean gtk_can_change_accels;
-	GList * list = NULL;
 
 	prefs_common.add_address_by_click = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_addaddrbyclick));
