@@ -64,7 +64,7 @@ typedef struct _SummariesPage
 	GtkWidget *entry_datefmt;
 
 	GtkWidget *checkbtn_reopen_last_folder;
-	GtkWidget *checkbtn_always_show_msg;
+	GtkWidget *optmenu_always_show_msg;
 	GtkWidget *checkbtn_mark_as_read_on_newwin;
 	GtkWidget *spinbtn_mark_as_read_delay;
 	GtkWidget *checkbtn_immedexec;
@@ -221,7 +221,7 @@ static GtkWidget *date_format_create(GtkButton *button, void *data)
 			 NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(datefmt_list_view), column);
 	
-	/* gtk_clist_set_column_width(GTK_CLIST(datefmt_clist), 0, 80); */
+	/* gtk_cmclist_set_column_width(GTK_CMCLIST(datefmt_clist), 0, 80); */
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(datefmt_list_view));
 	gtk_tree_selection_set_mode(selection, GTK_SELECTION_BROWSE);
 
@@ -327,18 +327,15 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	GtkWidget *label_datefmt;
 	GtkWidget *button_datefmt;
 	GtkWidget *entry_datefmt;
-	GtkTooltips *tip_datefmt;
 	GtkWidget *hbox_dispitem;
 	GtkWidget *button_dispitem;
-
 	GtkWidget *hbox2;
 	GtkWidget *checkbtn_reopen_last_folder;
-	GtkWidget *checkbtn_always_show_msg;
+	GtkWidget *optmenu_always_show_msg;
 	GtkWidget *spinbtn_mark_as_read_delay;
 	GtkObject *spinbtn_mark_as_read_delay_adj;
 	GtkWidget *checkbtn_immedexec;
 	GtkWidget *checkbtn_ask_mark_all_read;
-	GtkTooltips *immedexec_tooltip;
 	GtkWidget *label, *label_fill;
 	GtkListStore *menu;
 	GtkTreeIter iter;
@@ -348,10 +345,7 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	GtkWidget *button_edit_actions;
 	GtkWidget *radio_mark_as_read_on_select;
 	GtkWidget *radio_mark_as_read_on_new_win;
-
-	GtkTooltips *tooltips;
-
-	tooltips = gtk_tooltips_new();
+	CLAWS_TIP_DECL();
 
 	vbox1 = gtk_vbox_new (FALSE, VSPACING);
 	gtk_widget_show (vbox1);
@@ -453,22 +447,34 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 
 	gtk_box_pack_start(GTK_BOX(hbox1), optmenu_nextunreadmsgdialog, FALSE, FALSE, 0);
 
-	PACK_CHECK_BUTTON
-		(vbox2, checkbtn_always_show_msg,
-		 _("Always open message when selected"));
+	/* Open message on select policy */
+	hbox1 = gtk_hbox_new (FALSE, 10);
+	gtk_widget_show (hbox1);
+	gtk_box_pack_start (GTK_BOX (vbox2), hbox1, FALSE, FALSE, 0);	
+	label = gtk_label_new (_("Open message when selected"));
+	gtk_widget_show (label);
+	gtk_box_pack_start(GTK_BOX(hbox1), label, FALSE, FALSE, 0);
+
+	optmenu_always_show_msg = gtkut_sc_combobox_create(NULL, FALSE);
+	menu = GTK_LIST_STORE(gtk_combo_box_get_model(
+				GTK_COMBO_BOX(optmenu_always_show_msg)));
+	gtk_widget_show (optmenu_always_show_msg);
+	COMBOBOX_ADD (menu, _("Never"), OPENMSG_REQUEST_ONLY);
+	COMBOBOX_ADD (menu, _("Always"), OPENMSG_ALWAYS);
+	COMBOBOX_ADD (menu, _("When message view is visible"),
+			OPENMSG_WHEN_VIEW_VISIBLE);
+	gtk_box_pack_start(GTK_BOX(hbox1), optmenu_always_show_msg, FALSE, FALSE, 0);
+
 	PACK_CHECK_BUTTON
 		(vbox2, checkbtn_threadsubj,
 		 _("Thread using subject in addition to standard headers"));
 
-	immedexec_tooltip = gtk_tooltips_new();
-
 	PACK_CHECK_BUTTON
 		(vbox2, checkbtn_immedexec,
 		 _("Execute immediately when moving or deleting messages"));
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(immedexec_tooltip), checkbtn_immedexec,
+	CLAWS_SET_TIP(checkbtn_immedexec,
 			     _("Defers moving, copying and deleting of messages"
-		   	       " until you choose 'Tools/Execute'"),
-			     NULL);
+		   	       " until you choose 'Tools/Execute'"));
 
 	vbox3 = gtkut_get_options_frame(vbox2, NULL, _("Mark message as read"));
 
@@ -536,10 +542,8 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	label_fill = gtk_label_new(" ");
 	gtk_box_pack_start(GTK_BOX(hbox2), label_fill, TRUE, FALSE, 0);
 	
-	tip_datefmt = gtk_tooltips_new();
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tip_datefmt),
-			     button_datefmt,
-			     _("Date format help"), NULL);
+	CLAWS_SET_TIP(button_datefmt,
+			     _("Date format help"));
 			     
 	hbox_dispitem = gtk_hbox_new (FALSE, 8);
 	gtk_widget_show (hbox_dispitem);
@@ -561,9 +565,9 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	PACK_CHECK_BUTTON
 		(vbox1, checkbtn_transhdr,
 		 _("Translate header names"));
-	gtk_tooltips_set_tip(tooltips, checkbtn_transhdr,
+	CLAWS_SET_TIP(checkbtn_transhdr,
 			     _("The display of standard headers (such as 'From:', 'Subject:') "
-			     "will be translated into your language."), NULL);
+			     "will be translated into your language."));
 	
 	hbox2 = gtk_hbox_new (FALSE, 8);
 	gtk_widget_show (hbox2);
@@ -592,7 +596,7 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_reopen_last_folder),
 			prefs_common.goto_last_folder_on_startup);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_always_show_msg),
+	combobox_select_by_data(GTK_COMBO_BOX(optmenu_always_show_msg),
 			prefs_common.always_show_msg);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_mark_as_read_on_new_win),
 			prefs_common.mark_as_read_on_new_window);
@@ -615,7 +619,7 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	prefs_summaries->entry_datefmt = entry_datefmt;
 
 	prefs_summaries->checkbtn_reopen_last_folder = checkbtn_reopen_last_folder;
-	prefs_summaries->checkbtn_always_show_msg = checkbtn_always_show_msg;
+	prefs_summaries->optmenu_always_show_msg = optmenu_always_show_msg;
 	prefs_summaries->checkbtn_mark_as_read_on_newwin = radio_mark_as_read_on_new_win;
 	prefs_summaries->spinbtn_mark_as_read_delay = spinbtn_mark_as_read_delay;
 	prefs_summaries->checkbtn_immedexec = checkbtn_immedexec;
@@ -651,8 +655,8 @@ static void prefs_summaries_save(PrefsPage *_page)
 
 	prefs_common.goto_last_folder_on_startup = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_reopen_last_folder));
-	prefs_common.always_show_msg = gtk_toggle_button_get_active(
-		GTK_TOGGLE_BUTTON(page->checkbtn_always_show_msg));
+	prefs_common.always_show_msg = combobox_get_active_data(
+		GTK_COMBO_BOX(page->optmenu_always_show_msg));
 	prefs_common.mark_as_read_on_new_window = gtk_toggle_button_get_active(
 		GTK_TOGGLE_BUTTON(page->checkbtn_mark_as_read_on_newwin));
 	prefs_common.immediate_exec = gtk_toggle_button_get_active(
