@@ -30,7 +30,6 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <gtk/gtkoptionmenu.h>
 #include <gdk/gdkkeysyms.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -141,6 +140,7 @@ static const gint ToolbarIcons[] =
 	STOCK_PIXMAP_HAM_BTN,
 	STOCK_PIXMAP_TRASH,
 	STOCK_PIXMAP_DELETE,
+	STOCK_PIXMAP_CANCEL,
 	STOCK_PIXMAP_EMPTY,              /* last entry */
 };
 
