@@ -436,7 +436,7 @@ gboolean procmime_decode_content(MimeInfo *mimeinfo)
 		return FALSE;
 	}
 
-	stat(tmpfilename, &statbuf);
+	g_stat(tmpfilename, &statbuf);
 	if (mimeinfo->tmp && (mimeinfo->data.filename != NULL))
 		claws_unlink(mimeinfo->data.filename);
 	g_free(mimeinfo->data.filename);
@@ -586,7 +586,7 @@ gboolean procmime_encode_content(MimeInfo *mimeinfo, EncodingType encoding)
 			g_free(mimeinfo->data.mem);
 	}
 
-	stat(tmpfilename, &statbuf);
+	g_stat(tmpfilename, &statbuf);
 	mimeinfo->content = MIMECONTENT_FILE;
 	mimeinfo->data.filename = tmpfilename;
 	mimeinfo->tmp = TRUE;
@@ -691,6 +691,9 @@ static FILE *procmime_get_text_content(MimeInfo *mimeinfo)
 		      ? forced_charset : 
 		      procmime_mimeinfo_get_parameter(mimeinfo, "charset");
 
+	if (!forced_charset && src_codeset && !strcasecmp(src_codeset, CS_ISO_8859_1))
+		src_codeset = CS_WINDOWS_1252;
+
 	if (mimeinfo->type == MIMETYPE_TEXT && !g_ascii_strcasecmp(mimeinfo->subtype, "html")) {
 		SC_HTMLParser *parser;
 		CodeConverter *conv;
@@ -841,6 +844,8 @@ FILE *procmime_get_first_encrypted_text_content(MsgInfo *msginfo)
 	partinfo = mimeinfo;
 	while (partinfo && partinfo->type != MIMETYPE_TEXT) {
 		partinfo = procmime_mimeinfo_next(partinfo);
+		if (privacy_mimeinfo_is_signed(partinfo))
+			procmsg_msginfo_set_flags(msginfo, 0, MSG_SIGNED);
 	}
 
 	if (partinfo)
@@ -986,12 +991,11 @@ gchar *procmime_get_mime_type(const gchar *filename)
 
 	base = g_path_get_basename(filename);
 	if ((p = strrchr(base, '.')) != NULL)
-		Xstrdup_a(ext, p + 1, p = NULL );
+		ext = g_utf8_strdown(p + 1, -1);
 	g_free(base);
-	if (!p) return NULL;
 
-	g_strdown(ext);
 	mime_type = g_hash_table_lookup(mime_type_table, ext);
+	g_free(ext);
 	if (mime_type) {
 		gchar *str;
 
@@ -1048,8 +1052,6 @@ static GHashTable *procmime_get_mime_type_table(void)
 
 		exts = g_strsplit(mime_type->extension, " ", 16);
 		for (i = 0; exts[i] != NULL; i++) {
-			/* make the key case insensitive */
-			g_strdown(exts[i]);
 			/* use previously dup'd key on overwriting */
 			if (g_hash_table_lookup(table, exts[i]))
 				key = exts[i];
@@ -1125,7 +1127,7 @@ GList *procmime_get_mime_type_list(void)
 		}
 
 		if (*p)
-			mime_type->extension = g_strdup(p);
+			mime_type->extension = g_utf8_strdown(p, -1);
 		else
 			mime_type->extension = NULL;
 
@@ -1586,7 +1588,7 @@ static void parse_parameters(const gchar *parameters, GHashTable *table)
 	param = params;
 	next = params;
 	for (; next != NULL; param = next) {
-		gchar *attribute, *value, *tmp;
+		gchar *attribute, *value, *tmp, *down_attr, *orig_down_attr;
 		gint len;
 		gboolean convert = FALSE;
 
@@ -1608,14 +1610,15 @@ static void parse_parameters(const gchar *parameters, GHashTable *table)
 		while (value[0] == ' ')
 			value++;
 
-		g_strdown(attribute);
-
-		len = strlen(attribute);
-		if (attribute[len - 1] == '*') {
+		down_attr = g_utf8_strdown(attribute, -1);
+		orig_down_attr = down_attr;
+	
+		len = strlen(down_attr);
+		if (down_attr[len - 1] == '*') {
 			gchar *srcpos, *dstpos, *endpos;
 
 			convert = TRUE;
-			attribute[len - 1] = '\0';
+			down_attr[len - 1] = '\0';
 
 			srcpos = value;
 			dstpos = value;
@@ -1643,11 +1646,11 @@ static void parse_parameters(const gchar *parameters, GHashTable *table)
 				*tmp = '\0';
 		}
 
-		if (attribute) {
-			while (attribute[0] == ' ')
-				attribute++;
-			while (attribute[strlen(attribute)-1] == ' ') 
-				attribute[strlen(attribute)-1] = '\0';
+		if (down_attr) {
+			while (down_attr[0] == ' ')
+				down_attr++;
+			while (down_attr[strlen(down_attr)-1] == ' ') 
+				down_attr[strlen(down_attr)-1] = '\0';
 		} 
 		if (value) {
 			while (value[0] == ' ')
@@ -1655,28 +1658,29 @@ static void parse_parameters(const gchar *parameters, GHashTable *table)
 			while (value[strlen(value)-1] == ' ') 
 				value[strlen(value)-1] = '\0';
 		}		
-		if (strrchr(attribute, '*') != NULL) {
+		if (strrchr(down_attr, '*') != NULL) {
 			gchar *tmpattr;
 
-			tmpattr = g_strdup(attribute);
+			tmpattr = g_strdup(down_attr);
 			tmp = strrchr(tmpattr, '*');
 			tmp[0] = '\0';
 
 			if ((tmp[1] == '0') && (tmp[2] == '\0') && 
-			    (g_slist_find_custom(concatlist, attribute, g_str_equal) == NULL))
+			    (g_slist_find_custom(concatlist, down_attr, g_str_equal) == NULL))
 				concatlist = g_slist_prepend(concatlist, g_strdup(tmpattr));
 
-			if (convert && (g_slist_find_custom(convlist, attribute, g_str_equal) == NULL))
+			if (convert && (g_slist_find_custom(convlist, down_attr, g_str_equal) == NULL))
 				convlist = g_slist_prepend(convlist, g_strdup(tmpattr));
 
 			g_free(tmpattr);
 		} else if (convert) {
-			if (g_slist_find_custom(convlist, attribute, g_str_equal) == NULL)
-				convlist = g_slist_prepend(convlist, g_strdup(attribute));
+			if (g_slist_find_custom(convlist, down_attr, g_str_equal) == NULL)
+				convlist = g_slist_prepend(convlist, g_strdup(down_attr));
 		}
 
-		if (g_hash_table_lookup(table, attribute) == NULL)
-			g_hash_table_insert(table, g_strdup(attribute), g_strdup(value));
+		if (g_hash_table_lookup(table, down_attr) == NULL)
+			g_hash_table_insert(table, g_strdup(down_attr), g_strdup(value));
+		g_free(orig_down_attr);
 	}
 
 	for (cur = concatlist; cur != NULL; cur = g_slist_next(cur)) {
@@ -2003,7 +2007,7 @@ static MimeInfo *procmime_scan_file_with_offset(const gchar *filename, int offse
 	MimeInfo *mimeinfo;
 	struct stat buf;
 
-	stat(filename, &buf);
+	g_stat(filename, &buf);
 
 	mimeinfo = procmime_mimeinfo_new();
 	mimeinfo->content = MIMECONTENT_FILE;
