@@ -25,9 +25,7 @@
 
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 #include <stdio.h>
 #include <string.h>
 #include <signal.h>
@@ -232,7 +230,7 @@ gint send_message_smtp_full(PrefsAccount *ac_prefs, GSList *to_list, FILE *fp, g
 
 	if (!ac_prefs->session) {
 		/* we can't reuse a previously initialised session */
-		session = smtp_session_new();
+		session = smtp_session_new(ac_prefs);
 		smtp_session = SMTP_SESSION(session);
 
 		if (ac_prefs->set_domain && ac_prefs->domain && strlen(ac_prefs->domain)) {
@@ -248,39 +246,31 @@ gint send_message_smtp_full(PrefsAccount *ac_prefs, GSList *to_list, FILE *fp, g
 				if (ac_prefs->smtp_passwd)
 					smtp_session->pass =
 						g_strdup(ac_prefs->smtp_passwd);
-				else if (ac_prefs->tmp_smtp_pass)
-					smtp_session->pass =
-						g_strdup(ac_prefs->tmp_smtp_pass);
 				else {
 					smtp_session->pass =
-						input_dialog_query_password
+						input_dialog_query_password_keep
 							(ac_prefs->smtp_server,
-							 smtp_session->user);
+							 smtp_session->user,
+							 &(ac_prefs->session_smtp_passwd));
 					if (!smtp_session->pass) {
 						session_destroy(session);
 						return -1;
 					}
-					ac_prefs->tmp_smtp_pass =
-						g_strdup(smtp_session->pass);
 				}
 			} else {
 				smtp_session->user = g_strdup(ac_prefs->userid);
 				if (ac_prefs->passwd)
 					smtp_session->pass = g_strdup(ac_prefs->passwd);
-				else if (ac_prefs->tmp_pass)
-					smtp_session->pass =
-						g_strdup(ac_prefs->tmp_pass);
 				else {
 					smtp_session->pass =
-						input_dialog_query_password
+						input_dialog_query_password_keep
 							(ac_prefs->smtp_server,
-							 smtp_session->user);
+							 smtp_session->user,
+							 &(ac_prefs->session_smtp_passwd));
 					if (!smtp_session->pass) {
 						session_destroy(session);
 						return -1;
 					}
-					ac_prefs->tmp_pass =
-						g_strdup(smtp_session->pass);
 				}
 			}
 		} else {
@@ -383,12 +373,9 @@ gint send_message_smtp_full(PrefsAccount *ac_prefs, GSList *to_list, FILE *fp, g
 		gtk_main_iteration();
 
 	if (SMTP_SESSION(session)->error_val == SM_AUTHFAIL) {
-		if (ac_prefs->smtp_userid && ac_prefs->tmp_smtp_pass) {
-			g_free(ac_prefs->tmp_smtp_pass);
-			ac_prefs->tmp_smtp_pass = NULL;
-		} else if (ac_prefs->tmp_pass) {
-			g_free(ac_prefs->tmp_pass);
-			ac_prefs->tmp_pass = NULL;
+		if (ac_prefs->session_smtp_passwd) {
+			g_free(ac_prefs->session_smtp_passwd);
+			ac_prefs->session_smtp_passwd = NULL;
 		}
 		ret = -1;
 	} else if (SMTP_SESSION(session)->state == SMTP_MAIL_SENT_OK) {
