@@ -22,7 +22,7 @@
 #endif
 
 #if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
