@@ -19,8 +19,7 @@
 
 #include "defs.h"
 #include <glib.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkimage.h>
+#include <gtk/gtk.h>
 #include <string.h>
 #include <dirent.h>
 
@@ -50,6 +49,7 @@
 #include "pixmaps/interface.xpm"
 #include "pixmaps/jpilot.xpm"
 #include "pixmaps/key.xpm"
+#include "pixmaps/key_gpg_signed.xpm"
 #include "pixmaps/ldap.xpm"
 #include "pixmaps/linewrap.xpm"
 #include "pixmaps/linewrapcurrent.xpm"
@@ -275,6 +275,7 @@ static StockPixmapData pixmaps[] =
 	{interface_xpm				, NULL, NULL, "interface", NULL},
 	{jpilot_xpm				, NULL, NULL, "jpilot", NULL},
 	{key_xpm				, NULL, NULL, "key", NULL},
+	{key_gpg_signed_xpm			, NULL, NULL, "key_gpg_signed_xpm", NULL},
 	{ldap_xpm				, NULL, NULL, "ldap", NULL},
 	{linewrapcurrent_xpm			, NULL, NULL, "linewrapcurrent", NULL},
 	{linewrap_xpm				, NULL, NULL, "linewrap", NULL},
@@ -366,7 +367,7 @@ static StockPixmapData pixmaps[] =
 	{claws_mail_icon_xpm			, NULL, NULL, "claws_mail_icon", NULL},
 	{read_xpm				, NULL, NULL, "read", NULL},
 	{delete_btn_xpm				, NULL, NULL, "delete_btn", NULL},
-	{cancel_xpm				, NULL, NULL, "cancel_btn", NULL},
+	{cancel_xpm				, NULL, NULL, "cancel", NULL},
 	{trash_btn_xpm				, NULL, NULL, "trash_btn", NULL},
 #ifndef GENERIC_UMPC
 	{claws_mail_logo_xpm			, NULL, NULL, "claws_mail_logo", NULL},
@@ -381,15 +382,15 @@ static StockPixmapData pixmaps[] =
 	{copied_xpm				, NULL, NULL, "copied", NULL},
 	{selection_xpm				, NULL, NULL, "selection", NULL},
 	{watchthread_xpm			, NULL, NULL, "watchthread", NULL},
-	{tray_newmail_offline_xpm		, NULL, NULL, "tray_newmail_offline", NULL},
+	{tray_newmail_offline_xpm		, NULL, NULL, "tray_newmail.offline", NULL},
 	{tray_newmail_xpm			, NULL, NULL, "tray_newmail", NULL},
-	{tray_newmarkedmail_offline_xpm		, NULL, NULL, "tray_newmarkedmail_offline", NULL},
+	{tray_newmarkedmail_offline_xpm		, NULL, NULL, "tray_newmarkedmail.offline", NULL},
 	{tray_newmarkedmail_xpm			, NULL, NULL, "tray_newmarkedmail", NULL},
-	{tray_nomail_offline_xpm		, NULL, NULL, "tray_nomail_offline", NULL},
+	{tray_nomail_offline_xpm		, NULL, NULL, "tray_nomail.offline", NULL},
 	{tray_nomail_xpm			, NULL, NULL, "tray_nomail", NULL},
-	{tray_unreadmail_offline_xpm		, NULL, NULL, "tray_unreadmail_offline", NULL},
+	{tray_unreadmail_offline_xpm		, NULL, NULL, "tray_unreadmail.offline", NULL},
 	{tray_unreadmail_xpm			, NULL, NULL, "tray_unreadmail", NULL},
-	{tray_unreadmarkedmail_offline_xpm	, NULL, NULL, "tray_unreadmarkedmail_offline", NULL},
+	{tray_unreadmarkedmail_offline_xpm	, NULL, NULL, "tray_unreadmarkedmail.offline", NULL},
 	{tray_unreadmarkedmail_xpm		, NULL, NULL, "tray_unreadmarkedmail", NULL},
         {empty_xpm                              , NULL, NULL, "empty" , NULL}
 };
@@ -878,7 +879,7 @@ GtkWidget *stock_pixmap_widget_with_overlay(GtkWidget *window, StockPixmap icon,
 	data->highlight = FALSE;
 
 	widget = gtk_drawing_area_new();
-	gtk_drawing_area_size(GTK_DRAWING_AREA(widget), data->base_width + border_x * 2, 
+	gtk_widget_set_size_request(widget, data->base_width + border_x * 2, 
 			      data->base_height + border_y * 2);
 	g_signal_connect(G_OBJECT(widget), "expose_event", 
 			 G_CALLBACK(pixmap_with_overlay_expose_event_cb), data);
