@@ -26,18 +26,8 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkoptionmenu.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkhbbox.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkctree.h>
+#include <gtk/gtk.h>
+#include "gtk/gtksctree.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -146,14 +136,21 @@ static gboolean key_pressed		(GtkWidget	*widget,
 					 gpointer	 data);
 #endif
 
-#define GTK_BUTTON_SET_SENSITIVE(widget,sensitive) {	\
+#if !GTK_CHECK_VERSION(2,14,0)
+/* Work around http://bugzilla.gnome.org/show_bug.cgi?id=56070 */
+#define GTK_BUTTON_SET_SENSITIVE(widget,sensitive) {					\
 	gboolean in_btn = FALSE;							\
 	if (GTK_IS_BUTTON(widget))							\
-		in_btn = GTK_BUTTON(widget)->in_button;			\
-	gtk_widget_set_sensitive(widget, sensitive);		\
+		in_btn = GTK_BUTTON(widget)->in_button;					\
+	gtk_widget_set_sensitive(widget, sensitive);					\
 	if (GTK_IS_BUTTON(widget))							\
-		GTK_BUTTON(widget)->in_button = in_btn;			\
+		GTK_BUTTON(widget)->in_button = in_btn;					\
 }
+#else
+#define GTK_BUTTON_SET_SENSITIVE(widget,sensitive) {					\
+	gtk_widget_set_sensitive(widget, sensitive);					\
+}
+#endif
 
 void summary_search(SummaryView *summaryview)
 {
@@ -222,9 +219,8 @@ static void summary_search_create(void)
 	GtkWidget *next_btn;
 	GtkWidget *close_btn;
 	GtkWidget *stop_btn;
-	GtkTooltips *tooltip;
-
 	gboolean is_searching = FALSE;
+	CLAWS_TIP_DECL();
 
 	window = gtkut_window_new(GTK_WINDOW_TOPLEVEL, "summary_search");
 	gtk_window_set_title(GTK_WINDOW (window), _("Search messages"));
@@ -278,9 +274,9 @@ static void summary_search_create(void)
 			  GTK_EXPAND|GTK_FILL, 0, 0, 0);
 	g_signal_connect(G_OBJECT(from_entry), "changed",
 			 G_CALLBACK(from_changed), NULL);
-	g_signal_connect(G_OBJECT(GTK_BIN(from_entry)->child),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN((from_entry)))),
 			 "focus_in_event", G_CALLBACK(from_entry_focus_evt_in), NULL);
-	g_signal_connect(G_OBJECT(GTK_BIN(from_entry)->child),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN((from_entry)))),
 			 "focus_out_event", G_CALLBACK(from_entry_focus_evt_out), NULL);
 
 	to_entry = gtk_combo_box_entry_new_text ();
@@ -293,9 +289,9 @@ static void summary_search_create(void)
 			  GTK_EXPAND|GTK_FILL, 0, 0, 0);
 	g_signal_connect(G_OBJECT(to_entry), "changed",
 			 G_CALLBACK(to_changed), NULL);
-	g_signal_connect(G_OBJECT(GTK_BIN(to_entry)->child),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN((to_entry)))),
 			 "focus_in_event", G_CALLBACK(to_entry_focus_evt_in), NULL);
-	g_signal_connect(G_OBJECT(GTK_BIN(to_entry)->child),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN((to_entry)))),
 			 "focus_out_event", G_CALLBACK(to_entry_focus_evt_out), NULL);
 
 	subject_entry = gtk_combo_box_entry_new_text ();
@@ -308,9 +304,9 @@ static void summary_search_create(void)
 			  GTK_EXPAND|GTK_FILL, 0, 0, 0);
 	g_signal_connect(G_OBJECT(subject_entry), "changed",
 			 G_CALLBACK(subject_changed), NULL);
-	g_signal_connect(G_OBJECT(GTK_BIN(subject_entry)->child),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN((subject_entry)))),
 			 "focus_in_event", G_CALLBACK(subject_entry_focus_evt_in), NULL);
-	g_signal_connect(G_OBJECT(GTK_BIN(subject_entry)->child),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN((subject_entry)))),
 			 "focus_out_event", G_CALLBACK(subject_entry_focus_evt_out), NULL);
 
 	body_entry = gtk_combo_box_entry_new_text ();
@@ -323,9 +319,9 @@ static void summary_search_create(void)
 			  GTK_EXPAND|GTK_FILL, 0, 0, 0);
 	g_signal_connect(G_OBJECT(body_entry), "changed",
 			 G_CALLBACK(body_changed), NULL);
-	g_signal_connect(G_OBJECT(GTK_BIN(body_entry)->child),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN((body_entry)))),
 			 "focus_in_event", G_CALLBACK(body_entry_focus_evt_in), NULL);
-	g_signal_connect(G_OBJECT(GTK_BIN(body_entry)->child),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN((body_entry)))),
 			 "focus_out_event", G_CALLBACK(body_entry_focus_evt_out), NULL);
 
 	adv_condition_entry = gtk_combo_box_entry_new_text ();
@@ -338,9 +334,9 @@ static void summary_search_create(void)
 			  GTK_EXPAND|GTK_FILL, 0, 0, 0);
 	g_signal_connect(G_OBJECT(adv_condition_entry), "changed",
 			 G_CALLBACK(adv_condition_changed), NULL);
-	g_signal_connect(G_OBJECT(GTK_BIN(adv_condition_entry)->child),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN((adv_condition_entry)))),
 			 "focus_in_event", G_CALLBACK(adv_condition_entry_focus_evt_in), NULL);
-	g_signal_connect(G_OBJECT(GTK_BIN(adv_condition_entry)->child),
+	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN((adv_condition_entry)))),
 			 "focus_out_event", G_CALLBACK(adv_condition_entry_focus_evt_out), NULL);
 
 	adv_condition_btn = gtk_button_new_with_label(" ... ");
@@ -349,9 +345,9 @@ static void summary_search_create(void)
 			  GTK_FILL, 0, 0, 0);
 	g_signal_connect(G_OBJECT (adv_condition_btn), "clicked",
 			 G_CALLBACK(adv_condition_btn_clicked), search_window.window);
-	tooltip = gtk_tooltips_new();
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(tooltip), adv_condition_btn,
-			     _("Edit search criteria"), NULL);
+
+	CLAWS_SET_TIP(adv_condition_btn,
+			     _("Edit search criteria"));
 
 	from_label = gtk_label_new (_("From:"));
 	gtk_widget_show (from_label);
@@ -494,8 +490,8 @@ static void summary_search_create(void)
 static void summary_search_execute(gboolean backward, gboolean search_all)
 {
 	SummaryView *summaryview = search_window.summaryview;
-	GtkCTree *ctree = GTK_CTREE(summaryview->ctree);
-	GtkCTreeNode *node;
+	GtkCMCTree *ctree = GTK_CMCTREE(summaryview->ctree);
+	GtkCMCTreeNode *node;
 	MsgInfo *msginfo;
 	gboolean adv_search;
 	gboolean bool_and = FALSE;
@@ -628,13 +624,13 @@ static void summary_search_execute(gboolean backward, gboolean search_all)
 	if (search_all) {
 		summary_freeze(summaryview);
 		summary_unselect_all(summaryview);
-		node = GTK_CTREE_NODE(GTK_CLIST(ctree)->row_list);
+		node = GTK_CMCTREE_NODE(GTK_CMCLIST(ctree)->row_list);
 		backward = FALSE;
 	} else if (!summaryview->selected) {
 		if (backward) {
-			node = GTK_CTREE_NODE(GTK_CLIST(ctree)->row_list_end);
+			node = GTK_CMCTREE_NODE(GTK_CMCLIST(ctree)->row_list_end);
 		} else {
-			node = GTK_CTREE_NODE(GTK_CLIST(ctree)->row_list);
+			node = GTK_CMCTREE_NODE(GTK_CMCLIST(ctree)->row_list);
 		}
 
 		if (!node) {
@@ -680,11 +676,11 @@ static void summary_search_execute(gboolean backward, gboolean search_all)
 					 GTK_STOCK_NO, "+" GTK_STOCK_YES, NULL);
 			if (G_ALERTALTERNATE == val) {
 				if (backward) {
-					node = GTK_CTREE_NODE
-						(GTK_CLIST(ctree)->row_list_end);
+					node = GTK_CMCTREE_NODE
+						(GTK_CMCLIST(ctree)->row_list_end);
 				} else {
-					node = GTK_CTREE_NODE
-						(GTK_CLIST(ctree)->row_list);
+					node = GTK_CMCTREE_NODE
+						(GTK_CMCLIST(ctree)->row_list);
 				}
 
 				all_searched = TRUE;
@@ -695,7 +691,7 @@ static void summary_search_execute(gboolean backward, gboolean search_all)
 			}
 		}
 
-		msginfo = gtk_ctree_node_get_row_data(ctree, node);
+		msginfo = gtk_cmctree_node_get_row_data(ctree, node);
 		body_matched = FALSE;
 
 		if (adv_search) {
@@ -762,7 +758,7 @@ static void summary_search_execute(gboolean backward, gboolean search_all)
 
 		if (matched) {
 			if (search_all) {
-				gtk_ctree_select(ctree, node);
+				gtk_cmctree_select(ctree, node);
 			} else {
 				if (messageview_is_visible
 					(summaryview->messageview)) {
@@ -807,12 +803,12 @@ static void summary_search_clear(GtkButton *button, gpointer data)
 {
 	if (gtk_toggle_button_get_active
 		(GTK_TOGGLE_BUTTON(search_window.adv_search_checkbtn))) {
-		gtk_entry_set_text(GTK_ENTRY(GTK_BIN(search_window.adv_condition_entry)->child), "");
+		gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN((search_window.adv_condition_entry)))), "");
 	} else {
-		gtk_entry_set_text(GTK_ENTRY(GTK_BIN(search_window.from_entry)->child), "");
-		gtk_entry_set_text(GTK_ENTRY(GTK_BIN(search_window.to_entry)->child), "");
-		gtk_entry_set_text(GTK_ENTRY(GTK_BIN(search_window.subject_entry)->child), "");
-		gtk_entry_set_text(GTK_ENTRY(GTK_BIN(search_window.body_entry)->child), "");
+		gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN((search_window.from_entry)))), "");
+		gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN((search_window.to_entry)))), "");
+		gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN((search_window.subject_entry)))), "");
+		gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN((search_window.body_entry)))), "");
 	}
 	/* stop searching */
 	if (search_window.is_searching) {
@@ -849,7 +845,7 @@ static void adv_condition_btn_done(MatcherList * matchers)
 	str = matcherlist_to_string(matchers);
 
 	if (str != NULL) {
-		gtk_entry_set_text(GTK_ENTRY(GTK_BIN(search_window.adv_condition_entry)->child), str);
+		gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN((search_window.adv_condition_entry)))), str);
 		g_free(str);
 	}
 }
