@@ -91,9 +91,9 @@ static void activate_compose_button 		(Toolbar	*toolbar,
 
 /* toolbar callbacks */
 static void toolbar_reply			(gpointer 	 data, 
-						 guint 		 action);
+						 guint		 action);
 static void toolbar_learn			(gpointer 	 data, 
-						 guint 		 action);
+						 guint		 action);
 static void toolbar_delete_cb			(GtkWidget	*widget,
 					 	 gpointer        data);
 static void toolbar_trash_cb			(GtkWidget	*widget,
@@ -164,7 +164,7 @@ static void toolbar_linewrap_all_cb		(GtkWidget	*widget,
 					 	 gpointer	 data);
 static void toolbar_addrbook_cb   		(GtkWidget   	*widget, 
 					 	 gpointer     	 data);
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 static void toolbar_check_spelling_cb  		(GtkWidget   	*widget, 
 					 	 gpointer     	 data);
 #endif
@@ -208,7 +208,7 @@ struct {
 	{ "A_LINEWRAP_CURRENT",	N_("Wrap long lines of current paragraph") }, 
 	{ "A_LINEWRAP_ALL",     N_("Wrap all long lines")                  }, 
 	{ "A_ADDRBOOK",      	N_("Address book")                         },
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 	{ "A_CHECK_SPELLING",	N_("Check spelling")                       },
 #endif
 	{ "A_CLAWS_ACTIONS",   	N_("Claws Mail Actions Feature")	   }, 
@@ -230,40 +230,6 @@ struct {
 	{ "toolbar_compose.xml", NULL}, 
   	{ "toolbar_msgview.xml", NULL}
 };
-#ifndef GENERIC_UMPC
-static GtkItemFactoryEntry reply_entries[] =
-{
-	{N_("/Reply with _quote"), NULL,    toolbar_reply, COMPOSE_REPLY_WITH_QUOTE, NULL},
-	{N_("/_Reply without quote"), NULL, toolbar_reply, COMPOSE_REPLY_WITHOUT_QUOTE, NULL}
-};
-static GtkItemFactoryEntry replyall_entries[] =
-{
-	{N_("/Reply to all with _quote"), "<shift>A", toolbar_reply, COMPOSE_REPLY_TO_ALL_WITH_QUOTE, NULL},
-	{N_("/_Reply to all without quote"), "a",     toolbar_reply, COMPOSE_REPLY_TO_ALL_WITHOUT_QUOTE, NULL}
-};
-static GtkItemFactoryEntry replylist_entries[] =
-{
-	{N_("/Reply to list with _quote"),    NULL, toolbar_reply, COMPOSE_REPLY_TO_LIST_WITH_QUOTE, NULL},
-	{N_("/_Reply to list without quote"), NULL, toolbar_reply, COMPOSE_REPLY_TO_LIST_WITHOUT_QUOTE, NULL}
-};
-static GtkItemFactoryEntry replysender_entries[] =
-{
-	{N_("/Reply to sender with _quote"),    NULL, toolbar_reply, COMPOSE_REPLY_TO_SENDER_WITH_QUOTE, NULL},
-	{N_("/_Reply to sender without quote"), NULL, toolbar_reply, COMPOSE_REPLY_TO_SENDER_WITHOUT_QUOTE, NULL}
-};
-static GtkItemFactoryEntry forward_entries[] =
-{
-	{N_("/_Forward"),		"f", 	    toolbar_reply, COMPOSE_FORWARD_INLINE, NULL},
-	{N_("/For_ward as attachment"), "<shift>F", toolbar_reply, COMPOSE_FORWARD_AS_ATTACH, NULL},
-	{N_("/Redirec_t"),		NULL, 	    toolbar_reply, COMPOSE_REDIRECT, NULL}
-};
-#endif
-static GtkItemFactoryEntry learn_entries[] =
-{
-	{N_("/Learn as _Spam"),		NULL,	toolbar_learn, TRUE, NULL},
-	{N_("/Learn as _Ham"), 		NULL,	toolbar_learn, FALSE, NULL}
-};
-
 
 gint toolbar_ret_val_from_descr(const gchar *descr)
 {
@@ -346,7 +312,7 @@ GList *toolbar_get_action_items(ToolbarType source)
 					A_INSERT,        A_ATTACH,       A_SIG,
 					A_EXTEDITOR,     A_LINEWRAP_CURRENT,     
 					A_LINEWRAP_ALL,  A_ADDRBOOK,
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 					A_CHECK_SPELLING, 
 #endif
 					A_CLOSE };	
@@ -449,7 +415,7 @@ const gchar *toolbar_get_short_text(int action) {
 	case A_ADDRBOOK: 	return _("Address");
 	case A_CANCEL_INC:	return _("Stop");
 	case A_EXECUTE:		return _("Execute");
-	#ifdef USE_ASPELL
+	#ifdef USE_ENCHANT
 	case A_CHECK_SPELLING:	return _("Check spelling");
 	#endif
 	default:		return "";
@@ -492,7 +458,7 @@ gint toolbar_get_icon(int action) {
 	case A_ADDRBOOK: 	return STOCK_PIXMAP_ADDRESS_BOOK;
 	case A_CANCEL_INC:	return STOCK_PIXMAP_CANCEL;
 	case A_EXECUTE:		return STOCK_PIXMAP_EXEC;
-	#ifdef USE_ASPELL
+	#ifdef USE_ENCHANT
 	case A_CHECK_SPELLING:	return STOCK_PIXMAP_CHECK_SPELLING;
 	#endif
 	default:		return -1;
@@ -874,10 +840,35 @@ static void toolbar_action_execute(GtkWidget    *widget,
 		g_warning ("Error: did not find Claws Action to execute");
 }
 
+#if !(GTK_CHECK_VERSION(2,12,0))
+#define CLAWS_SET_TOOL_ITEM_TIP(widget,tip) { \
+	gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(widget), GTK_TOOLTIPS(toolbar_tips),	\
+			tip, NULL);								\
+}
+#else
+#define CLAWS_SET_TOOL_ITEM_TIP(widget,tip) { \
+	gtk_tool_item_set_tooltip_text(GTK_TOOL_ITEM(widget), tip);				\
+}
+#endif	
+
+#if !(GTK_CHECK_VERSION(2,12,0))
+#define CLAWS_SET_ARROW_TIP(widget,tip) { \
+	gtk_menu_tool_button_set_arrow_tooltip(GTK_MENU_TOOL_BUTTON(widget), GTK_TOOLTIPS(toolbar_tips),	\
+			tip, NULL);								\
+}
+#else
+#define CLAWS_SET_ARROW_TIP(widget,tip) { \
+	gtk_menu_tool_button_set_arrow_tooltip_text(GTK_MENU_TOOL_BUTTON(widget), tip);				\
+}
+#endif	
+
 static void activate_compose_button (Toolbar           *toolbar,
 				     ToolbarStyle      style,
 				     ComposeButtonType type)
 {
+#if !(GTK_CHECK_VERSION(2,12,0))
+	GtkTooltips *toolbar_tips = toolbar->tooltips;
+#endif
 	if ((!toolbar->compose_mail_btn))
 		return;
 
@@ -886,8 +877,7 @@ static void activate_compose_button (Toolbar           *toolbar,
 			GTK_TOOL_BUTTON(toolbar->compose_mail_btn),
 			toolbar->compose_news_icon);
 #ifndef GENERIC_UMPC
-		gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(toolbar->compose_mail_btn), GTK_TOOLTIPS(toolbar->tooltips),
-			_("Compose News message"), NULL);
+		CLAWS_SET_TOOL_ITEM_TIP(GTK_TOOL_ITEM(toolbar->compose_mail_btn), _("Compose News message"));
 #endif	
 		gtk_widget_show(toolbar->compose_news_icon);
 	} else {
@@ -895,8 +885,7 @@ static void activate_compose_button (Toolbar           *toolbar,
 			GTK_TOOL_BUTTON(toolbar->compose_mail_btn),
 			toolbar->compose_mail_icon);
 #ifndef GENERIC_UMPC
-		gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(toolbar->compose_mail_btn), GTK_TOOLTIPS(toolbar->tooltips),
-			_("Compose Email"), NULL);
+		CLAWS_SET_TOOL_ITEM_TIP(GTK_TOOL_ITEM(toolbar->compose_mail_btn), _("Compose Email"));
 #endif	
 		gtk_widget_show(toolbar->compose_mail_icon);
 	}
@@ -916,6 +905,9 @@ static void activate_learn_button (Toolbar           *toolbar,
 				     ToolbarStyle      style,
 				     LearnButtonType type)
 {
+#if !(GTK_CHECK_VERSION(2,12,0))
+	GtkTooltips *toolbar_tips = toolbar->tooltips;
+#endif
 	if ((!toolbar->learn_spam_btn))
 		return;
 
@@ -927,8 +919,7 @@ static void activate_learn_button (Toolbar           *toolbar,
 			GTK_TOOL_BUTTON(toolbar->learn_spam_btn),
 			_("Spam"));
 #ifndef GENERIC_UMPC
-		gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(toolbar->learn_spam_btn), GTK_TOOLTIPS(toolbar->tooltips),
-			_("Learn spam"), NULL);	
+		CLAWS_SET_TOOL_ITEM_TIP(GTK_TOOL_ITEM(toolbar->learn_spam_btn), _("Learn spam"));	
 #endif
 		gtk_widget_show(toolbar->learn_spam_icon);
 	} else {
@@ -939,8 +930,7 @@ static void activate_learn_button (Toolbar           *toolbar,
 			GTK_TOOL_BUTTON(toolbar->learn_spam_btn),
 			_("Ham"));
 #ifndef GENERIC_UMPC
-		gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(toolbar->learn_spam_btn), GTK_TOOLTIPS(toolbar->tooltips),
-			_("Learn ham"), NULL);
+		CLAWS_SET_TOOL_ITEM_TIP(GTK_TOOL_ITEM(toolbar->learn_spam_btn), _("Learn ham"));
 #endif	
 		gtk_widget_show(toolbar->learn_ham_icon);
 	}
@@ -1249,8 +1239,8 @@ static void toolbar_learn_cb(GtkWidget *widget, gpointer data)
  */
 static void toolbar_reply_cb(GtkWidget *widget, gpointer data)
 {
-	toolbar_reply(data, prefs_common.reply_with_quote ? 
-		      COMPOSE_REPLY_WITH_QUOTE : COMPOSE_REPLY_WITHOUT_QUOTE);
+	toolbar_reply(data, (prefs_common.reply_with_quote ? 
+		      COMPOSE_REPLY_WITH_QUOTE : COMPOSE_REPLY_WITHOUT_QUOTE));
 }
 
 
@@ -1260,8 +1250,8 @@ static void toolbar_reply_cb(GtkWidget *widget, gpointer data)
 static void toolbar_reply_to_all_cb(GtkWidget *widget, gpointer data)
 {
 	toolbar_reply(data,
-		      prefs_common.reply_with_quote ? COMPOSE_REPLY_TO_ALL_WITH_QUOTE 
-		      : COMPOSE_REPLY_TO_ALL_WITHOUT_QUOTE);
+		      (prefs_common.reply_with_quote ? COMPOSE_REPLY_TO_ALL_WITH_QUOTE 
+		      : COMPOSE_REPLY_TO_ALL_WITHOUT_QUOTE));
 }
 
 
@@ -1271,8 +1261,8 @@ static void toolbar_reply_to_all_cb(GtkWidget *widget, gpointer data)
 static void toolbar_reply_to_list_cb(GtkWidget *widget, gpointer data)
 {
 	toolbar_reply(data, 
-		      prefs_common.reply_with_quote ? COMPOSE_REPLY_TO_LIST_WITH_QUOTE 
-		      : COMPOSE_REPLY_TO_LIST_WITHOUT_QUOTE);
+		      (prefs_common.reply_with_quote ? COMPOSE_REPLY_TO_LIST_WITH_QUOTE 
+		      : COMPOSE_REPLY_TO_LIST_WITHOUT_QUOTE));
 }
 
 
@@ -1282,8 +1272,8 @@ static void toolbar_reply_to_list_cb(GtkWidget *widget, gpointer data)
 static void toolbar_reply_to_sender_cb(GtkWidget *widget, gpointer data)
 {
 	toolbar_reply(data, 
-		      prefs_common.reply_with_quote ? COMPOSE_REPLY_TO_SENDER_WITH_QUOTE 
-		      : COMPOSE_REPLY_TO_SENDER_WITHOUT_QUOTE);
+		      (prefs_common.reply_with_quote ? COMPOSE_REPLY_TO_SENDER_WITH_QUOTE 
+		      : COMPOSE_REPLY_TO_SENDER_WITHOUT_QUOTE));
 }
 
 /*
@@ -1316,7 +1306,7 @@ static void toolbar_addrbook_cb(GtkWidget *widget, gpointer data)
  */
 static void toolbar_forward_cb(GtkWidget *widget, gpointer data)
 {
-	toolbar_reply(data, COMPOSE_FORWARD);
+	toolbar_reply(data, (COMPOSE_FORWARD));
 }
 
 /*
@@ -1585,7 +1575,7 @@ static void toolbar_linewrap_all_cb(GtkWidget *widget, gpointer data)
 	compose_toolbar_cb(A_LINEWRAP_ALL, data);
 }
 
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 static void toolbar_check_spelling_cb(GtkWidget *widget, gpointer data)
 {
 	compose_toolbar_cb(A_CHECK_SPELLING, data);
@@ -1715,7 +1705,7 @@ static void toolbar_buttons_cb(GtkWidget   *widget,
 		{ A_LINEWRAP_CURRENT,	toolbar_linewrap_current_cb   	},
 		{ A_LINEWRAP_ALL,	toolbar_linewrap_all_cb   	},
 		{ A_ADDRBOOK,		toolbar_addrbook_cb		},
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 		{ A_CHECK_SPELLING,     toolbar_check_spelling_cb       },
 #endif
 		{ A_CLAWS_ACTIONS,	toolbar_actions_execute_cb	},
@@ -1738,8 +1728,8 @@ static void toolbar_buttons_cb(GtkWidget   *widget,
 	gtk_tool_item_set_is_important(GTK_TOOL_ITEM(item), TRUE);					\
 	g_signal_connect (G_OBJECT(item), "clicked", G_CALLBACK(toolbar_buttons_cb), toolbar_item);	\
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(item), -1);				\
-	gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(item), GTK_TOOLTIPS(toolbar_tips),			\
-			tooltip, NULL);									\
+	CLAWS_SET_TOOL_ITEM_TIP(GTK_TOOL_ITEM(item), 							\
+			tooltip);									\
 }
 
 #define TOOLBAR_MENUITEM(item,icon,text,tooltip,menutip) {						\
@@ -1750,10 +1740,9 @@ static void toolbar_buttons_cb(GtkWidget   *widget,
 	gtk_tool_item_set_is_important(GTK_TOOL_ITEM(item), TRUE);					\
 	g_signal_connect (G_OBJECT(item), "clicked", G_CALLBACK(toolbar_buttons_cb), toolbar_item);	\
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(item), -1);				\
-	gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(item), GTK_TOOLTIPS(toolbar_tips),			\
-			tooltip, NULL);									\
-	gtk_menu_tool_button_set_arrow_tooltip(GTK_MENU_TOOL_BUTTON(item), 				\
-				GTK_TOOLTIPS(toolbar_tips), menutip, NULL);				\
+	CLAWS_SET_TOOL_ITEM_TIP(GTK_TOOL_ITEM(item), 							\
+			tooltip);									\
+	CLAWS_SET_ARROW_TIP(GTK_MENU_TOOL_BUTTON(item), menutip);					\
 	child = gtk_bin_get_child(GTK_BIN(item)); 							\
 	gchild = gtk_container_get_children(								\
 			GTK_CONTAINER(child)); 								\
@@ -1793,11 +1782,30 @@ static void toolbar_buttons_cb(GtkWidget   *widget,
 }
 #endif
 
-#define MAKE_MENU(entries,path,btn) {									\
-	n_menu_entries = sizeof(entries) /								\
-		sizeof(entries[0]);									\
-	menu = menu_create_items(entries, n_menu_entries, path, &factory, toolbar_item);		\
-	gtk_menu_tool_button_set_menu(GTK_MENU_TOOL_BUTTON(btn), menu);					\
+#define ADD_MENU_ITEM(name,cb,data) {							\
+	item = gtk_menu_item_new_with_mnemonic(name);					\
+	gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);				\
+	g_signal_connect(G_OBJECT(item), "activate",					\
+			 G_CALLBACK(cb),						\
+			   toolbar_item);						\
+	g_object_set_data(G_OBJECT(item), "int-value", GINT_TO_POINTER(data));		\
+	gtk_widget_show(item);								\
+}
+
+static void toolbar_reply_menu_cb(GtkWidget *widget, gpointer data)
+{
+	gpointer int_value = g_object_get_data(G_OBJECT(widget), "int-value");
+	ToolbarItem *toolbar_item = (ToolbarItem *)data;
+	
+	toolbar_reply(toolbar_item, GPOINTER_TO_INT(int_value));
+}
+
+static void toolbar_learn_menu_cb(GtkWidget *widget, gpointer data)
+{
+	gpointer int_value = g_object_get_data(G_OBJECT(widget), "int-value");
+	ToolbarItem *toolbar_item = (ToolbarItem *)data;
+	
+	toolbar_learn(toolbar_item, GPOINTER_TO_INT(int_value));
 }
 
 /**
@@ -1816,17 +1824,15 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 	GtkWidget *icon_news;
 	GtkWidget *icon_ham;
 	GtkWidget *item;
-	GtkWidget *menu;
-	guint n_menu_entries;
-	GtkItemFactory *factory;
 	ToolbarClawsActions *action_item;
 	GSList *cur;
 	GSList *toolbar_list;
 	Toolbar *toolbar_data;
+	GtkWidget *menu;
 #ifndef GENERIC_UMPC
-	GtkTooltips *toolbar_tips;
-	
- 	toolbar_tips = gtk_tooltips_new();
+#if !(GTK_CHECK_VERSION(2,12,0))
+	GtkTooltips *toolbar_tips = gtk_tooltips_new();
+#endif
 #endif	
 	toolbar_read_config_file(type);
 	toolbar_list = toolbar_get_list(type);
@@ -1925,7 +1931,10 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 			toolbar_data->learn_ham_icon = icon_ham; 
 			g_object_ref(toolbar_data->learn_ham_icon);
 
-			MAKE_MENU(learn_entries,"<LearnSpam>",toolbar_data->learn_spam_btn);
+			menu = gtk_menu_new();
+			ADD_MENU_ITEM(_("Learn as _Spam"), toolbar_learn_menu_cb, TRUE);
+			ADD_MENU_ITEM(_("Learn as _Ham"), toolbar_learn_menu_cb, FALSE);
+			gtk_menu_tool_button_set_menu(GTK_MENU_TOOL_BUTTON(toolbar_data->learn_spam_btn), menu);
 			break;
 		case A_REPLY_MESSAGE:
 #ifndef GENERIC_UMPC
@@ -1934,7 +1943,10 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 				_("Reply to Message options"));
 			toolbar_data->reply_btn = item;
 
-			MAKE_MENU(reply_entries,"<Reply>",toolbar_data->reply_btn);
+			menu = gtk_menu_new();
+			ADD_MENU_ITEM(_("_Reply with quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_WITH_QUOTE);
+			ADD_MENU_ITEM(_("Reply without _quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_WITHOUT_QUOTE);
+			gtk_menu_tool_button_set_menu(GTK_MENU_TOOL_BUTTON(toolbar_data->reply_btn), menu);
 #else
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,
 				_("Reply to Message"));
@@ -1948,7 +1960,10 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 				_("Reply to Sender options"));
 			toolbar_data->replysender_btn = item;
 
-			MAKE_MENU(replysender_entries,"<ReplySender>",toolbar_data->replysender_btn);
+			menu = gtk_menu_new();
+			ADD_MENU_ITEM(_("_Reply with quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_TO_SENDER_WITH_QUOTE);
+			ADD_MENU_ITEM(_("Reply without _quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_TO_SENDER_WITHOUT_QUOTE);
+			gtk_menu_tool_button_set_menu(GTK_MENU_TOOL_BUTTON(toolbar_data->replysender_btn), menu);
 #else
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,
 				_("Reply to Sender"));
@@ -1962,7 +1977,10 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 				_("Reply to All options"));
 			toolbar_data->replyall_btn = item;
 
-			MAKE_MENU(replyall_entries,"<ReplyAll>",toolbar_data->replyall_btn);
+			menu = gtk_menu_new();
+			ADD_MENU_ITEM(_("_Reply with quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_TO_ALL_WITH_QUOTE);
+			ADD_MENU_ITEM(_("Reply without _quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_TO_ALL_WITHOUT_QUOTE);
+			gtk_menu_tool_button_set_menu(GTK_MENU_TOOL_BUTTON(toolbar_data->replyall_btn), menu);
 #else
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,
 				_("Reply to All"));
@@ -1976,7 +1994,10 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 				_("Reply to Mailing-list options"));
 			toolbar_data->replylist_btn = item;
 
-			MAKE_MENU(replylist_entries,"<ReplyList>",toolbar_data->replylist_btn);
+			menu = gtk_menu_new();
+			ADD_MENU_ITEM(_("_Reply with quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_TO_LIST_WITH_QUOTE);
+			ADD_MENU_ITEM(_("Reply without _quote"), toolbar_reply_menu_cb, COMPOSE_REPLY_TO_LIST_WITHOUT_QUOTE);
+			gtk_menu_tool_button_set_menu(GTK_MENU_TOOL_BUTTON(toolbar_data->replylist_btn), menu);
 #else
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,
 				_("Reply to Mailing-list"));
@@ -1990,7 +2011,11 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 				_("Forward Message options"));
 			toolbar_data->fwd_btn = item;
 
-			MAKE_MENU(forward_entries,"<Forward>",toolbar_data->fwd_btn);
+			menu = gtk_menu_new();
+			ADD_MENU_ITEM(_("_Forward"), toolbar_reply_menu_cb, COMPOSE_FORWARD_INLINE);
+			ADD_MENU_ITEM(_("For_ward as attachment"), toolbar_reply_menu_cb, COMPOSE_FORWARD_AS_ATTACH);
+			ADD_MENU_ITEM(_("Redirec_t"), toolbar_reply_menu_cb, COMPOSE_REDIRECT);
+			gtk_menu_tool_button_set_menu(GTK_MENU_TOOL_BUTTON(toolbar_data->fwd_btn), menu);
 #else
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,
 				_("Forward Message"));
@@ -2059,7 +2084,7 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,_("Address book"));
 			toolbar_data->addrbook_btn = item;
 			break;
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 		case A_CHECK_SPELLING:
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,_("Check spelling"));
 			toolbar_data->spellcheck_btn = item;
@@ -2090,7 +2115,9 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 	}
 	toolbar_data->toolbar = toolbar;
 #ifndef GENERIC_UMPC
+#if !(GTK_CHECK_VERSION(2,12,0))
 	toolbar_data->tooltips = toolbar_tips;
+#endif
 #endif
 	gtk_widget_show_all(toolbar);
 
@@ -2213,6 +2240,8 @@ void toolbar_update(ToolbarType type, gpointer data)
 	}
 }
 
+#if !GTK_CHECK_VERSION(2,14,0)
+/* Work around http://bugzilla.gnome.org/show_bug.cgi?id=56070 */
 #define GTK_BUTTON_SET_SENSITIVE(widget,sensitive) {		\
 	gboolean in_btn1 = FALSE, in_btn2 = FALSE;		\
 	if (GTK_IS_BUTTON(widget))				\
@@ -2261,6 +2290,11 @@ void toolbar_update(ToolbarType type, gpointer data)
 			GTK_BUTTON(child)->in_button = in_btn1;	\
 	}							\
 }
+#else
+#define GTK_BUTTON_SET_SENSITIVE(widget,sensitive) {		\
+	gtk_widget_set_sensitive(widget, sensitive);		\
+}
+#endif
 
 void toolbar_main_set_sensitive(gpointer data)
 {
@@ -2417,7 +2451,7 @@ void toolbar_comp_set_sensitive(gpointer data, gboolean sensitive)
 		GTK_BUTTON_SET_SENSITIVE(compose->toolbar->linewrap_all_btn, sensitive);
 	if (compose->toolbar->addrbook_btn)
 		GTK_BUTTON_SET_SENSITIVE(compose->toolbar->addrbook_btn, sensitive);
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 	if (compose->toolbar->spellcheck_btn)
 		GTK_BUTTON_SET_SENSITIVE(compose->toolbar->spellcheck_btn, sensitive);
 #endif
@@ -2463,7 +2497,7 @@ static void toolbar_init(Toolbar * toolbar)
 	toolbar->linewrap_current_btn	= NULL;	
 	toolbar->linewrap_all_btn     	= NULL;	
 	toolbar->addrbook_btn     	= NULL;	
-#ifdef USE_ASPELL
+#ifdef USE_ENCHANT
 	toolbar->spellcheck_btn   	= NULL;
 #endif
 
